@@ -18,12 +18,12 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include "config.h" //For VERSION, GLOM_ENABLE_CLIENT_ONLY, GLOM_ENABLE_SQLITE
+#include <config.h> //For VERSION, GLOM_ENABLE_CLIENT_ONLY, GLOM_ENABLE_SQLITE
 
-#include "application.h"
-#include "dialog_existing_or_new.h"
+#include <glom/application.h>
+#include <glom/dialog_existing_or_new.h>
 
-#include <libglom/dialog_progress_creating.h>
+#include <glom/dialog_progress_creating.h>
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 #include <glom/translation/dialog_change_language.h>
@@ -31,11 +31,9 @@
 #include <glom/utility_widgets/filechooserdialog_saveextras.h>
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-#include <libglom/utils.h>
-#include <libglom/glade_utils.h>
-
-//#include <libglom/connectionpool_backends/postgres_central.h>
-//#include <libglom/connectionpool_backends/postgres_self.h>
+#include <glom/utils_ui.h>
+#include <glom/glade_utils.h>
+#include <glom/glom_privs.h>
 
 #include <cstdio>
 #include <memory> //For std::auto_ptr<>
@@ -92,17 +90,8 @@ static const int GLOM_RESPONSE_BROWSE_NETWORK = 1;
 // Global application variable
 App_Glom* global_application = NULL;
 
-App_Glom::App_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
-  // Note cobject is actually a GtkWindow, not a HildonWindow, because the
-  // glade file specified the type as GtkWindow.
-  // ParentWindow is defined in Bakery.
-  // The compilation will fail here if you have not built Bakery with or without --enable-maemo as appropriate:
-#ifdef GLOM_ENABLE_MAEMO
-: ParentWindow(turn_gtk_window_into_hildon_window(GTK_WINDOW(cobject))), //It's a virtual base class, so we have to call the specific constructor to prevent the default constructor from being called.
-#else
-: ParentWindow(cobject), //It's a virtual base class, so we have to call the specific constructor to prevent the default constructor from being called.
-#endif
-  type_base(cobject, "Glom"),
+App_Glom::App_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
+: type_base(cobject, "Glom"),
   m_pBoxTop(0),
   m_pFrame(0),
 #ifndef GLOM_ENABLE_CLIENT_ONLY
@@ -113,9 +102,10 @@ App_Glom::App_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml
   m_menu_print_layouts_ui_merge_id(0),
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   m_ui_save_extra_showextras(false),
-  m_ui_save_extra_newdb_hosting_mode(Document_Glom::DEFAULT_HOSTED),
+  m_ui_save_extra_newdb_hosting_mode(Document::DEFAULT_HOSTED),
 
 #endif // !GLOM_ENABLE_CLIENT_ONLY
+  m_avahi_progress_dialog(0),
   m_show_sql_debug(false)
 {
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
@@ -143,15 +133,23 @@ App_Glom::App_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml
   } 
 
   //Load widgets from glade file:
-  refGlade->get_widget("bakery_vbox", m_pBoxTop);
-  refGlade->get_widget("sidebar_vbox", m_pBoxSidebar);
-  refGlade->get_widget_derived("vbox_frame", m_pFrame); //This one is derived. There's a lot happening here.
+  builder->get_widget("bakery_vbox", m_pBoxTop);
+  builder->get_widget("sidebar_vbox", m_pBoxSidebar);
+  builder->get_widget_derived("vbox_frame", m_pFrame); //This one is derived. There's a lot happening here.
 
   add_mime_type("application/x-glom"); //TODO: make this actually work - we need to register it properly.
 
   //Hide the toolbar because it doesn't contain anything useful for this app.
   m_HandleBox_Toolbar.hide();
   
+  //Install UI hooks for this:
+  ConnectionPool* connection_pool = ConnectionPool::get_instance();
+  if(!connection_pool)
+    connection_pool->set_avahi_publish_callbacks(
+      sigc::mem_fun(*this, &App_Glom::on_connection_avahi_begin),
+      sigc::mem_fun(*this, &App_Glom::on_connection_avahi_progress),
+      sigc::mem_fun(*this, &App_Glom::on_connection_avahi_done) );     
+  
   global_application = this;
 }
 
@@ -164,11 +162,49 @@ App_Glom::~App_Glom()
     delete m_window_translations;
   }
 #endif // !GLOM_ENABLE_CLIENT_ONLY
+
+  if(m_avahi_progress_dialog)
+  {
+    delete m_avahi_progress_dialog;
+    m_avahi_progress_dialog = 0;
+  }
+}
+
+void App_Glom::on_connection_avahi_begin()
+{
+  //Create the dialog:
+  if(m_avahi_progress_dialog)
+  {
+    delete m_avahi_progress_dialog;
+    m_avahi_progress_dialog = 0;
+  }
+
+  m_avahi_progress_dialog = new Gtk::MessageDialog(Utils::bold_message(_("Glom: Generating Encryption Certificates")), true, Gtk::MESSAGE_INFO);
+  m_avahi_progress_dialog->set_secondary_text(_("Please wait while Glom prepares your system for publishing over the network."));
+  m_avahi_progress_dialog->set_transient_for(*this);
+  m_avahi_progress_dialog->show();
+}
+
+void App_Glom::on_connection_avahi_progress()
+{
+  //Allow GTK+ to process events, so that the UI is responsive:
+  while(Gtk::Main::events_pending())
+   Gtk::Main::iteration();
+}
+
+void App_Glom::on_connection_avahi_done()
+{
+  //Delete the dialog:
+  if(m_avahi_progress_dialog)
+  {
+    delete m_avahi_progress_dialog;
+    m_avahi_progress_dialog = 0;
+  }
 }
 
 bool App_Glom::init(const Glib::ustring& document_uri)
 {
-  type_vecStrings vecAuthors;
+  type_vec_strings vecAuthors;
   vecAuthors.push_back("Murray Cumming <murrayc@murrayc.com>");
   set_about_information(VERSION, vecAuthors, _("(C) 2000-2005 Murray Cumming"), _("A Database GUI"));
 
@@ -181,7 +217,7 @@ bool App_Glom::init(const Glib::ustring& document_uri)
 
   if(document_uri.empty())
   {
-    Document_Glom* pDocument = static_cast<Document_Glom*>(get_document());
+    Document* pDocument = static_cast<Document*>(get_document());
     if(pDocument && pDocument->get_connection_database().empty()) //If it is a new (default) document.
     {
       return offer_new_or_existing();
@@ -259,22 +295,6 @@ void App_Glom::init_toolbars()
 */
 }
 
-//gtkmm <2.12.7 has a bug that stops this working with non-ASCII text,
-//so we use the C function instead.
-//We could put this in Bakery instead, but it's hard enough just getting updates 
-//into Ubuntu, so we override this Bakery::App method here.
-//TODO: Remove this when gtkmm 2.12.7 is distributed widely-enough.
-void App_Glom::add_ui_from_string(const Glib::ustring& ui_description)
-{
-  GError* error = 0;
-  gtk_ui_manager_add_ui_from_string(m_refUIManager->gobj(), ui_description.c_str(), ui_description.bytes(), &error);
-  if(error)
-  {
-    std::cerr << "App_Glom::add_ui_from_string(): exception: " << error->message << std::endl;
-    g_clear_error(&error);
-  }
-}
-
 void App_Glom::init_menus_file()
 {
   //Overridden to remove the Save and Save-As menu items,
@@ -308,6 +328,13 @@ void App_Glom::init_menus_file()
   m_refFileActionGroup->add(action, sigc::mem_fun(*m_pFrame, &Frame_Glom::on_menu_file_import));
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
+  m_toggleaction_network_shared = Gtk::ToggleAction::create("BakeryAction_Menu_File_Share", _("Shared On Network"));
+  m_refFileActionGroup->add(m_toggleaction_network_shared);
+  m_connection_toggleaction_network_shared = 
+    m_toggleaction_network_shared->signal_toggled().connect(
+      sigc::mem_fun(*this, &App_Glom::on_menu_file_toggle_share) );
+  m_listDeveloperActions.push_back(m_toggleaction_network_shared);
+
   m_refFileActionGroup->add(Gtk::Action::create("GlomAction_Menu_File_Print", Gtk::Stock::PRINT));
   m_refFileActionGroup->add(Gtk::Action::create("GlomAction_File_Print", _("_Standard")),
                         sigc::mem_fun(*m_pFrame, &Frame_Glom::on_menu_file_print) );
@@ -320,8 +347,6 @@ void App_Glom::init_menus_file()
 
   m_refFileActionGroup->add(Gtk::Action::create("BakeryAction_File_Close", Gtk::Stock::CLOSE),
                         sigc::mem_fun((App_WithDoc&)*this, &App_WithDoc::on_menu_file_close));
-  /*m_refFileActionGroup->add(Gtk::Action::create("BakeryAction_File_Exit", Gtk::Stock::QUIT),
-                        sigc::mem_fun((App&)*this, &App::on_menu_file_exit));*/
 
   m_refUIManager->insert_action_group(m_refFileActionGroup);
 
@@ -341,8 +366,10 @@ void App_Glom::init_menus_file()
     "        </menu>"
 #ifndef GLOM_ENABLE_CLIENT_ONLY
     "        <menuitem action='BakeryAction_File_SaveAsExample' />"
+    "        <separator/>"
     "        <menuitem action='BakeryAction_Menu_File_Export' />"
     "        <menuitem action='BakeryAction_Menu_File_Import' />"
+    "        <menuitem action='BakeryAction_Menu_File_Share' />"
 #endif // !GLOM_ENABLE_CLIENT_ONLY
     "        <separator/>"
     "        <menu action='GlomAction_Menu_File_Print'>"
@@ -587,6 +614,14 @@ void App_Glom::init_menus()
   fill_menu_tables();
 }
 
+void App_Glom::on_menu_file_toggle_share()
+{
+  if(!m_pFrame)
+    return;
+
+  m_pFrame->on_menu_file_toggle_share(m_toggleaction_network_shared);
+}
+
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 void App_Glom::on_menu_userlevel_developer()
 {
@@ -702,7 +737,7 @@ void App_Glom::open_browsed_document(const EpcServiceInfo* server, const Glib::u
   if(document_contents && length)
   {
     //Create a temporary Document instance, so we can manipulate the data:
-    Document_Glom document_temp;
+    Document document_temp;
     const bool loaded = document_temp.load_from_data((const guchar*)document_contents, length);
     if(loaded)
     {
@@ -710,8 +745,8 @@ void App_Glom::open_browsed_document(const EpcServiceInfo* server, const Glib::u
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 #ifdef GLOM_ENABLE_POSTGRESQL
       //Stop the document from being self-hosted (it's already hosted by the other networked Glom instance):
-      if(document_temp.get_hosting_mode() == Document_Glom::HOSTING_MODE_POSTGRES_SELF)
-        document_temp.set_hosting_mode(Document_Glom::HOSTING_MODE_POSTGRES_CENTRAL);
+      if(document_temp.get_hosting_mode() == Document::HOSTING_MODE_POSTGRES_SELF)
+        document_temp.set_hosting_mode(Document::HOSTING_MODE_POSTGRES_CENTRAL);
 #endif //GLOM_ENABLE_POSTGRESQL
 #endif // !GLOM_ENABLE_CLIENT_ONLY
       // TODO: Error out in case this is a sqlite database, since we probably
@@ -745,11 +780,14 @@ void App_Glom::open_browsed_document(const EpcServiceInfo* server, const Glib::u
     //so we don't think that opening has failed because it has no URI,
     //and to stop us from allowing developer mode
     //(that would require changes to the original document).
-    Document_Glom* document = dynamic_cast<Document_Glom*>(get_document());
+    Document* document = dynamic_cast<Document*>(get_document());
     if(document)
     {
       document->set_opened_from_browse();
 
+      document->set_network_shared(true); //It is shared by the computer that we opened this from.
+      update_network_shared_ui();
+
       document->set_userlevel(AppState::USERLEVEL_OPERATOR); //TODO: This should happen automatically.
 #ifndef GLOM_ENABLE_CLIENT_ONLY
       update_userlevel_ui();
@@ -790,7 +828,7 @@ void App_Glom::on_menu_file_open()
 void App_Glom::on_menu_file_close() //override
 {
   // Call the base class implementation:
-  Bakery::App_WithDoc_Gtk::on_menu_file_close();
+  GlomBakery::App_WithDoc_Gtk::on_menu_file_close();
 }
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
@@ -850,37 +888,36 @@ Glib::ustring App_Glom::get_file_uri_without_extension(const Glib::ustring& uri)
   }
 }
 
-Bakery::App* App_Glom::new_instance() //Override
+void App_Glom::new_instance(const Glib::ustring& uri) //Override
 {
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-  Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom.glade"), "window_main");
-#else
-  std::auto_ptr<Gnome::Glade::XmlError> error;
-  Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom.glade"), "window_main", "", error);
-  if(error.get())
-    return 0;
-#endif
+  Glib::ustring command = "glom";
+  if(!uri.empty())
+    command += " " + uri;
 
-  App_Glom* pApp_Glom = 0;
-  refXml->get_widget_derived("window_main", pApp_Glom);
-
-  return pApp_Glom;
+  GError* gerror = 0;
+  gdk_spawn_command_line_on_screen(Glib::unwrap(get_screen()),
+    command.c_str(),
+    &gerror);
+  if(gerror)
+  {
+    std::cerr << "App_Glom::new_instance(): error calling gdk_spawn_command_line_on_screen(): " << gerror->message << std::endl;
+  }
 }
 
 void App_Glom::init_create_document()
 {
   if(!m_pDocument)
   {
-    Document_Glom* document_glom = new Document_Glom();
+    Document* document_glom = new Document();
     m_pDocument = document_glom;
-    document_glom->set_parent_window(this); //So that it can show a BusyCursor when loading and saving.
+    //document_glom->set_parent_window(this); //So that it can show a BusyCursor when loading and saving.
 
     //Tell document about view:
     m_pDocument->set_view(m_pFrame);
 
     //Tell view about document:
     //(This calls set_document() in the child views too.)
-    m_pFrame->set_document(static_cast<Document_Glom*>(m_pDocument));
+    m_pFrame->set_document(static_cast<Document*>(m_pDocument));
   }
 
   type_base::init_create_document(); //Sets window title. Doesn't recreate doc.
@@ -891,7 +928,7 @@ bool App_Glom::on_document_load()
   //Link to the database described in the document.
   //Need to ask user for user/password:
   //m_pFrame->load_from_document();
-  Document_Glom* pDocument = static_cast<Document_Glom*>(get_document());
+  Document* pDocument = static_cast<Document*>(get_document());
   if(!pDocument)
   {
     return false;
@@ -930,6 +967,7 @@ bool App_Glom::on_document_load()
         // adding the URI to the recently used files in document_history_add.
         // We want to add the document that is created from the example
         // instead of the example itself.
+        // TODO: This is a weird hack. Find a nicer way. murrayc.
         m_example_uri = pDocument->get_file_uri();
 
         pDocument->set_file_uri(Glib::ustring()); //Prevent it from defaulting to the read-only examples directory when offering saveas.
@@ -938,7 +976,7 @@ bool App_Glom::on_document_load()
         m_ui_save_extra_title = _("Creating From Example File");
         m_ui_save_extra_message = _("To use this example file you must save an editable copy of the file. A new database will also be created on the server.");
         m_ui_save_extra_newdb_title = "TODO";
-        m_ui_save_extra_newdb_hosting_mode = Document_Glom::DEFAULT_HOSTED;
+        m_ui_save_extra_newdb_hosting_mode = Document::DEFAULT_HOSTED;
 
         
         // Reinit cancelled state
@@ -955,7 +993,7 @@ bool App_Glom::on_document_load()
           //Get the results from the extended save dialog:
           pDocument->set_database_title(m_ui_save_extra_newdb_title);
           pDocument->set_hosting_mode(m_ui_save_extra_newdb_hosting_mode);
-          m_ui_save_extra_newdb_hosting_mode = Document_Glom::DEFAULT_HOSTED;
+          m_ui_save_extra_newdb_hosting_mode = Document::DEFAULT_HOSTED;
           pDocument->set_is_example_file(false);
           // We have a valid uri, so we can set it to !new and modified here
         }        
@@ -981,11 +1019,11 @@ bool App_Glom::on_document_load()
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
       //Warn about read-only files, because users will otherwise wonder why they can't use Developer mode:
-      Document_Glom::userLevelReason reason = Document_Glom::USER_LEVEL_REASON_UNKNOWN;
+      Document::userLevelReason reason = Document::USER_LEVEL_REASON_UNKNOWN;
       const AppState::userlevels userlevel = pDocument->get_userlevel(reason);
-      if( (userlevel == AppState::USERLEVEL_OPERATOR) && (reason == Document_Glom::USER_LEVEL_REASON_FILE_READ_ONLY) )
+      if( (userlevel == AppState::USERLEVEL_OPERATOR) && (reason == Document::USER_LEVEL_REASON_FILE_READ_ONLY) )
       {
-        Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("Opening Read-Only File.")), true,  Gtk::MESSAGE_INFO, Gtk::BUTTONS_NONE);
+        Gtk::MessageDialog dialog(Utils::bold_message(_("Opening Read-Only File.")), true,  Gtk::MESSAGE_INFO, Gtk::BUTTONS_NONE);
         dialog.set_secondary_text(_("This file is read only, so you will not be able to enter Developer mode to make design changes."));
         dialog.set_transient_for(*this);
         dialog.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
@@ -1012,56 +1050,50 @@ bool App_Glom::on_document_load()
 
         //Attempt to connect to the specified database:
         bool test = false;
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-        try
-#else
-        std::auto_ptr<ExceptionConnection> error;
-#endif
-        {
+
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-          if(is_example)
-          {
-            //The user has already had the chance to specify a new filename and database name.
-            test = m_pFrame->connection_request_password_and_choose_new_database_name();
-          }
-          else
-#endif // !GLOM_ENABLE_CLIENT_ONLY
-            //Ask for the username/password and connect:
-            //Note that m_temp_username and m_temp_password are set if 
-            //we already asked for them when getting the document over the network: 
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-            test = m_pFrame->connection_request_password_and_attempt(m_temp_username, m_temp_password);
-#else
-            test = m_pFrame->connection_request_password_and_attempt(m_temp_username, m_temp_password, error);
-#endif
-            m_temp_username = Glib::ustring();
-            m_temp_password = Glib::ustring();
+        if(is_example)
+        {
+          //The user has already had the chance to specify a new filename and database name.
+          test = m_pFrame->connection_request_password_and_choose_new_database_name();
         }
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-        catch(const ExceptionConnection& ex)
+        else
+#endif // !GLOM_ENABLE_CLIENT_ONLY
         {
-#else
-        if(error.get())
-        {
-          const ExceptionConnection& ex = *error.get();
-#endif
-          if(ex.get_failure_type() == ExceptionConnection::FAILURE_NO_DATABASE) //This is the only FAILURE_* type that connection_request_password_and_attempt() throws.
+          //Ask for the username/password and connect:
+          //Note that m_temp_username and m_temp_password are set if 
+          //we already asked for them when getting the document over the network:
+
+          //Use the default username/password if opening as non network-shared:
+          if(!(pDocument->get_network_shared()))
           {
-#ifndef GLOM_ENABLE_CLIENT_ONLY
+            m_temp_username = Privs::get_default_developer_user_name(m_temp_password);
+          }
+
+          bool database_not_found = false;
+          test = m_pFrame->connection_request_password_and_attempt(database_not_found, m_temp_username, m_temp_password);
+          m_temp_username = Glib::ustring();
+          m_temp_password = Glib::ustring();
+
+          if(!test && database_not_found)
+          {
+            #ifndef GLOM_ENABLE_CLIENT_ONLY
             if(!is_example)
             {
               //The connection to the server is OK, but the database is not there yet.
               Frame_Glom::show_ok_dialog(_("Database Not Found On Server"), _("The database could not be found on the server. Please consult your system administrator."), *this, Gtk::MESSAGE_ERROR);
             }
             else
-#endif // !GLOM_ENABLE_CLIENT_ONLY
-              std::cerr << "App_Glom::on_document_load(): unexpected ExceptionConnection when opening example." << std::endl;
+            #endif // !GLOM_ENABLE_CLIENT_ONLY
+              std::cerr << "App_Glom::on_document_load(): unexpected database_not_found error when opening example." << std::endl;
+          }
+          else if(!test)
+          {
+            std::cerr << "App_Glom::on_document_load(): unexpected error." << std::endl;
           }
-          else
-            std::cerr << "App_Glom::on_document_load(): unexpected ExceptionConnection failure type." << std::endl;
         }
 
-        if(!test) //It usually throws an exception instead of returning false.
+        if(!test)
           return false; //Failed. Close the document.
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
@@ -1075,7 +1107,7 @@ bool App_Glom::on_document_load()
           {
             // TODO: Do we need to call connection_pool->cleanup() here, for
             // stopping self-hosted databases? armin.
-            connection_pool->cleanup(this);
+            connection_pool->cleanup( sigc::mem_fun(*this, &App_Glom::on_connection_close_progress) );
             //If the database was not successfully recreated:
             if(!user_cancelled)
             {
@@ -1112,6 +1144,8 @@ bool App_Glom::on_document_load()
     //List the non-hidden tables in the menu:
     fill_menu_tables();
 
+    update_network_shared_ui();
+
 #ifndef GLOM_ENABLE_CLIENT_ONLY
     pDocument->set_allow_autosave(true);
 #endif // !GLOM_ENABLE_CLIENT_ONLY
@@ -1120,6 +1154,24 @@ bool App_Glom::on_document_load()
   }
 }
 
+void App_Glom::on_connection_close_progress()
+{
+  //TODO_murrayc
+}
+
+void App_Glom::on_document_close()
+{
+#ifndef GLOM_ENABLE_CLIENT_ONLY
+  //TODO: It would be better to do this in a Application::on_document_closed() virtual method,
+  //but that would need an ABI break in Bakery:
+  ConnectionPool* connection_pool = ConnectionPool::get_instance();
+  if(!connection_pool)
+    return;
+
+  connection_pool->cleanup( sigc::mem_fun(*this, &App_Glom::on_connection_close_progress) );
+#endif // !GLOM_ENABLE_CLIENT_ONLY
+}
+
 /*
 void App_Glom::statusbar_set_text(const Glib::ustring& strText)
 {
@@ -1139,6 +1191,30 @@ void App_Glom::on_userlevel_changed(AppState::userlevels /* userlevel */)
   update_userlevel_ui();
 }
 
+void App_Glom::update_network_shared_ui()
+{
+  Document* document = dynamic_cast<Document*>(get_document());
+  if(!document)
+    return;
+
+  //Show the status in the UI:
+  //(get_network_shared() already enforces constraints).
+  const bool shared = document->get_network_shared();
+  //TODO: Our use of block() does not seem to work. The signal actually seems to be emitted some time later instead.
+  m_connection_toggleaction_network_shared.block(); //Prevent signal handling.
+  m_toggleaction_network_shared->set_active(shared);
+ 
+  //Do not allow impossible changes:
+  const Document::HostingMode hosting_mode = document->get_hosting_mode();
+  if( (hosting_mode == Document::HOSTING_MODE_POSTGRES_CENTRAL) //Central hosting means that it must be shared on the network.
+    || (hosting_mode == Document::HOSTING_MODE_SQLITE) ) //sqlite does not allow network sharing.
+  {
+    m_toggleaction_network_shared->set_sensitive(false);
+  }
+
+  m_connection_toggleaction_network_shared.unblock();
+}
+
 void App_Glom::update_userlevel_ui()
 {
   AppState::userlevels userlevel = get_userlevel();
@@ -1184,10 +1260,10 @@ bool App_Glom::offer_new_or_existing()
 {
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
   //Offer to load an existing document, or start a new one.
-  Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom.glade"), "dialog_existing_or_new");
+  Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom.glade"), "dialog_existing_or_new");
 #else
-  std::auto_ptr<Gnome::Glade::XmlError> error;
-  Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom.glade"), "dialog_existing_or_new", "", error);
+  std::auto_ptr<Glib::Error> error;
+  Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom.glade"), "dialog_existing_or_new", "", error);
   if(error.get())
     return false;
 #endif
@@ -1233,7 +1309,7 @@ bool App_Glom::offer_new_or_existing()
       }
 
       //Check that a document was opened:
-      Document_Glom* document = dynamic_cast<Document_Glom*>(get_document());
+      Document* document = dynamic_cast<Document*>(get_document());
       if(!document->get_file_uri().empty() || (document->get_opened_from_browse()))
         ask_again = false;
     }
@@ -1260,25 +1336,25 @@ void App_Glom::existing_or_new_new()
   Glib::ustring db_title;
 
   m_ui_save_extra_showextras = true; //Offer self-hosting or central hosting, and offer the database title.
-  m_ui_save_extra_newdb_hosting_mode = Document_Glom::DEFAULT_HOSTED; /* Default to self-hosting */
+  m_ui_save_extra_newdb_hosting_mode = Document::DEFAULT_HOSTED; /* Default to self-hosting */
   m_ui_save_extra_newdb_title.clear();
   offer_saveas();
 
   //Check that the document was given a location:
-  Document_Glom* document = dynamic_cast<Document_Glom*>(get_document());
+  Document* document = dynamic_cast<Document*>(get_document());
   if(!document->get_file_uri().empty())
   {
     //Get details from the extended save dialog:
     const Glib::ustring db_title = m_ui_save_extra_newdb_title;
-    Document_Glom::HostingMode hosting_mode = m_ui_save_extra_newdb_hosting_mode;
+    Document::HostingMode hosting_mode = m_ui_save_extra_newdb_hosting_mode;
     m_ui_save_extra_newdb_title.clear();
-    m_ui_save_extra_newdb_hosting_mode = Document_Glom::DEFAULT_HOSTED;
+    m_ui_save_extra_newdb_hosting_mode = Document::DEFAULT_HOSTED;
 
     //Make sure that the user can do something with his new document:
     document->set_userlevel(AppState::USERLEVEL_DEVELOPER);
     // Try various ports if connecting to an existing database server instead
     // of self-hosting one:
-    document->set_connection_try_other_ports(m_ui_save_extra_newdb_hosting_mode == Document_Glom::DEFAULT_HOSTED);
+    document->set_connection_try_other_ports(m_ui_save_extra_newdb_hosting_mode == Document::DEFAULT_HOSTED);
 
     //Each new document must have an associated new database,
     //so choose a name
@@ -1383,7 +1459,7 @@ void App_Glom::on_menu_help_contents()
 bool App_Glom::recreate_database(bool& user_cancelled)
 {
   //Create a database, based on the information in the current document:
-  Document_Glom* pDocument = static_cast<Document_Glom*>(get_document());
+  Document* pDocument = static_cast<Document*>(get_document());
   if(!pDocument)
     return false;
 
@@ -1445,7 +1521,7 @@ bool App_Glom::recreate_database(bool& user_cancelled)
   //Show the user that something is happening, because the INSERTS might take time.
   //TOOD: This doesn't actually show up until near the end, even with Gtk::Main::instance()->iteration().
   std::auto_ptr<Dialog_ProgressCreating> dialog_progress;
-  Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom.glade"), "window_progress");
+  Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom.glade"), "window_progress");
   if(refXml)
   {
     Dialog_ProgressCreating* dialog_progress_temp = 0;
@@ -1478,7 +1554,7 @@ bool App_Glom::recreate_database(bool& user_cancelled)
     connection_pool->set_database(db_name); //Specify the new database when connecting from now on.
 
   dialog_progress->pulse();
-  Bakery::BusyCursor busy_cursor(this);
+  BusyCursor busy_cursor(this);
 
   sharedptr<SharedConnection> sharedconnection;
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
@@ -1508,14 +1584,14 @@ bool App_Glom::recreate_database(bool& user_cancelled)
   dialog_progress->pulse();
 
   //Create each table:
-  Document_Glom::type_listTableInfo tables = pDocument->get_tables();
-  for(Document_Glom::type_listTableInfo::const_iterator iter = tables.begin(); iter != tables.end(); ++iter)
+  Document::type_listTableInfo tables = pDocument->get_tables();
+  for(Document::type_listTableInfo::const_iterator iter = tables.begin(); iter != tables.end(); ++iter)
   {
     sharedptr<const TableInfo> table_info = *iter;
 
     //Create SQL to describe all fields in this table:
     Glib::ustring sql_fields;
-    Document_Glom::type_vecFields fields = pDocument->get_table_fields(table_info->get_name());
+    Document::type_vec_fields fields = pDocument->get_table_fields(table_info->get_name());
 
     dialog_progress->pulse();
     const bool table_creation_succeeded = m_pFrame->create_table(table_info, fields);
@@ -1537,7 +1613,7 @@ bool App_Glom::recreate_database(bool& user_cancelled)
   if(!test)
     return false;
 
-  for(Document_Glom::type_listTableInfo::const_iterator iter = tables.begin(); iter != tables.end(); ++iter)
+  for(Document::type_listTableInfo::const_iterator iter = tables.begin(); iter != tables.end(); ++iter)
   {
     sharedptr<const TableInfo> table_info = *iter;
 
@@ -1568,7 +1644,7 @@ bool App_Glom::recreate_database(bool& user_cancelled)
 
 AppState::userlevels App_Glom::get_userlevel() const
 {
-  const Document_Glom* document = dynamic_cast<const Document_Glom*>(get_document());
+  const Document* document = dynamic_cast<const Document*>(get_document());
   if(document)
   {
     return document->get_userlevel();
@@ -1611,7 +1687,7 @@ void App_Glom::fill_menu_tables()
   if(m_refNavTablesActionGroup)
   {
     m_refUIManager->remove_action_group(m_refNavTablesActionGroup);
-    m_refNavTablesActionGroup.clear();
+    m_refNavTablesActionGroup.reset();
   }
 
   m_refNavTablesActionGroup = Gtk::ActionGroup::create("NavTablesActions");
@@ -1627,9 +1703,9 @@ void App_Glom::fill_menu_tables()
     "      <menu action='Glom_Menu_Tables'>"
     "        <placeholder name='Menu_Tables_Dynamic'>";
 
-  Document_Glom* document = dynamic_cast<Document_Glom*>(get_document());
-  const Document_Glom::type_listTableInfo tables = document->get_tables();
-  for(Document_Glom::type_listTableInfo::const_iterator iter = tables.begin(); iter != tables.end(); ++iter)
+  Document* document = dynamic_cast<Document*>(get_document());
+  const Document::type_listTableInfo tables = document->get_tables();
+  for(Document::type_listTableInfo::const_iterator iter = tables.begin(); iter != tables.end(); ++iter)
   {
     sharedptr<const TableInfo> table_info = *iter;
     if(!table_info->m_hidden)
@@ -1700,7 +1776,7 @@ void App_Glom::fill_menu_reports(const Glib::ustring& table_name)
   if(m_refNavReportsActionGroup)
   {
     m_refUIManager->remove_action_group(m_refNavReportsActionGroup);
-    m_refNavReportsActionGroup.clear();
+    m_refNavReportsActionGroup.reset();
   }
 
   m_refNavReportsActionGroup = Gtk::ActionGroup::create("NavReportsActions");
@@ -1716,9 +1792,9 @@ void App_Glom::fill_menu_reports(const Glib::ustring& table_name)
     "     <menu action='Glom_Menu_Reports'>"
     "        <placeholder name='Menu_Reports_Dynamic'>";
 
-  Document_Glom* document = dynamic_cast<Document_Glom*>(get_document());
-  const Document_Glom::type_listReports tables = document->get_report_names(table_name);
-  for(Document_Glom::type_listReports::const_iterator iter = tables.begin(); iter != tables.end(); ++iter)
+  Document* document = dynamic_cast<Document*>(get_document());
+  const Document::type_listReports tables = document->get_report_names(table_name);
+  for(Document::type_listReports::const_iterator iter = tables.begin(); iter != tables.end(); ++iter)
   {
     sharedptr<Report> report = document->get_report(table_name, *iter);
     if(report)
@@ -1798,7 +1874,7 @@ void App_Glom::fill_menu_print_layouts(const Glib::ustring& table_name)
   if(m_refNavPrintLayoutsActionGroup)
   {
     m_refUIManager->remove_action_group(m_refNavPrintLayoutsActionGroup);
-    m_refNavPrintLayoutsActionGroup.clear();
+    m_refNavPrintLayoutsActionGroup.reset();
   }
 
   m_refNavPrintLayoutsActionGroup = Gtk::ActionGroup::create("NavPrintLayoutsActions");
@@ -1815,13 +1891,13 @@ void App_Glom::fill_menu_print_layouts(const Glib::ustring& table_name)
     "        <menu action='GlomAction_Menu_File_Print'>"
     "          <placeholder name='Menu_PrintLayouts_Dynamic'>";
 
-  Document_Glom* document = dynamic_cast<Document_Glom*>(get_document());
-  const Document_Glom::type_listPrintLayouts tables = document->get_print_layout_names(table_name);
+  Document* document = dynamic_cast<Document*>(get_document());
+  const Document::type_listPrintLayouts tables = document->get_print_layout_names(table_name);
 
   // TODO_clientonly: Should this be available in client only mode? We need to
   // depend on goocanvas in client only mode then:
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-  for(Document_Glom::type_listPrintLayouts::const_iterator iter = tables.begin(); iter != tables.end(); ++iter)
+  for(Document::type_listPrintLayouts::const_iterator iter = tables.begin(); iter != tables.end(); ++iter)
   {
     sharedptr<PrintLayout> print_layout = document->get_print_layout(table_name, *iter);
     if(print_layout)
@@ -1889,7 +1965,7 @@ void App_Glom::fill_menu_print_layouts(const Glib::ustring& table_name)
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 void App_Glom::on_menu_file_save_as_example()
 {
-  //Based on the implementation of Bakery::App_WithDoc::on_menu_file_saveas()
+  //Based on the implementation of GlomBakery::App_WithDoc::on_menu_file_saveas()
 
   //Display File Save dialog and respond to choice:
 
@@ -1898,14 +1974,14 @@ void App_Glom::on_menu_file_save_as_example()
   ui_bring_to_front();
 
   //Show the save dialog:
-  Document_Glom* document = dynamic_cast<Document_Glom*>(get_document());
+  Document* document = dynamic_cast<Document*>(get_document());
   const Glib::ustring& file_uriOld = document->get_file_uri();
 
   m_ui_save_extra_showextras = false;
   m_ui_save_extra_title.clear();
   m_ui_save_extra_message.clear();
   m_ui_save_extra_newdb_title.clear();
-  m_ui_save_extra_newdb_hosting_mode = Document_Glom::DEFAULT_HOSTED;
+  m_ui_save_extra_newdb_hosting_mode = Document::DEFAULT_HOSTED;
 
   Glib::ustring file_uri = ui_file_select_save(file_uriOld); //Also asks for overwrite confirmation.
   if(!file_uri.empty())
@@ -1930,19 +2006,19 @@ void App_Glom::on_menu_file_save_as_example()
       document->set_is_example_file();
 
       //Save all data from all tables into the document:
-      Document_Glom::type_listTableInfo list_table_info = document->get_tables();
-      for(Document_Glom::type_listTableInfo::const_iterator iter = list_table_info.begin(); iter != list_table_info.end(); ++iter)
+      Document::type_listTableInfo list_table_info = document->get_tables();
+      for(Document::type_listTableInfo::const_iterator iter = list_table_info.begin(); iter != list_table_info.end(); ++iter)
       {
         const Glib::ustring table_name = (*iter)->get_name();
 
-        //const type_vecFields vec_fields = document->get_table_fields(table_name);
+        //const type_vec_fields vec_fields = document->get_table_fields(table_name);
 
         //export_data_to_stream() needs a type_list_layout_groups;
-        Document_Glom::type_list_layout_groups sequence = document->get_data_layout_groups_default("list", table_name, "" /* layout_platform */);
+        Document::type_list_layout_groups sequence = document->get_data_layout_groups_default("list", table_name, "" /* layout_platform */);
 
         //std::cout << "debug: table_name=" << table_name << std::endl;
 
-        Document_Glom::type_example_rows example_rows;
+        Document::type_example_rows example_rows;
         FoundSet found_set;
         found_set.m_table_name = table_name;
         m_pFrame->export_data_to_vector(example_rows, found_set, sequence);
@@ -2109,7 +2185,7 @@ Glib::ustring App_Glom::ui_file_select_save(const Glib::ustring& old_file_uri) /
     
 
     //Start with something suitable:
-    Document_Glom* document = dynamic_cast<Document_Glom*>(get_document());
+    Document* document = dynamic_cast<Document*>(get_document());
     g_assert(document);
     const Glib::ustring filename = document->get_name(); //Get the filename without the path and extension.
 
@@ -2227,12 +2303,12 @@ Glib::ustring App_Glom::ui_file_select_save(const Glib::ustring& old_file_uri) /
       bool is_self_hosted = false;
 
 #ifdef GLOM_ENABLE_POSTGRESQL
-      if(m_ui_save_extra_newdb_hosting_mode == Document_Glom::HOSTING_MODE_POSTGRES_SELF)
+      if(m_ui_save_extra_newdb_hosting_mode == Document::HOSTING_MODE_POSTGRES_SELF)
         is_self_hosted = true;
 #endif //GLOM_ENABLE_POSTGRESQL
 
 #ifdef GLOM_ENABLE_SQLITE
-      if(m_ui_save_extra_newdb_hosting_mode == Document_Glom::HOSTING_MODE_SQLITE)
+      if(m_ui_save_extra_newdb_hosting_mode == Document::HOSTING_MODE_SQLITE)
         is_self_hosted = true;
 #endif // GLOM_ENABLE_SQLITE
 
@@ -2287,20 +2363,20 @@ Glib::ustring App_Glom::ui_file_select_save(const Glib::ustring& old_file_uri) /
 
 void App_Glom::stop_self_hosting_of_document_database()
 {
-  Document_Glom* pDocument = static_cast<Document_Glom*>(get_document());
+  Document* pDocument = static_cast<Document*>(get_document());
   if(pDocument)
   {
     ConnectionPool* connection_pool = ConnectionPool::get_instance();
     if(!connection_pool)
       return;
 
-    connection_pool->cleanup(this);
+    connection_pool->cleanup( sigc::mem_fun(*this, &App_Glom::on_connection_close_progress ));
   }
 }
 
 void App_Glom::on_menu_developer_changelanguage()
 {
-  Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "dialog_change_language");
+  Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "dialog_change_language");
   if(refXml)
   {
     Dialog_ChangeLanguage* dialog = 0;
@@ -2331,13 +2407,13 @@ void App_Glom::on_menu_developer_translations()
 {
   if(!m_window_translations)
   {
-    Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "window_translations");
+    Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "window_translations");
     refXml->get_widget_derived("window_translations", m_window_translations);
     if(m_window_translations)
     {
       m_pFrame->add_view(m_window_translations);
       m_window_translations->set_transient_for(*this);
-      m_window_translations->set_document(static_cast<Document_Glom*>(m_pDocument));
+      m_window_translations->set_document(static_cast<Document*>(m_pDocument));
       m_window_translations->load_from_document();
       m_window_translations->show();
 
@@ -2353,7 +2429,7 @@ void App_Glom::on_menu_developer_translations()
 
 void App_Glom::on_menu_developer_active_platform_normal()
 {
-  Document_Glom* document = dynamic_cast<Document_Glom*>(get_document());
+  Document* document = dynamic_cast<Document*>(get_document());
   if(document)
    document->set_active_layout_platform("");
 
@@ -2362,7 +2438,7 @@ void App_Glom::on_menu_developer_active_platform_normal()
 
 void App_Glom::on_menu_developer_active_platform_maemo()
 {
-  Document_Glom* document = dynamic_cast<Document_Glom*>(get_document());
+  Document* document = dynamic_cast<Document*>(get_document());
   if(document)
    document->set_active_layout_platform("maemo");
 
@@ -2401,7 +2477,7 @@ void App_Glom::document_history_add(const Glib::ustring& file_uri)
       return;
   }
 
-  Bakery::App_WithDoc_Gtk::document_history_add(file_uri);
+  GlomBakery::App_WithDoc_Gtk::document_history_add(file_uri);
 }
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
@@ -2417,12 +2493,13 @@ void App_Glom::do_menu_developer_relationships(Gtk::Window& parent, const Glib::
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-Document_Glom* App_Glom::on_connection_pool_get_document()
+Document* App_Glom::on_connection_pool_get_document()
 {
-  return dynamic_cast<Document_Glom*>(get_document());
+  return dynamic_cast<Document*>(get_document());
 }
 #endif
 
+
 } //namespace Glom
 
 
