@@ -21,12 +21,12 @@
 #ifndef GLOM_DIALOG_CONNECTION_H
 #define GLOM_DIALOG_CONNECTION_H
 
-#include <libglademm.h>
 #include <gtkmm/dialog.h>
 #include <gtkmm/entry.h>
 #include <gtkmm/label.h>
+#include <gtkmm/builder.h>
 #include "base_db.h"
-#include <glom/libglom/connectionpool.h>
+#include <libglom/connectionpool.h>
 
 namespace Glom
 {
@@ -36,7 +36,7 @@ class Dialog_Connection
     public Base_DB
 {
 public:
-  Dialog_Connection(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
+  Dialog_Connection(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
   virtual ~Dialog_Connection();
 
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
@@ -48,6 +48,12 @@ public:
   ///Disable irrelevant fields:
   void set_connect_to_browsed();
 
+  /** Change the main message text of the dialog, so we can use the dialog 
+   * to confirm that the user knows a password before disconnecting, when 
+   * switching to network sharing.
+   */
+  void set_confirm_existing_user_note();
+
   void set_username(const Glib::ustring& username);
   void set_password(const Glib::ustring& password);
   void get_username_and_password(Glib::ustring& user, Glib::ustring& password) const;
@@ -61,11 +67,12 @@ public:
    */
   void set_database_name(const Glib::ustring& name);
 
-protected:
+private:
   Gtk::Entry* m_entry_host;
   Gtk::Entry* m_entry_user;
   Gtk::Entry* m_entry_password;
   Gtk::Label* m_label_database;
+  Gtk::Label* m_label_note;
   Glib::ustring m_database_name;
 };
 
