@@ -20,18 +20,18 @@
  
 #include "dialog_database_preferences.h"
 #include "box_withbuttons.h" //For Box_WithButtons::connect_to_server().
-#include <glom/libglom/standard_table_prefs_fields.h>
-#include <glom/libglom/data_structure/glomconversions.h>
-#include <bakery/Utilities/BusyCursor.h>
+#include <libglom/standard_table_prefs_fields.h>
+#include <libglom/data_structure/glomconversions.h>
+#include <glom/bakery/busy_cursor.h>
 #include <glibmm/i18n.h>
 
 namespace Glom
 {
 
-Dialog_Database_Preferences::Dialog_Database_Preferences(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
+Dialog_Database_Preferences::Dialog_Database_Preferences(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Gtk::Dialog(cobject),
   Base_DB(),
-  m_glade_variables_map(refGlade)
+  m_glade_variables_map(builder)
 {
   m_glade_variables_map.connect_widget("entry_name", m_system_prefs.m_name);
   m_glade_variables_map.connect_widget("entry_org_name", m_system_prefs.m_org_name);
@@ -42,11 +42,11 @@ Dialog_Database_Preferences::Dialog_Database_Preferences(BaseObjectType* cobject
   m_glade_variables_map.connect_widget("entry_org_address_country", m_system_prefs.m_org_address_country);
   m_glade_variables_map.connect_widget("entry_org_address_postcode", m_system_prefs.m_org_address_postcode);
 
-  refGlade->get_widget_derived("imageglom", m_image);
-  refGlade->get_widget("button_choose_image", m_button_choose_image);
+  builder->get_widget_derived("imageglom", m_image);
+  builder->get_widget("button_choose_image", m_button_choose_image);
   m_button_choose_image->signal_clicked().connect(sigc::mem_fun(*this, &Dialog_Database_Preferences::on_button_choose_image));
 
-  refGlade->get_widget("treeview_autoincrements", m_treeview_autoincrements);
+  builder->get_widget("treeview_autoincrements", m_treeview_autoincrements);
 
   m_model_autoincrements = Gtk::ListStore::create(m_columns);
   m_treeview_autoincrements->set_model(m_model_autoincrements);
@@ -101,7 +101,7 @@ void Dialog_Database_Preferences::on_treeview_cell_edited_next_value(const Glib:
         " WHERE \"" GLOM_STANDARD_TABLE_AUTOINCREMENTS_FIELD_TABLE_NAME "\" = '" + table_name + "' AND "
                "\"" GLOM_STANDARD_TABLE_AUTOINCREMENTS_FIELD_FIELD_NAME "\" = '" + field_name +"'";
 
-    const bool test = query_execute(sql_query, this);
+    const bool test = query_execute(sql_query);
     if(!test)
       std::cerr << "Dialog_Database_Preferences::on_treeview_cell_edited_next_value(): UPDATE failed." << std::endl;
   }
@@ -117,12 +117,12 @@ void Dialog_Database_Preferences::load_from_document()
 
 
   //Make sure that all auto-increment values are setup:
-  Document_Glom* document = get_document();
-  const Document_Glom::type_listTableInfo tables = document->get_tables();
-  for(Document_Glom::type_listTableInfo::const_iterator iter = tables.begin(); iter != tables.end(); ++iter)
+  Document* document = get_document();
+  const Document::type_listTableInfo tables = document->get_tables();
+  for(Document::type_listTableInfo::const_iterator iter = tables.begin(); iter != tables.end(); ++iter)
   {
-    const Document_Glom::type_vecFields fields = document->get_table_fields((*iter)->get_name());
-    for(Document_Glom::type_vecFields::const_iterator iterFields = fields.begin(); iterFields != fields.end(); ++iterFields)
+    const Document::type_vec_fields fields = document->get_table_fields((*iter)->get_name());
+    for(Document::type_vec_fields::const_iterator iterFields = fields.begin(); iterFields != fields.end(); ++iterFields)
     {
       sharedptr<Field> field = *iterFields;
       if(field->get_primary_key())
@@ -141,7 +141,7 @@ void Dialog_Database_Preferences::load_from_document()
 
   NumericFormat numeric_format; //ignored
 
-  Glib::RefPtr<Gnome::Gda::DataModel> datamodel = query_execute_select(sql_query, this);
+  Glib::RefPtr<Gnome::Gda::DataModel> datamodel = query_execute_select(sql_query);
   if(!datamodel)
   {
     std::cerr << "Dialog_Database_Preferences::load_from_document(): Gda::DataModel is NULL." << std::endl;
@@ -178,7 +178,7 @@ int Dialog_Database_Preferences::on_autoincrements_sort(const Gtk::TreeModel::it
 
 void Dialog_Database_Preferences::save_to_document()
 {
-  Bakery::BusyCursor busy_cursor(this);
+  BusyCursor busy_cursor(this);
 
   m_glade_variables_map.transfer_widgets_to_variables();
   m_system_prefs.m_org_logo = m_image->get_value();
