@@ -32,7 +32,7 @@
 #include <gtkmm/treestore.h>
 #include <gtkmm/recentinfo.h>
 #include <gtkmm/notebook.h>
-#include <libglademm/xml.h>
+#include <gtkmm/builder.h>
 
 #ifndef G_OS_WIN32
 # include <libepc/service-monitor.h>
@@ -53,7 +53,7 @@ public:
     OPEN_REMOTE
   };
 
-  Dialog_ExistingOrNew(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
+  Dialog_ExistingOrNew(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
   virtual ~Dialog_ExistingOrNew();
 
   Action get_action() const;
@@ -134,11 +134,7 @@ private:
 #endif
 
     // For recently used resources:
-    // TODO: We can't use Glib::RefPtr<Gtk::RecentInfo> directly here, due to
-    // bug #527587. Therefore, the refptrs are dynamically allocated and
-    // explicitely freed in the destructor. This has already been fixed in
-    // gtkmm trunk and is fixed for gtkmm 2.14.
-    Gtk::TreeModelColumn<Glib::RefPtr<Gtk::RecentInfo>*> m_col_recent_info;
+    Gtk::TreeModelColumn< Glib::RefPtr<Gtk::RecentInfo> > m_col_recent_info;
   };
   
   class NewModelColumns : public Gtk::TreeModel::ColumnRecord
