@@ -18,14 +18,15 @@
  * Boston, MA 02111-1307, USA.
  */
  
-#include "dialog_glom.h"
+#include <glom/dialog_glom.h>
+#include <glom/utils_ui.h>
 
 namespace Glom
 {
 
-Dialog_Glom::Dialog_Glom(Box_DB* pBox)
+Dialog_Glom::Dialog_Glom(Box_WithButtons* pBox)
 {
-  set_border_width(Glom::Utils::DEFAULT_SPACING_SMALL);
+  set_border_width(Utils::DEFAULT_SPACING_SMALL);
 
   m_pBox = pBox;
 
