@@ -24,8 +24,9 @@
 #include <libglom/libglom_config.h> // For GLOM_ENABLE_CLIENT_ONLY
 
 #include <gtkmm/frame.h>
-#include "bakery/View/View_Composite.h"
-#include <libglom/document/document_glom.h>
+#include <gtkmm/toggleaction.h>
+#include <libglom/document/bakery/view/view_composite.h>
+#include <libglom/document/document.h>
 
 #include "dialog_glom.h"
 #include "navigation/box_tables.h"
@@ -52,15 +53,16 @@ class Dialog_Layout_Report;
 class Window_PrintLayout_Edit;
 class Dialog_AddRelatedTable;
 class Dialog_RelationshipsOverview;
+class Dialog_ProgressCreating;
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
 class Frame_Glom :
   public PlaceHolder,
-  //public Bakery::View_Composite<Document_Glom>,
+  //public GlomBakery::View_Composite<Document>,
   public Base_DB //Inherits from View_Composite.
 {
 public: 
-  Frame_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
+  Frame_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
   virtual ~Frame_Glom();
 
   void set_databases_selected(const Glib::ustring& strName);
@@ -76,8 +78,9 @@ public:
   void on_menu_file_export();
   void on_menu_file_import();
   void on_menu_file_print_edit_layouts();
-
 #endif // !GLOM_ENABLE_CLIENT_ONLY
+
+  void on_menu_file_toggle_share(const Glib::RefPtr<Gtk::ToggleAction>& action);
   void on_menu_file_print();
 
   void on_menu_Mode_Data();
@@ -127,7 +130,7 @@ public:
 
   void on_dialog_tables_hide();
 
-  virtual void set_document(Document_Glom* pDocument); //View override
+  virtual void set_document(Document* pDocument); //View override
   virtual void load_from_document(); //View override
 
   enum enumModes
@@ -141,25 +144,28 @@ public:
 
   static void show_ok_dialog(const Glib::ustring& title, const Glib::ustring& message, Gtk::Window& parent, Gtk::MessageType message_type = Gtk::MESSAGE_INFO);
 
-  //Show the dialog to request the password, and check whether it works.
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-  bool connection_request_password_and_attempt(const Glib::ustring known_username = Glib::ustring(), const Glib::ustring& known_password = Glib::ustring());
-#else
-  bool connection_request_password_and_attempt(const Glib::ustring known_username = Glib::ustring(), const Glib::ustring& known_password = Glib::ustring(), std::auto_ptr<ExceptionConnection>& error);
-#endif
+  /** Show the dialog to request the password, and check whether it works.
+   *
+   * @param database_not_found true if the connection failed only because the database was not found on the server.
+   * @param known_username The username if known. Otherwise, the user will be asked via a dialog.
+   * @param known_password The password if known. Otherwise, the user will be asked via a dialog.
+   * @param confirm_existing_user If true then an alternative message text will be shown.
+   * @result true if the connection succeeded and the database was found on the server.
+   */
+  bool connection_request_password_and_attempt(bool& database_not_found, const Glib::ustring known_username = Glib::ustring(), const Glib::ustring& known_password = Glib::ustring(), bool confirm_existing_user = false);
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   //Show the dialog to request the password, and choose an unused database name.
   bool connection_request_password_and_choose_new_database_name();
 
-#ifndef GLOM_ENABLE_CLIENT_ONLY
   ///Create the database for new documents, showing the Connection dialog
   bool create_database(const Glib::ustring& database_name, const Glib::ustring& title);
   void show_layout_toolbar(bool show = true);
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-  void export_data_to_vector(Document_Glom::type_example_rows& the_vector, const FoundSet& found_set, const Document_Glom::type_list_layout_groups& sequence);
-  void export_data_to_string(Glib::ustring& the_string, const FoundSet& found_set, const Document_Glom::type_list_layout_groups& sequence);
-  void export_data_to_stream(std::ostream& the_stream, const FoundSet& found_set, const Document_Glom::type_list_layout_groups& sequence);
+  void export_data_to_vector(Document::type_example_rows& the_vector, const FoundSet& found_set, const Document::type_list_layout_groups& sequence);
+  void export_data_to_string(Glib::ustring& the_string, const FoundSet& found_set, const Document::type_list_layout_groups& sequence);
+  void export_data_to_stream(std::ostream& the_stream, const FoundSet& found_set, const Document::type_list_layout_groups& sequence);
 
   /** Show the table again. For instance, if the document has changed, or we want to display it differently.
    */
@@ -170,7 +176,9 @@ public:
 
 protected:
 
-  //virtual void set_document(Document_Glom* pDocument); //override
+  
+
+  //virtual void set_document(Document* pDocument); //override
 
   /** Show the table, possibly selecting a particular record, possibly showing that in the details tab. This allows table_name to be empty in which case no
    * table will be shown.
@@ -192,9 +200,13 @@ protected:
   void show_no_table();
 
   void show_table_title();
+
 #ifndef GLOM_ENABLE_CLIENT_ONLY
+  bool connection_request_initial_password(Glib::ustring& user, Glib::ustring& password);
+
   void update_table_in_document_from_database();
 #endif // !GLOM_ENABLE_CLIENT_ONLY
+
   virtual void set_mode_widget(Gtk::Widget& widget); //e.g. show the design mode notebook.
   virtual bool set_mode(enumModes mode); //bool indicates that there was a change.
 
@@ -217,6 +229,12 @@ protected:
   void on_dialog_add_related_table_response(int response);
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
+  void on_connection_initialize_progress();
+  void on_connection_startup_progress();
+  void on_connection_cleanup_progress();
+  void cleanup_connection();
+  bool handle_connection_initialize_errors(ConnectionPool::InitErrors error);
+  
   //Member data:
   Glib::ustring m_table_name;
 
@@ -259,10 +277,13 @@ protected:
   Dialog_Relationships* m_pDialog_Relationships;
   Dialog_AddRelatedTable* m_dialog_addrelatedtable;
   Dialog_RelationshipsOverview* m_dialog_relationships_overview;
-  
+    
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
   Dialog_Connection* m_pDialogConnection;
+  Dialog_ProgressCreating* m_dialog_progess_connection_initialize;
+  Dialog_ProgressCreating* m_dialog_progess_connection_startup;
+  Dialog_ProgressCreating* m_dialog_progess_connection_cleanup;
 };
 
 } //namespace Glom
