@@ -23,7 +23,7 @@
 
 #include <gtkmm.h>
 #include "../utility_widgets/dialog_properties.h"
-#include <libglom/document/document_glom.h>
+#include <libglom/document/document.h>
 #include "../box_withbuttons.h"
 #include "../utility_widgets/combo_textglade.h"
 #include "../utility_widgets/comboentry_currency.h"
@@ -39,7 +39,7 @@ class Dialog_GroupBy
    public Base_DB
 {
 public:
-  Dialog_GroupBy(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
+  Dialog_GroupBy(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
   virtual ~Dialog_GroupBy();
 
   /**
