@@ -41,7 +41,6 @@ typedef struct _EpcAuthContext EpcAuthContext;
 
 namespace Gtk
 {
-  class Window;
   class Dialog;
 }
 
@@ -77,7 +76,7 @@ private:
   type_signal_finished m_signal_finished;
 };
 
-class Document_Glom;
+class Document;
 
 /** This is a singleton.
  * Use get_instance().
@@ -89,10 +88,10 @@ private:
   //ConnectionPool(const ConnectionPool& src);
   virtual ~ConnectionPool();
   //ConnectionPool& operator=(const ConnectionPool& src);
-
+  
 public:
   typedef ConnectionPoolBackends::Backend Backend;
-  typedef Backend::type_vecConstFields type_vecConstFields;
+  typedef Backend::type_vec_const_fields type_vec_const_fields;
 
   /** Get the singleton instance.
    * Use delete_instance() when the program quits.
@@ -101,6 +100,18 @@ public:
 
   /// Delete the singleton so it doesn't show up as leaked memory in, for instance, valgrind.
   static void delete_instance();
+  
+  typedef sigc::slot<void> type_void_slot;
+  
+  /** Set callbacks that will be called to show UI while starting to advertise 
+   * on the network via Avahi.
+   *
+   * @param slot_begin Show an explanatory message.
+   * @param slot_progress Show a pulse progress and/or keep the UI updating.
+   * @param slot_done Stop showing the message.
+   */ 
+  void set_avahi_publish_callbacks(const type_void_slot& slot_begin, const type_void_slot& slot_progress, const type_void_slot& slot_done);
+  
 
   bool get_ready_to_connect() const;
   void set_ready_to_connect(bool val = true);
@@ -150,22 +161,51 @@ public:
   const FieldTypes* get_field_types() const;
   Glib::ustring get_string_find_operator() const;
 
+  /** This callback should show UI to indicate that work is still happening.
+   * For instance, a pulsing ProgressBar.
+   */
+  typedef Backend::SlotProgress SlotProgress;
+ 
+  typedef Backend::InitErrors InitErrors;
+  
   /** Do one-time initialization, such as  creating required database
    * files on disk for later use by their own  database server instance.
+   *
+   * @param slot_progress A callback to call while the work is still happening.
+   * @param network_shared Whether the database (and document) should be available to other users over the network, 
+   * if possible. 
    * @param parent_window A parent window to use as the transient window when displaying errors.
    */
-  bool initialize(Gtk::Window* parent_window);
+  InitErrors initialize(const SlotProgress& slot_progress, bool network_shared = false);
 
   /** Start a database server instance for the exisiting database files.
+   *
+   * @param slot_progress A callback to call while the work is still happening.
+   * @param network_shared Whether the database (and document) should be available to other users over the network, 
+   * if possible. 
    * @param parent_window The parent window (transient for) of any dialogs shown during this operation.
    * @result Whether the operation was successful.
    */
-  bool startup(Gtk::Window* parent_window);
+  bool startup(const SlotProgress& slot_progress, bool network_shared = false);
 
   /** Stop the database server instance for the database files.
+   *
+   * @param slot_progress A callback to call while the work is still happening.
    * @param parent_window The parent window (transient for) of any dialogs shown during this operation.
    */
-  void cleanup(Gtk::Window* parent_window);
+  void cleanup(const SlotProgress& slot_progress);
+
+  /** Change the database server's configration to allow or prevent access from 
+   * other users on the network.
+   *
+   * For current backends, you may use this only before startup(), 
+   * or after cleanup().
+   *
+   * @param slot_progress A callback to call while the work is still happening.
+   * @param network_shared Whether the database (and document) should be available to other users over the network, 
+   * if possible. 
+   */
+  virtual bool set_network_shared(const SlotProgress& slot_progress, bool network_shared = true);
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
@@ -187,9 +227,9 @@ public:
 #endif
 
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
-  bool change_columns(const Glib::ustring& table_name, const type_vecConstFields& old_fields, const type_vecConstFields& fields);
+  bool change_columns(const Glib::ustring& table_name, const type_vec_const_fields& old_fields, const type_vec_const_fields& fields);
 #else
-  bool change_columns(const Glib::ustring& table_name, const type_vecConstFields& old_fields, const type_vecConstFields& fields, std::auto_ptr<Glib::Error>& error);
+  bool change_columns(const Glib::ustring& table_name, const type_vec_const_fields& old_fields, const type_vec_const_fields& fields, std::auto_ptr<Glib::Error>& error);
 #endif
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
@@ -197,7 +237,7 @@ public:
    * This callback avoids Connection having to link to App_Glom,
    * and avoids us worrying about whether a previously-set document (via a set_document() method) is still valid.
    */ 
-  typedef sigc::slot<Document_Glom*> SlotGetDocument; 
+  typedef sigc::slot<Document*> SlotGetDocument; 
   void set_get_document_func(const SlotGetDocument& slot);
 
 #ifndef G_OS_WIN32
@@ -210,23 +250,23 @@ public:
 #endif // !G_OS_WIN32
 
   //Show the gda error in a dialog.
-  static bool handle_error(bool cerr_only = false);
-
-  /** Postgres can't be started as root. initdb complains.
-   * So just prevent this in general. It is safer anyway.
-   */
-  static bool check_user_is_not_root();
+  static bool handle_error_cerr_only();
 
 private:
   void on_sharedconnection_finished();
 
+  /** We call this when we know that the current connection will no longer work, 
+   * for instance after we have stopped the server.
+   */
+  void invalidate_connection();
+
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   /** Examine ports one by one, starting at @a starting_port, in increasing order,
    * and return the first one that is available.
    */
   //static int discover_first_free_port(int start_port, int end_port);
 
-  Document_Glom* get_document();
+  Document* get_document();
 
 #ifndef G_OS_WIN32
   /** Advertize self-hosting via avahi:
@@ -257,6 +297,8 @@ private:
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   SlotGetDocument m_slot_get_document;
 #endif
+
+  type_void_slot m_epc_slot_begin, m_epc_slot_progress, m_epc_slot_done;
 };
 
 } //namespace Glom
