@@ -45,18 +45,24 @@ ExceptionConnection::failure_type ExceptionConnection::get_failure_type() const
 namespace ConnectionPoolBackends
 {
 
-bool Backend::initialize(Gtk::Window* /* parent_window */, const Glib::ustring& /* initial_username */, const Glib::ustring& /* password */)
+Backend::InitErrors Backend::initialize(const SlotProgress& /* slot_progress */, const Glib::ustring& /* initial_username */, const Glib::ustring& /* password */, bool /* network_shared */)
+{
+  return INITERROR_NONE;
+}
+
+bool Backend::startup(const SlotProgress& /* slot_progress */, bool /* network_shared */)
 {
   return true;
 }
 
-bool Backend::startup(Gtk::Window* /* parent_window */)
+void Backend::cleanup(const SlotProgress& /* slot_progress */)
 {
-  return true;
 }
 
-void Backend::cleanup(Gtk::Window* /* parent_window */)
-{}
+bool Backend::set_network_shared(const SlotProgress& /* slot_progress */, bool /* network_shared */)
+{
+  return true; //Success at doing nothing.
+}
 
 bool Backend::set_server_operation_value(const Glib::RefPtr<Gnome::Gda::ServerOperation>& operation, const Glib::ustring& path, const Glib::ustring& value, std::auto_ptr<Glib::Error>& error)
 {
@@ -237,7 +243,7 @@ bool Backend::drop_column(const Glib::RefPtr<Gnome::Gda::Connection>& connection
 //operations at once, maybe optimizing them. For example, for SQLite we need
 //to recreate the whole table when changing columns, so we only need to do
 //this once instead of twice when changing the primary key. armin.
-bool Backend::change_columns(const Glib::RefPtr<Gnome::Gda::Connection>& connection, const Glib::ustring& table_name, const type_vecConstFields& old_fields, const type_vecConstFields& new_fields, std::auto_ptr<Glib::Error>& error)
+bool Backend::change_columns(const Glib::RefPtr<Gnome::Gda::Connection>& connection, const Glib::ustring& table_name, const type_vec_const_fields& old_fields, const type_vec_const_fields& new_fields, std::auto_ptr<Glib::Error>& error)
 {
   static const char* TRANSACTION_NAME = "glom_change_columns_transaction";
   static const gchar* TEMP_COLUMN_NAME = "glom_temp_column"; // TODO: Find a unique name.
