@@ -26,8 +26,6 @@
 #include <libglom/sharedptr.h>
 #include <libglom/data_structure/field.h>
 
-#include <gtkmm/window.h>
-
 #include <memory>
 
 namespace Glom
@@ -41,7 +39,8 @@ public:
   enum failure_type
   {
     FAILURE_NO_SERVER, //Either there was no attempt to connect to a specific database, or the connection failed both with and without specifying the database.
-    FAILURE_NO_DATABASE //Connection without specifying the database was possible.
+    FAILURE_NO_DATABASE, //Connection without specifying the database was possible.
+    FAILURE_NO_BACKEND //No backend instance available. Should never happen.
   };
 
   ExceptionConnection(failure_type failure);
@@ -67,8 +66,17 @@ class Backend
   friend class Glom::ConnectionPool;
 public:
   virtual ~Backend() {}
-  typedef std::vector<sharedptr<const Field> > type_vecConstFields;
+  typedef std::vector<sharedptr<const Field> > type_vec_const_fields;
 
+  enum InitErrors
+  {
+     INITERROR_NONE,
+     INITERROR_DIRECTORY_ALREADY_EXISTS,
+     INITERROR_COULD_NOT_CREATE_DIRECTORY,
+     INITERROR_COULD_NOT_START_SERVER,
+     INITERROR_OTHER
+  };
+  
 protected:
   /** Helper functions for backend implementations to use, so that these don't
    * need to worry whether glibmm was compiled with exceptions or not.
@@ -101,30 +109,66 @@ protected:
    */
   virtual Glib::ustring get_string_find_operator() const = 0;
 
-  /** This method is called for one-time initialization of the database
-   * storage. No need to implement this function if the data is centrally
-   * hosted, not managed by Glom.
+  /** This specifies the database schema which contains the non-internal
+   * tables. This is used to speedup the libgda meta store update by only
+   * updating the non-internal tables. libgda might later be able to do this
+   * without us specifying it explicitely. See #575235.
    */
-  virtual bool initialize(Gtk::Window* parent_window, const Glib::ustring& initial_username, const Glib::ustring& password);
+  virtual const char* get_public_schema_name() const = 0;
+
+  /** This callback should show UI to indicate that work is still happening.
+   * For instance, a pulsing ProgressBar.
+   */
+  typedef sigc::slot<void> SlotProgress;
+  
+  /** This method is called for one-time initialization of the database
+   * storage. There is no need to implement this function if the data is centrally
+   * hosted rather than hosted by Glom.
+   *
+   * @param slot_progress A callback to call while the work is still happening.
+   * @param network_shared Whether the database (and document) should be available to other users over the network, 
+   * if possible. 
+   */
+  virtual InitErrors initialize(const SlotProgress& slot_progress, const Glib::ustring& initial_username, const Glib::ustring& password, bool network_shared = false);
 
   /** This method is called before the backend is used otherwise. This can
    * be used to start a self-hosted database server. There is no need to implement
    * this function if there is no need for extra startup code.
+   *
+   * @param slot_progress A callback to call while the work is still happening.
+   * @param network_shared Whether the database (and document) should be available to other users over the network, 
+   * if possible. 
    */
-  virtual bool startup(Gtk::Window* parent_window);
+  virtual bool startup(const SlotProgress& slot_progress, bool network_shared = false);
 
   /** This method is called when the backend is no longer used. This can be
    * used to shut down a self-hosted database server. There is no need to
    * implement this function if there is no need for extra cleanup code.
+   *
+   * @param slot_progress A callback to call while the work is still happening.
    */
-  virtual void cleanup(Gtk::Window* parent_window);
+  virtual void cleanup(const SlotProgress& slot_progress);
+
+  /** Change the database server's configration to allow or prevent access from 
+   * other users on the network.
+   *
+   * For current backends, you may use this only before startup(), 
+   * or after cleanup().
+   *
+   * @param slot_progress A callback to call while the work is still happening.
+   * @param network_shared Whether the database (and document) should be available to other users over the network, 
+   * if possible. 
+   */
+  virtual bool set_network_shared(const SlotProgress& slot_progress, bool network_shared = true);
 
   /** This method is called to create a connection to the database server.
    * There exists only the variant with an error variable as last parameter
    * so we don't need #ifdefs all over the code. This part of the API is only
    * used by the ConnectionPool which will translate the error back into
    * an exception in case exceptions are enabled.
-    */
+   * If this method doesn't return a connection handle then error will be
+   * non-zero (and vice versa).
+   */
   virtual Glib::RefPtr<Gnome::Gda::Connection> connect(const Glib::ustring& database, const Glib::ustring& username, const Glib::ustring& password, std::auto_ptr<ExceptionConnection>& error) = 0;
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
@@ -132,7 +176,7 @@ protected:
 
   virtual bool drop_column(const Glib::RefPtr<Gnome::Gda::Connection>& connection, const Glib::ustring& table_name, const Glib::ustring& field_name, std::auto_ptr<Glib::Error>& error);
 
-  virtual bool change_columns(const Glib::RefPtr<Gnome::Gda::Connection>& connection, const Glib::ustring& table_name, const type_vecConstFields& old_fields, const type_vecConstFields& new_fields, std::auto_ptr<Glib::Error>& error);
+  virtual bool change_columns(const Glib::RefPtr<Gnome::Gda::Connection>& connection, const Glib::ustring& table_name, const type_vec_const_fields& old_fields, const type_vec_const_fields& new_fields, std::auto_ptr<Glib::Error>& error);
 
   /** This method is called to create a new database on the
    * database server. */
