@@ -23,27 +23,22 @@
 #include <libglom/connectionpool_backends/postgres.h>
 #include <libglom/utils.h>
 #include <glibmm/i18n.h>
-#include <bakery/bakery.h>
-
-#ifdef GLOM_ENABLE_MAEMO
-# include <hildonmm/note.h>
-#else
-# include <gtkmm/messagedialog.h>
-#endif
-
 
 // Uncomment to see debug messages
-// #define GLOM_CONNECTION_DEBUG
+//#define GLOM_CONNECTION_DEBUG
 
 namespace
 {
 
 static Glib::ustring create_auth_string(const Glib::ustring& username, const Glib::ustring& password)
 {
-  return "USERNAME=" + username + ";PASSWORD=" + password;
+  if(username.empty() and password.empty())
+    return Glib::ustring();
+  else
+    return "USERNAME=" + username + ";PASSWORD=" + password; //TODO: How should we quote and escape these?
 }
 
-}
+} //anonymous namespace
 
 namespace Glom
 {
@@ -79,10 +74,16 @@ Glib::RefPtr<Gnome::Gda::Connection> Postgres::attempt_connect(const Glib::ustri
   Glib::RefPtr<Gnome::Gda::Connection> connection;
   Glib::RefPtr<Gnome::Gda::DataModel> data_model;
 
+  const Glib::ustring auth_string = create_auth_string(username, password);   
+ 
+#ifdef GLOM_CONNECTION_DEBUG
+  std::cout << "DEBUG: ConnectionPoolBackends::Postgres::attempt_connect(): cnc_string=" << cnc_string << std::endl;
+  std::cout << "  DEBUG: auth_string=" << auth_string << std::endl;
+#endif
+
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
-    Glib::ustring auth_string = create_auth_string(username, password);
     connection = Gnome::Gda::Connection::open_from_string("PostgreSQL", cnc_string, auth_string);
     
     connection->statement_execute_non_select("SET DATESTYLE = 'ISO'");
@@ -92,14 +93,13 @@ Glib::RefPtr<Gnome::Gda::Connection> Postgres::attempt_connect(const Glib::ustri
   {
 #else
   std::auto_ptr<Glib::Error> error;
-  Glib::ustring auth_string = create_auth_string(username, password);
   connection = Gnome::Gda::Connection::open_from_string("PostgreSQL", cnc_string, auth_string, Gnome::Gda::CONNECTION_OPTIONS_NONE, error);
   
   if(!error)
-      connection->statement_execute_non_select("SET DATESTYLE = 'ISO'", error);
+    connection->statement_execute_non_select("SET DATESTYLE = 'ISO'", error);
 
   if(!error)
-      data_model = connection->statement_execute_select("SELECT version()", error);
+    data_model = connection->statement_execute_select("SELECT version()", error);
 
   if(glib_error.get())
   {
@@ -107,8 +107,8 @@ Glib::RefPtr<Gnome::Gda::Connection> Postgres::attempt_connect(const Glib::ustri
 #endif
 
 #ifdef GLOM_CONNECTION_DEBUG
-    std::cout << "ConnectionPoolBackends::PostgresCentralHosted::attempt_connect(): Attempt to connect to database failed on port=" << port << ", database=" << database << ": " << ex.what() << std::endl;
-    std::cout << "ConnectionPoolBackends::PostgresCentralHosted::attempt_connect(): Attempting to connect without specifying the database." << std::endl;
+    std::cout << "ConnectionPoolBackends::Postgres::attempt_connect(): Attempt to connect to database failed on port=" << port << ", database=" << database << ": " << ex.what() << std::endl;
+    std::cout << "ConnectionPoolBackends::Postgres::attempt_connect(): Attempting to connect without specifying the database." << std::endl;
 #endif
 
     Glib::ustring cnc_string = cnc_string_main + ";DB_NAME=" + default_database;
@@ -159,7 +159,7 @@ Glib::RefPtr<Gnome::Gda::Connection> Postgres::attempt_connect(const Glib::ustri
 }
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-bool Postgres::change_columns(const Glib::RefPtr<Gnome::Gda::Connection>& connection, const Glib::ustring& table_name, const type_vecConstFields& old_fields, const type_vecConstFields& new_fields, std::auto_ptr<Glib::Error>& error)
+bool Postgres::change_columns(const Glib::RefPtr<Gnome::Gda::Connection>& connection, const Glib::ustring& table_name, const type_vec_const_fields& old_fields, const type_vec_const_fields& new_fields, std::auto_ptr<Glib::Error>& error)
 {
   static const char* TRANSACTION_NAME = "glom_change_columns_transaction";
   static const gchar* TEMP_COLUMN_NAME = "glom_temp_column"; // TODO: Find a unique name.
@@ -427,39 +427,30 @@ bool Postgres::attempt_create_database(const Glib::ustring& database_name, const
 }
 #endif
 
-bool Postgres::check_postgres_gda_client_is_available_with_warning()
+bool Postgres::check_postgres_gda_client_is_available()
 {
   //This API is horrible.
   //See libgda bug http://bugzilla.gnome.org/show_bug.cgi?id=575754
   Glib::RefPtr<Gnome::Gda::DataModel> model = Gnome::Gda::Config::list_providers();
-  if(!model)
-    return false;
-
-  Glib::RefPtr<Gnome::Gda::DataModelIter> iter = model->create_iter();
-
-  do
+  if(model && model->get_n_columns() && model->get_n_rows())
   {
-    //See http://library.gnome.org/devel/libgda/unstable/libgda-40-Configuration.html#gda-config-list-providers
-    //about the columns of this DataModel:
-    const Gnome::Gda::Value name = iter->get_value_at(0);
-    const Glib::ustring name_as_string = name.get_string();
-    //std::cout << "DEBUG: Provider name:" << name_as_string << std::endl;
-    if(name_as_string == "PostgreSQL")
-      return true;
+    Glib::RefPtr<Gnome::Gda::DataModelIter> iter = model->create_iter();
+
+    do
+    {
+      //See http://library.gnome.org/devel/libgda/unstable/libgda-40-Configuration.html#gda-config-list-providers
+      //about the columns of this DataModel:
+      const Gnome::Gda::Value name = iter->get_value_at(0);
+      if(name.get_value_type() != G_TYPE_STRING)
+        continue;
+
+      const Glib::ustring name_as_string = name.get_string();
+      //std::cout << "DEBUG: Provider name:" << name_as_string << std::endl;
+      if(name_as_string == "PostgreSQL")
+        return true;
+    }
+    while(iter->move_next());
   }
-  while(iter->move_next());
-
-
-  const Glib::ustring message = _("Your installation of Glom is not complete, because the PostgreSQL libgda provider is not available on your system. This provider is needed to access Postgres database servers.\n\nPlease report this bug to your vendor, or your system administrator so it can be corrected.");
-#ifndef GLOM_ENABLE_MAEMO
-  /* The Postgres provider was not found, so warn the user: */
-  Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("Incomplete Glom Installation")), true /* use_markup */, Gtk::MESSAGE_ERROR, Gtk::BUTTONS_OK, true /* modal */);
-  dialog.set_secondary_text(message);
-  dialog.run();
-#else
-  Hildon::Note note(Hildon::NOTE_TYPE_INFORMATION, message);
-  note.run();
-#endif
 
   return false;
 }
