@@ -18,17 +18,17 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include "config.h" // For POSTGRES_UTILS_PATH
+#include <config.h> // For POSTGRES_UTILS_PATH
 
 #include <libglom/connectionpool_backends/postgres_self.h>
 #include <libglom/utils.h>
 #include <libglom/spawn_with_feedback.h>
+#include <giomm.h>
 #include <glib/gstdio.h> // For g_remove
 
-#include <bakery/bakery.h>
 #include <glibmm/i18n.h>
 
-#include "../gst-package.h"
+#include <libglom/gst-package.h>
 
 #ifndef G_OS_WIN32
 #include <sys/types.h>
@@ -66,7 +66,50 @@ static Glib::ustring port_as_string(int port_num)
   return result;
 }
 
-static std::string get_path_to_postgres_executable(const std::string& program)
+} // anonymous namespace
+
+namespace Glom
+{
+
+namespace ConnectionPoolBackends
+{
+
+//TODO: Do we need these sameuser lines?
+#define DEFAULT_CONFIG_PG_HBA_LOCAL \
+"# TYPE  DATABASE    USER        CIDR-ADDRESS          METHOD\n\
+\n\
+# local is for Unix domain socket connections only\n\
+# trust allows connection from the current PC without a password:\n\
+local   all         all                               trust\n\
+local   all         all                               ident sameuser\n\
+local   all         all                               md5\n\
+\n\
+# TCP connections from the same computer, with a password:\n\
+host    all         all         127.0.0.1    255.255.255.255    md5\n\
+# IPv6 local connections:\n\
+host    all         all         ::1/128               md5\n"
+
+#define DEFAULT_CONFIG_PG_HBA_REMOTE \
+"DEFAULT_CONFIG_PG_HBA_LOCAL \
+\n\
+# IPv4 local connections:\n\
+host    all         all         0.0.0.0/0          md5\n\
+# IPv6 local connections:\n\
+host    all         all         ::1/128               md5\n"
+
+#define PORT_POSTGRESQL_SELF_HOSTED_START 5433
+#define PORT_POSTGRESQL_SELF_HOSTED_END 5500
+
+#define DEFAULT_CONFIG_PG_IDENT ""
+
+PostgresSelfHosted::PostgresSelfHosted()
+: m_port(0),
+   m_network_shared(false)
+{
+}
+
+
+std::string PostgresSelfHosted::get_path_to_postgres_executable(const std::string& program)
 {
 #ifdef G_OS_WIN32
   // Add the .exe extension on Windows:
@@ -91,35 +134,6 @@ static std::string get_path_to_postgres_executable(const std::string& program)
 #else // G_OS_WIN32
   return Glib::build_filename(POSTGRES_UTILS_PATH, program + EXEEXT);
 #endif // !G_OS_WIN32
-  }
-} // anonymous namespace
-
-namespace Glom
-{
-
-namespace ConnectionPoolBackends
-{
-
-#define DEFAULT_CONFIG_PG_HBA "local   all         postgres                          ident sameuser\n\
-\n\
-# TYPE  DATABASE    USER        CIDR-ADDRESS          METHOD\n\
-\n\
-# local is for Unix domain socket connections only\n\
-local   all         all                               ident sameuser\n\
-# IPv4 local connections:\n\
-host    all         all         0.0.0.0/0          md5\n\
-# IPv6 local connections:\n\
-host    all         all         ::1/128               md5\n"
-
-#define PORT_POSTGRESQL_SELF_HOSTED_START 5433
-#define PORT_POSTGRESQL_SELF_HOSTED_END 5500
-
-#define DEFAULT_CONFIG_PG_IDENT ""
-
-PostgresSelfHosted::PostgresSelfHosted()
-:
-  m_port(0)
-{
 }
 
 void PostgresSelfHosted::set_self_hosting_data_uri(const std::string& data_uri)
@@ -142,59 +156,10 @@ int PostgresSelfHosted::get_port() const
   return m_port;
 }
 
-// Message to packagers:
-// If your Glom package does not depend on PostgreSQL, for some reason, 
-// then your distro-specific patch should uncomment this #define.
-// and implement ConnectionPool::install_posgres().
-// But please, just make your Glom package depend on PostgreSQL instead, 
-// because this is silly.
-//
-//#define DISTRO_SPECIFIC_POSTGRES_INSTALL_IMPLEMENTED 1
-
-bool PostgresSelfHosted::check_postgres_is_available_with_warning()
-{
-  //EXEEXT is defined in the Makefile.am
-  const std::string binpath = get_path_to_postgres_executable("postgres");
-
-  // TODO: At least on Windows we should probably also check for initdb and
-  // pg_ctl. Perhaps it would also be a good idea to access these files as
-  // long as glom runs so they cannot be (re)moved.
-  if(!binpath.empty())
-  {
-    const Glib::ustring uri_binpath = Glib::filename_to_uri(binpath);
-    if(Bakery::App_WithDoc::file_exists(uri_binpath))
-      return true;
-  }
-
-  #ifdef DISTRO_SPECIFIC_POSTGRES_INSTALL_IMPLEMENTED
-
-  //Show message to the user about the broken installation:
-  //This is a packaging bug, but it would probably annoy packagers to mention that in the dialog:
-  Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("Incomplete Glom Installation")), true /* use_markup */, Gtk::MESSAGE_ERROR, Gtk::BUTTONS_NONE, true /* modal */);
-  dialog.set_secondary_text(_("Your installation of Glom is not complete, because PostgreSQL is not available on your system. PostgreSQL is needed for self-hosting of Glom databases.\n\nYou may now install PostgreSQL to complete the Glom installation."));
-  dialog.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
-  dialog.add_button(_("Install PostgreSQL"), Gtk::RESPONSE_OK);
-  const int response = dialog.run();
-  if(response != Gtk::RESPONSE_OK)
-    return false; //Failure. Glom should now quit.
-  else
-    return install_postgres(&dialog);
-
-  #else  //DISTRO_SPECIFIC_POSTGRES_INSTALL_IMPLEMENTED
-
-  //Show message to the user about the broken installation:
-  Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("Incomplete Glom Installation")), true /* use_markup */, Gtk::MESSAGE_ERROR, Gtk::BUTTONS_OK, true /* modal */);
-  dialog.set_secondary_text(_("Your installation of Glom is not complete, because PostgreSQL is not available on your system. PostgreSQL is needed for self-hosting of Glom databases.\n\nPlease report this bug to your vendor, or your system administrator so it can be corrected."));
-  dialog.run();
-  return false;
-
-  #endif //DISTRO_SPECIFIC_POSTGRES_INSTALL_IMPLEMENTED
-}
-
 /** Try to install postgres on the distro, though this will require a
  * distro-specific patch to the implementation.
  */
-bool PostgresSelfHosted::install_postgres(Gtk::Window* /* parent_window */)
+bool PostgresSelfHosted::install_postgres(const SlotProgress& /* slot_progress */)
 {
 #if 0
   // This  is example code for Ubuntu, and possibly Debian,
@@ -229,12 +194,20 @@ bool PostgresSelfHosted::install_postgres(Gtk::Window* /* parent_window */)
 #endif // #if 0
 }
 
-bool PostgresSelfHosted::initialize(Gtk::Window* parent_window, const Glib::ustring& initial_username, const Glib::ustring& password)
+Backend::InitErrors PostgresSelfHosted::initialize(const SlotProgress& slot_progress, const Glib::ustring& initial_username, const Glib::ustring& password, bool network_shared)
 {
+  m_network_shared = network_shared;
+
   if(m_self_hosting_data_uri.empty())
   {
     std::cerr << "PostgresSelfHosted::initialize: m_self_hosting_data_uri is empty." << std::endl;
-    return false;
+    return INITERROR_OTHER;
+  }
+  
+  if(initial_username.empty())
+  {
+    std::cerr << "PostgresSelfHosted::initialize(). Username was empty while attempting to create self-hosting database" << std::endl;
+    return INITERROR_OTHER;
   }
 
   //Get the filepath of the directory that we should create:
@@ -242,14 +215,7 @@ bool PostgresSelfHosted::initialize(Gtk::Window* parent_window, const Glib::ustr
   //std::cout << "debug: dbdir_uri=" << dbdir_uri << std::endl;
 
   if(directory_exists_uri(dbdir_uri))
-  { 
-    if(parent_window)
-    {
-      Utils::show_ok_dialog(_("Directory Already Exists"), _("There is an existing directory with the same name as the directory that should be created for the new database files. You should specify a different filename to use a new directory instead."), *parent_window, Gtk::MESSAGE_ERROR);
-    }
-    
-    return false;
-  }
+    return INITERROR_DIRECTORY_ALREADY_EXISTS;
 
   const std::string dbdir = Glib::filename_from_uri(dbdir_uri);
   //std::cout << "debug: dbdir=" << dbdir << std::endl;
@@ -262,13 +228,8 @@ bool PostgresSelfHosted::initialize(Gtk::Window* parent_window, const Glib::ustr
   {
     std::cerr << "Error from g_mkdir_with_parents() while trying to create directory: " << dbdir << std::endl;
     perror("Error from g_mkdir_with_parents");
-
-    if(parent_window)
-    {
-       Utils::show_ok_dialog(_("Could Not Create Directory"), _("There was an error when attempting to create the directory for the new database files."), *parent_window, Gtk::MESSAGE_ERROR);
-    }
-
-    return false;
+    
+    return INITERROR_COULD_NOT_CREATE_DIRECTORY;
   }
 
   //Create the config directory:
@@ -279,22 +240,11 @@ bool PostgresSelfHosted::initialize(Gtk::Window* parent_window, const Glib::ustr
     std::cerr << "Error from g_mkdir_with_parents() while trying to create directory: " << dbdir_config << std::endl;
     perror("Error from g_mkdir_with_parents");
 
-    if(parent_window)
-    {
-       Utils::show_ok_dialog(_("Could Not Create Configuration Directory"), _("There was an error when attempting to create the configuration directory for the new database files."), *parent_window, Gtk::MESSAGE_ERROR);
-    }
-
-    return false;
+    return INITERROR_COULD_NOT_CREATE_DIRECTORY;
   }
 
   //Create these files: environment  pg_hba.conf  pg_ident.conf  start.conf
-
-  const std::string dbdir_uri_config = dbdir_uri + "/config";
-  const bool hba_conf_creation_succeeded = create_text_file(dbdir_uri_config + "/pg_hba.conf", DEFAULT_CONFIG_PG_HBA);
-  g_assert(hba_conf_creation_succeeded);
-
-  const bool ident_conf_creation_succeeded = create_text_file(dbdir_uri_config + "/pg_ident.conf", DEFAULT_CONFIG_PG_IDENT);
-  g_assert(ident_conf_creation_succeeded);
+  set_network_shared(slot_progress, m_network_shared); //Creates pg_hba.conf and pg_ident.conf
 
   //Check that there is not an existing data directory:
   const std::string dbdir_data = dbdir + "/data";
@@ -303,11 +253,6 @@ bool PostgresSelfHosted::initialize(Gtk::Window* parent_window, const Glib::ustr
 
   
   // initdb creates a new postgres database cluster:
-  if(initial_username.empty())
-  {
-    std::cerr << "PostgresSelfHosted::initialize(). Username was empty while attempting to create self-hosting database" << std::endl;
-    return false;
-  }
 
   //Get file:// URI for the tmp/ directory:
   const std::string temp_pwfile = Glib::build_filename(Glib::get_tmp_dir(), "glom_initdb_pwfile");
@@ -322,7 +267,7 @@ bool PostgresSelfHosted::initialize(Gtk::Window* parent_window, const Glib::ustr
                                         " -U " + initial_username + " --pwfile=\"" + temp_pwfile + "\"";
 
   //Note that --pwfile takes the password from the first line of a file. It's an alternative to supplying it when prompted on stdin.
-  const bool result = Glom::Spawn::execute_command_line_and_wait(command_initdb, _("Creating Database Data"), parent_window);
+  const bool result = Glom::Spawn::execute_command_line_and_wait(command_initdb, slot_progress);
   if(!result)
   {
     std::cerr << "Error while attempting to create self-hosting database." << std::endl;
@@ -331,11 +276,13 @@ bool PostgresSelfHosted::initialize(Gtk::Window* parent_window, const Glib::ustr
   const int temp_pwfile_removed = g_remove(temp_pwfile.c_str()); //Of course, we don't want this to stay around. It would be a security risk.
   g_assert(temp_pwfile_removed == 0);
  
-  return result;
+  return result ? INITERROR_NONE : INITERROR_COULD_NOT_START_SERVER;
 }
 
-bool PostgresSelfHosted::startup(Gtk::Window* parent_window)
+bool PostgresSelfHosted::startup(const SlotProgress& slot_progress, bool network_shared)
 {
+   m_network_shared = network_shared;
+
   // Don't risk random crashes, although this really shouldn't be called
   // twice of course.
   //g_assert(!get_self_hosting_active());
@@ -352,6 +299,9 @@ bool PostgresSelfHosted::startup(Gtk::Window* parent_window)
     return false;
   }
 
+  //Attempt to ensure that the config files are correct:
+  set_network_shared(slot_progress, m_network_shared); //Creates pg_hba.conf and pg_ident.conf
+
   const std::string dbdir = Glib::filename_from_uri(dbdir_uri);
   g_assert(!dbdir.empty());
 
@@ -405,7 +355,7 @@ bool PostgresSelfHosted::startup(Gtk::Window* parent_window)
   const std::string second_command_success_text = "is running"; //TODO: This is not a stable API. Also, watch out for localisation.
 
   //The first command does not return, but the second command can check whether it succeeded:
-  const bool result = Glom::Spawn::execute_command_line_and_wait_until_second_command_returns_success(command_postgres_start, command_check_postgres_has_started, _("Starting Database Server"), parent_window, second_command_success_text);
+  const bool result = Glom::Spawn::execute_command_line_and_wait_until_second_command_returns_success(command_postgres_start, command_check_postgres_has_started, slot_progress, second_command_success_text);
   if(!result)
   {
     std::cerr << "Error while attempting to self-host a database." << std::endl;
@@ -417,7 +367,7 @@ bool PostgresSelfHosted::startup(Gtk::Window* parent_window)
   return true;
 }
 
-void PostgresSelfHosted::cleanup(Gtk::Window* parent_window)
+void PostgresSelfHosted::cleanup(const SlotProgress& slot_progress)
 {
   // This seems to be called twice sometimes, so we don't assert here until
   // this is fixed.
@@ -445,14 +395,14 @@ void PostgresSelfHosted::cleanup(Gtk::Window* parent_window)
   // Make sure to use double quotes for the executable path, because the
   // CreateProcess() API used on Windows does not support single quotes.
   const std::string command_postgres_stop = "\"" + get_path_to_postgres_executable("pg_ctl") + "\" -D \"" + dbdir_data + "\" stop -m fast";
-  const bool result = Glom::Spawn::execute_command_line_and_wait(command_postgres_stop, _("Stopping Database Server"), parent_window);
+  const bool result = Glom::Spawn::execute_command_line_and_wait(command_postgres_stop, slot_progress);
   if(!result)
   {
     std::cerr << "Error while attempting to stop self-hosting of the database. Trying again."  << std::endl;
 
     //I've seen it fail when running under valgrind, and there are reports of failures in bug #420962.
     //Maybe it will help to try again:
-    const bool result = Glom::Spawn::execute_command_line_and_wait(command_postgres_stop, _("Stopping Database Server (retrying)"), parent_window);
+    const bool result = Glom::Spawn::execute_command_line_and_wait(command_postgres_stop, slot_progress);
     if(!result)
     {
       std::cerr << "Error while attempting (for a second time) to stop self-hosting of the database."  << std::endl;
@@ -462,10 +412,35 @@ void PostgresSelfHosted::cleanup(Gtk::Window* parent_window)
   m_port = 0;
 }
 
+bool PostgresSelfHosted::set_network_shared(const SlotProgress& /* slot_progress */, bool network_shared)
+{
+  //TODO: Use slot_progress, while doing async IO for create_text_file().
+
+  m_network_shared = network_shared;
+
+  const std::string dbdir_uri = m_self_hosting_data_uri;
+  const std::string dbdir = Glib::filename_from_uri(dbdir_uri);
+
+  const std::string dbdir_uri_config = dbdir_uri + "/config";
+  const char* default_conf_contents = m_network_shared ? DEFAULT_CONFIG_PG_HBA_REMOTE : DEFAULT_CONFIG_PG_HBA_LOCAL;
+  const bool hba_conf_creation_succeeded = create_text_file(dbdir_uri_config + "/pg_hba.conf", default_conf_contents);
+  g_assert(hba_conf_creation_succeeded);
+  if(!hba_conf_creation_succeeded)
+    return false;
+
+  const bool ident_conf_creation_succeeded = create_text_file(dbdir_uri_config + "/pg_ident.conf", DEFAULT_CONFIG_PG_IDENT);
+  g_assert(ident_conf_creation_succeeded);
+
+  return hba_conf_creation_succeeded;
+}
+
 Glib::RefPtr<Gnome::Gda::Connection> PostgresSelfHosted::connect(const Glib::ustring& database, const Glib::ustring& username, const Glib::ustring& password, std::auto_ptr<ExceptionConnection>& error)
 {
   if(!get_self_hosting_active())
+  {
+    error.reset(new ExceptionConnection(ExceptionConnection::FAILURE_NO_BACKEND)); //TODO: But there is a backend. It's just not ready.
     return Glib::RefPtr<Gnome::Gda::Connection>();
+  }
 
   return attempt_connect("localhost", port_as_string(m_port), database, username, password, error);
 
