@@ -54,23 +54,19 @@ public:
    */
   int get_port() const;
 
-  /** Check whether PostgreSQL is really available for self-hosting,
-   * in case the distro package has incorrect dependencies.
-   *
-   * @results True if everything is OK.
-   */
-  static bool check_postgres_is_available_with_warning();
-
   /** Try to install postgres on the distro, though this will require a
    * distro-specific patch to the implementation.
    */
-  static bool install_postgres(Gtk::Window* parent_window);
+  static bool install_postgres(const SlotProgress& slot_progress);
+
+  static std::string get_path_to_postgres_executable(const std::string& program);
 
 private:
-  virtual bool initialize(Gtk::Window* parent_window, const Glib::ustring& initial_username, const Glib::ustring& password);
+  virtual InitErrors initialize(const SlotProgress& slot_progress, const Glib::ustring& initial_username, const Glib::ustring& password, bool network_shared = false);
 
-  virtual bool startup(Gtk::Window* parent_window);
-  virtual void cleanup(Gtk::Window* parent_window);
+  virtual bool startup(const SlotProgress& slot_progress, bool network_shared = false);
+  virtual void cleanup(const SlotProgress& slot_progress);
+  virtual bool set_network_shared(const SlotProgress& slot_progress, bool network_shared = true);
 
   virtual Glib::RefPtr<Gnome::Gda::Connection> connect(const Glib::ustring& database, const Glib::ustring& username, const Glib::ustring& password, std::auto_ptr<ExceptionConnection>& error);
 
@@ -91,6 +87,7 @@ private:
 
   std::string m_self_hosting_data_uri;
   int m_port;
+  bool m_network_shared;
 };
 
 } // namespace ConnectionPoolBackends
