@@ -18,7 +18,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <glom/libglom/data_structure/foundset.h>
+#include <libglom/data_structure/foundset.h>
 
 namespace Glom
 {
