@@ -21,12 +21,12 @@
 #ifndef GLOM_DATASTRUCTURE_LAYOUTITEM_FIELD_H
 #define GLOM_DATASTRUCTURE_LAYOUTITEM_FIELD_H
 
-#include "layoutitem.h"
-#include "usesrelationship.h"
-#include "../field.h"
-#include "../numeric_format.h"
-#include "../relationship.h"
-#include "custom_title.h"
+#include <libglom/data_structure/layout/layoutitem.h>
+#include <libglom/data_structure/layout/usesrelationship.h>
+#include <libglom/data_structure/field.h>
+#include <libglom/data_structure/numeric_format.h>
+#include <libglom/data_structure/relationship.h>
+#include <libglom/data_structure/layout/custom_title.h>
 
 namespace Glom
 {
@@ -56,7 +56,7 @@ public:
     return (*uses_a == *uses_b);
   }
     
-protected:
+private:
   sharedptr<const T_Element> m_layout_item;
 };
 
@@ -133,7 +133,7 @@ public:
    */
   Glib::ustring get_sql_name(const Glib::ustring& parent_table) const;
 
-protected:
+private:
 
   //This is just a cache, filled in by looking at the database structure:
   sharedptr<const Field> m_field;
