@@ -24,12 +24,12 @@
 #include <eval.h> /* for PyEval_EvalCode */
 #include <objimpl.h> /* for PyObject_New() */
 
-#include <glom/libglom/python_embed/py_glom_related.h>
-//#include <glom/libglom/python_embed/py_glom_record.h>
-#include <glom/libglom/python_embed/py_glom_relatedrecord.h>
+#include <libglom/python_embed/py_glom_related.h>
+//#include <libglom/python_embed/py_glom_record.h>
+#include <libglom/python_embed/py_glom_relatedrecord.h>
 
-#include <glom/libglom/data_structure/field.h>
-#include <glom/libglom/data_structure/glomconversions.h>
+#include <libglom/data_structure/field.h>
+#include <libglom/data_structure/glomconversions.h>
 #include <glibmm/ustring.h>
 
 
@@ -214,7 +214,7 @@ static PyMappingMethods Related_tp_as_mapping = {
 static PyTypeObject pyglom_RelatedType = {
     PyObject_HEAD_INIT(NULL)
     0,                         /*ob_size*/
-    "glom.Related",             /*tp_name*/
+    (char*)"glom.Related",             /*tp_name*/
     sizeof(PyGlomRelated), /*tp_basicsize*/
     0,                         /*tp_itemsize*/
     (destructor)Related_dealloc, /*tp_dealloc*/
@@ -233,7 +233,7 @@ static PyTypeObject pyglom_RelatedType = {
     0,                         /*tp_setattro*/
     0,                         /*tp_as_buffer*/
     Py_TPFLAGS_DEFAULT,        /*tp_flags*/
-    "Glom objects",           /* tp_doc */
+    (char*)"Glom objects",           /* tp_doc */
     0,                  /* tp_traverse */
     0,                   /* tp_clear */
     0,                   /* tp_richcompare */
