@@ -32,7 +32,7 @@
 #include <libglom/data_structure/field.h>
 #include <glibmm/ustring.h>
 
-#include "glom/application.h"
+//#include "glom/application.h"
 
 namespace Glom
 {
@@ -248,7 +248,7 @@ RelatedRecord_tp_as_mapping_getitem(PyObject *self, PyObject *item)
             else if(!datamodel)
             {
               g_warning("RelatedRecord_tp_as_mapping_getitem(): The datamodel was null.");
-              ConnectionPool::handle_error(true /* cerr only */);
+              ConnectionPool::handle_error_cerr_only();
               RelatedRecord_HandlePythonError();
             }
             else
@@ -352,7 +352,7 @@ RelatedRecord_generic_aggregate(PyGlomRelatedRecord* self, PyObject *args, PyObj
         else if(!datamodel)
         {
           g_warning("RelatedRecord_generic_aggregate(): The datamodel was null.");
-          ConnectionPool::handle_error(true /* cerr only */);
+          ConnectionPool::handle_error_cerr_only();
           RelatedRecord_HandlePythonError();
         }
         else
@@ -463,7 +463,7 @@ PyTypeObject* PyGlomRelatedRecord_GetPyType()
 }
 
 
-void PyGlomRelatedRecord_SetRelationship(PyGlomRelatedRecord* self, const sharedptr<const Relationship>& relationship, const Glib::ustring& from_key_value_sqlized,  Document_Glom* document)
+void PyGlomRelatedRecord_SetRelationship(PyGlomRelatedRecord* self, const sharedptr<const Relationship>& relationship, const Glib::ustring& from_key_value_sqlized,  Document* document)
 {
   self->m_relationship = new sharedptr<const Relationship>(relationship);
 
