@@ -26,9 +26,6 @@
 
 #include <libglom/data_structure/layout/layoutitem_field.h>
 
-#include <gtkmm/dialog.h>
-#include <gtkmm/messagedialog.h>
-
 namespace Glom
 {
 
@@ -39,12 +36,6 @@ typedef std::list<type_pair_sort_field> type_sort_clause;
 namespace Utils
 {
 
-///A standard widget spacing:
-extern const unsigned int DEFAULT_SPACING_LARGE;
-
-///A standard widget spacing:
-extern const unsigned int DEFAULT_SPACING_SMALL;
-
 Glib::ustring trim_whitespace(const Glib::ustring& text);
 
 Glib::ustring string_replace(const Glib::ustring& src, const Glib::ustring search_for, const Glib::ustring& replace_with);
@@ -90,25 +81,14 @@ Glib::ustring string_from_decimal(guint decimal);
  */
 Glib::ustring title_from_string(const Glib::ustring& text);
 
-typedef std::vector<Glib::ustring> type_vecStrings;
-type_vecStrings string_separate(const Glib::ustring& str, const Glib::ustring& separator, bool ignore_quoted_separator = false);
+typedef std::vector<Glib::ustring> type_vec_strings;
+type_vec_strings string_separate(const Glib::ustring& str, const Glib::ustring& separator, bool ignore_quoted_separator = false);
 
 Glib::ustring string_trim(const Glib::ustring& str, const Glib::ustring& to_remove);
 
 Glib::ustring string_remove_suffix(const Glib::ustring& str, const Glib::ustring& suffix, bool case_sensitive = true);
 
-int dialog_run_with_help(Gtk::Dialog* dialog, const Glib::ustring& id = Glib::ustring());
-
-/** This is a replacement for gnome_help_display(), 
- * to avoid the libgnome dependency.
- * TODO: GTK+ should have a function for this soon.
- */
-void show_help(const Glib::ustring& id = Glib::ustring());
-
-void show_ok_dialog(const Glib::ustring& title, const Glib::ustring& message, Gtk::Window& parent, Gtk::MessageType message_type);
-void show_ok_dialog(const Glib::ustring& title, const Glib::ustring& message, Gtk::Window* parent, Gtk::MessageType message_type);
-
-void show_window_until_hide(Gtk::Window* window);
+bool file_exists(const Glib::ustring& uri);
 
 } //namespace Utils
 
