@@ -18,12 +18,12 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include "box_data_calendar_related.h"
-#include "dialog_layout_calendar_related.h"
+#include <glom/mode_data/box_data_calendar_related.h>
+#include <glom/mode_data/dialog_layout_calendar_related.h>
+#include <glom/utils_ui.h>
 #include <glom/application.h>
 #include <libglom/data_structure/glomconversions.h>
 #include <glom/frame_glom.h> //For show_ok_dialog()
-#include <bakery/App/App_Gtk.h> //For util_bold_message().
 #include <glibmm/i18n.h>
 
 namespace Glom
@@ -96,7 +96,7 @@ bool Box_Data_Calendar_Related::init_db_details(const Glib::ustring& parent_tabl
       relationship_title = _("Undefined Table");
     }
 
-    m_Label.set_markup(Bakery::App_Gtk::util_bold_message(relationship_title));
+    m_Label.set_markup(Utils::bold_message(relationship_title));
     m_Label.show();
 
     m_Alignment.set_padding(Utils::DEFAULT_SPACING_SMALL /* top */, 0, Utils::DEFAULT_SPACING_LARGE /* left */, 0);
@@ -344,7 +344,7 @@ void Box_Data_Calendar_Related::on_dialog_layout_hide()
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 Dialog_Layout* Box_Data_Calendar_Related::create_layout_dialog() const
 {
-  Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(GLOM_GLADEDIR "glom_developer.glade", "window_data_layout");
+  Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(GLOM_GLADEDIR "glom_developer.glade", "window_data_layout");
   if(refXml)
   {
     Dialog_Layout_Calendar_Related* dialog = 0;
