@@ -18,18 +18,17 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include "box_data_details.h"
-#include "../frame_glom.h" //For show_ok_dialog().
+#include <glom/mode_data/box_data_details.h>
+#include <glom/frame_glom.h> //For show_ok_dialog().
 #include <libglom/data_structure/field.h>
 #include <libglom/data_structure/relationship.h>
 #include <libglom/data_structure/glomconversions.h>
-#include "dialog_layout_details.h"
-#include <libglom/glade_utils.h>
-#include <libglom/utils.h>
+#include <glom/mode_data/dialog_layout_details.h>
+#include <glom/glade_utils.h>
+#include <glom/utils_ui.h>
 #include <glom/glom_privs.h>
-#include "../xsl_utils.h"
-#include <bakery/App/App_Gtk.h> //For util_bold_message().
-#include "../python_embed/glom_python.h"
+#include <glom/xsl_utils.h>
+#include <glom/python_embed/glom_python.h>
 #include <sstream> //For stringstream
 #include <glibmm/i18n.h>
 
@@ -193,22 +192,22 @@ bool Box_Data_Details::refresh_data_from_database_blank()
 
 void Box_Data_Details::create_layout()
 {
-  Bakery::BusyCursor busy_cursor(get_app_window());
+  BusyCursor busy_cursor(get_app_window());
 
   Box_Data::create_layout(); //Fills m_TableFields.
 
   //Remove existing child widgets:
   m_FlowTable.remove_all();
 
-  Document_Glom* document = dynamic_cast<Document_Glom*>(get_document());
+  Document* document = dynamic_cast<Document*>(get_document());
   if(document)
   {
     m_FlowTable.set_table(m_table_name); //This allows portals to get full Relationship information
 
     //This map of layout groups will also contain the field information from the database:
-    Document_Glom::type_list_layout_groups layout_groups = get_data_layout_groups(m_layout_name, m_layout_platform);
+    Document::type_list_layout_groups layout_groups = get_data_layout_groups(m_layout_name, m_layout_platform);
 
-    for(Document_Glom::type_list_layout_groups::const_iterator iter = layout_groups.begin(); iter != layout_groups.end(); ++iter)
+    for(Document::type_list_layout_groups::const_iterator iter = layout_groups.begin(); iter != layout_groups.end(); ++iter)
     {
       m_FlowTable.add_layout_group(*iter);
     }
@@ -230,7 +229,7 @@ bool Box_Data_Details::fill_from_database()
 
   bool bResult = false;
 
-  Bakery::BusyCursor busy_cursor(get_app_window());
+  BusyCursor busy_cursor(get_app_window());
 
   const bool primary_key_is_empty = Conversions::value_is_empty(m_primary_key_value);
   if(!primary_key_is_empty)
@@ -337,11 +336,11 @@ bool Box_Data_Details::fill_from_database()
 
         if((result && result->get_n_rows()) || primary_key_is_empty) //either a working result or no result needed.
         {
-          const Document_Glom* pDoc = dynamic_cast<const Document_Glom*>(get_document());
+          const Document* pDoc = dynamic_cast<const Document*>(get_document());
           if(pDoc)
           {
             //Get glom-specific field info:
-            //Document_Glom::type_vecFields vecFields = pDoc->get_table_fields(m_table_name);
+            //Document::type_vec_fields vecFields = pDoc->get_table_fields(m_table_name);
 
             const int row_number = 0; //The only row.
             int cols_count = 0;
@@ -404,7 +403,7 @@ void Box_Data_Details::on_button_new()
   {
     //Warn the user that they won't see anything if there are no fields on the layout,
     //doing an extra check:
-    Document_Glom* document = get_document();
+    Document* document = get_document();
     if( document && !(document->get_data_layout_groups_have_any_fields(m_layout_name, m_table_name, m_layout_platform)) )
     {
       Gtk::Window* parent_window = get_app_window();
@@ -436,7 +435,7 @@ void Box_Data_Details::on_button_del()
   if( Conversions::value_is_empty(get_primary_key_value_selected()) )
   {
     //Tell user that a primary key is needed to delete a record:
-    Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("No primary key value.")), true);
+    Gtk::MessageDialog dialog(Utils::bold_message(_("No primary key value.")), true);
     dialog.set_secondary_text(_("This record cannot be deleted because there is no primary key."));
     dialog.set_transient_for(*get_app_window());
     dialog.run();
@@ -507,7 +506,7 @@ void Box_Data_Details::recalculate_fields_for_related_records(const Glib::ustrin
 
   //Check all fields in the parent table:
   const Gnome::Gda::Value primary_key_value = get_primary_key_value_selected();
-  for(type_vecFields::iterator iter = m_TableFields.begin(); iter != m_TableFields.end(); ++iter)
+  for(type_vec_fields::iterator iter = m_TableFields.begin(); iter != m_TableFields.end(); ++iter)
   {
     const sharedptr<const Field> field = *iter;
 
@@ -601,11 +600,11 @@ void Box_Data_Details::on_flowtable_layout_changed()
 {
   //Get new layout:
 #if 0
-  Document_Glom::type_list_layout_groups layout_groups;
+  Document::type_list_layout_groups layout_groups;
   m_FlowTable.get_layout_groups(layout_groups);
 
   //Store it in the document:
-  Document_Glom* document = get_document();
+  Document* document = get_document();
   if(document)
     document->set_data_layout_groups(m_layout_name, m_table_name, m_layout_platform, layout_groups);
   //Build the view again from the new layout:
@@ -613,7 +612,7 @@ void Box_Data_Details::on_flowtable_layout_changed()
   create_layout();
 
   //Store it in the document:
-  Document_Glom* document = get_document();
+  Document* document = get_document();
   if(document)
     document->set_modified();
     
@@ -692,7 +691,7 @@ void Box_Data_Details::on_flowtable_field_edited(const sharedptr<const LayoutIte
 
   Gtk::Window* window = get_app_window();
 
-  Document_Glom* document = dynamic_cast<Document_Glom*>(get_document());
+  Document* document = dynamic_cast<Document*>(get_document());
 
   Gnome::Gda::Value primary_key_value = get_primary_key_value_selected();
   //std::cout << "Box_Data_Details::on_flowtable_field_edited(): primary_key_value=" << primary_key_value.to_string() << std::endl;
@@ -761,8 +760,8 @@ void Box_Data_Details::on_flowtable_field_edited(const sharedptr<const LayoutIte
     }
 
     //Set the value in all instances of this field in the layout (The field might be on the layout more than once):
-    //if(layout_field->get_glom_type() != Field::TYPE_IMAGE) //TODO For now, don't do this for images, because the ImageGlom widget expects a broken GdaValue, because gda_value_get_binary() needs to be fixed.
-    m_FlowTable.set_field_value(layout_field, field_value);
+    //We don't need to set the value in the layout_field itself, as this is where the value comes from.
+    m_FlowTable.set_other_field_value(layout_field, field_value);
 
     //Update the field in the record (the record with this primary key):
 
@@ -802,8 +801,8 @@ void Box_Data_Details::on_flowtable_field_edited(const sharedptr<const LayoutIte
         //If this is a foreign key then refresh the related records:
         /*
         bool bIsForeignKey = false;
-        Document_Glom::type_vecRelationships vecRelationships = get_document()->get_relationships(m_table_name);
-        for(Document_Glom::type_vecRelationships::iterator iter = vecRelationships.begin(); iter != vecRelationships.end(); iter++)
+        Document::type_vec_relationships vecRelationships = get_document()->get_relationships(m_table_name);
+        for(Document::type_vec_relationships::iterator iter = vecRelationships.begin(); iter != vecRelationships.end(); iter++)
         {
           const Relationship& relationship = *iter;
 
@@ -840,7 +839,7 @@ void Box_Data_Details::on_flowtable_field_edited(const sharedptr<const LayoutIte
       if(strFieldName == m_field_primary_key->get_name()) //If edited field is the primary key.
       {
         //Warn user that they can't choose their own primary key:
-        Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("Primary key auto increments")), true);
+        Gtk::MessageDialog dialog(Utils::bold_message(_("Primary key auto increments")), true);
         dialog.set_secondary_text(_("The primary key is auto-incremented.\n You may not enter your own primary key value."));
         dialog.set_transient_for(*get_app_window());
         dialog.run();
@@ -986,8 +985,8 @@ void Box_Data_Details::print_layout()
     //The groups:
     xmlpp::Element* nodeParent = nodeRoot;
 
-    Document_Glom::type_list_layout_groups layout_groups = get_data_layout_groups(m_layout_name, m_layout_platform);
-    for(Document_Glom::type_list_layout_groups::const_iterator iter = layout_groups.begin(); iter != layout_groups.end(); ++iter)
+    Document::type_list_layout_groups layout_groups = get_data_layout_groups(m_layout_name, m_layout_platform);
+    for(Document::type_list_layout_groups::const_iterator iter = layout_groups.begin(); iter != layout_groups.end(); ++iter)
     {
       sharedptr<const LayoutGroup> layout_group = *iter;
       print_layout_group(nodeParent, layout_group);
@@ -1000,7 +999,7 @@ void Box_Data_Details::print_layout()
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 Dialog_Layout* Box_Data_Details::create_layout_dialog() const
 {
-  Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "window_data_layout"); //TODO: Use a generic layout dialog?
+  Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "window_data_layout"); //TODO: Use a generic layout dialog?
   if(refXml)
   {
     Dialog_Layout_Details* dialog = 0;
