@@ -18,12 +18,12 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include "box_data_list_related.h"
-#include "dialog_layout_list_related.h"
+#include <glom/mode_data/box_data_list_related.h>
+#include <glom/mode_data/dialog_layout_list_related.h>
 #include <libglom/data_structure/glomconversions.h>
-#include <libglom/glade_utils.h>
+#include <glom/glade_utils.h>
 #include <glom/frame_glom.h> //For show_ok_dialog()
-#include <bakery/App/App_Gtk.h> //For util_bold_message().
+#include <glom/utils_ui.h> //For bold_message()).
 #include <glibmm/i18n.h>
 
 namespace Glom
@@ -89,7 +89,7 @@ bool Box_Data_List_Related::init_db_details(const Glib::ustring& parent_table, b
       relationship_title = _("Undefined Table");
     }
   
-    m_Label.set_markup(Bakery::App_Gtk::util_bold_message(relationship_title));
+    m_Label.set_markup(Utils::bold_message(relationship_title));
     m_Label.show();
 
     m_Alignment.set_padding(Utils::DEFAULT_SPACING_SMALL /* top */, 0, Utils::DEFAULT_SPACING_LARGE /* left */, 0);
@@ -332,7 +332,7 @@ void Box_Data_List_Related::on_dialog_layout_hide()
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 Dialog_Layout* Box_Data_List_Related::create_layout_dialog() const
 {
-  Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "window_data_layout");
+  Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "window_data_layout");
   if(refXml)
   {
     Dialog_Layout_List_Related* dialog = 0;
@@ -368,9 +368,9 @@ void Box_Data_List_Related::set_primary_key_value(const Gtk::TreeModel::iterator
 }
 
 
-Document_Glom::type_list_layout_groups Box_Data_List_Related::create_layout_get_layout()
+Document::type_list_layout_groups Box_Data_List_Related::create_layout_get_layout()
 {
-  Document_Glom::type_list_layout_groups result;
+  Document::type_list_layout_groups result;
 
   //Do not use get_data_layout_groups(m_layout_name).
   //instead do this:
@@ -386,7 +386,7 @@ void Box_Data_List_Related::create_layout()
 {
   Box_Data::create_layout(); //Fills m_TableFields.
 
-  const Document_Glom* pDoc = dynamic_cast<const Document_Glom*>(get_document());
+  const Document* pDoc = dynamic_cast<const Document*>(get_document());
   if(pDoc)
   {
     //Field Names:
@@ -406,10 +406,10 @@ void Box_Data_List_Related::create_layout()
       m_AddDel.set_key_field(field_primary_key);
  
       //This map of layout groups will also contain the field information from the database:
-      Document_Glom::type_list_layout_groups layout_groups = create_layout_get_layout();
+      Document::type_list_layout_groups layout_groups = create_layout_get_layout();
       
       //int debug_count = 0;
-      for(Document_Glom::type_list_layout_groups::const_iterator iter = layout_groups.begin(); iter != layout_groups.end(); ++iter)
+      for(Document::type_list_layout_groups::const_iterator iter = layout_groups.begin(); iter != layout_groups.end(); ++iter)
       {
         //std::cout << "Box_Data_List::create_layout() group number=" << debug_count;
         //debug_count++;
