@@ -18,11 +18,11 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include "box_data_portal.h"
-#include <glom/libglom/data_structure/glomconversions.h>
-#include <glom/libglom/glade_utils.h>
+#include <glom/mode_data/box_data_portal.h>
+#include <libglom/data_structure/glomconversions.h>
+#include <glom/glade_utils.h>
 #include <glom/frame_glom.h> //For show_ok_dialog()
-#include <bakery/App/App_Gtk.h> //For util_bold_message().
+#include <glom/utils_ui.h> //For bold_message()).
 #include <glibmm/i18n.h>
 
 namespace Glom
@@ -86,7 +86,7 @@ bool Box_Data_Portal::init_db_details(const Glib::ustring& parent_table, bool sh
       relationship_title = _("Undefined Table");
     }
 
-    m_Label.set_markup(Bakery::App_Gtk::util_bold_message(relationship_title));
+    m_Label.set_markup(Utils::bold_message(relationship_title));
     m_Label.show();
 
     m_Alignment.set_padding(Utils::DEFAULT_SPACING_SMALL /* top */, 0, Utils::DEFAULT_SPACING_LARGE /* left */, 0);
@@ -103,55 +103,22 @@ bool Box_Data_Portal::init_db_details(const Glib::ustring& parent_table, bool sh
 
   FoundSet found_set;
   found_set.m_table_name = LayoutWidgetBase::m_table_name;
-  return Box_Data::init_db_details(found_set); //Calls create_layout() and fill_from_database().
+  return Box_Data::init_db_details(found_set, m_layout_platform); //Calls create_layout() and fill_from_database().
 }
 
 bool Box_Data_Portal::refresh_data_from_database_with_foreign_key(const Gnome::Gda::Value& foreign_key_value)
 {
   m_key_value = foreign_key_value;
+  
 
   if(m_key_field && m_portal)
   {
     if(!Conversions::value_is_empty(m_key_value))
     {
-      sharedptr<Relationship> relationship = m_portal->get_relationship();
-
-      // Notice that, in the case that this is a portal to doubly-related records,
-      // The WHERE clause mentions the first-related table (though by the alias defined in extra_join)
-      // and we add an extra JOIN to mention the second-related table.
-
-      Glib::ustring where_clause_to_table_name = relationship->get_to_table();
-      sharedptr<Field> where_clause_to_key_field = m_key_field;
-
-      FoundSet found_set = m_found_set;
-      found_set.m_table_name = m_portal->get_table_used(Glib::ustring() /* parent table - not relevant */);
-      
-      sharedptr<const Relationship> relationship_related = m_portal->get_related_relationship();
-      if(relationship_related)
-      {
-         //Add the extra JOIN:
-         sharedptr<UsesRelationship> uses_rel_temp = sharedptr<UsesRelationship>::create();
-         uses_rel_temp->set_relationship(relationship);
-         //found_set.m_extra_join = uses_rel_temp->get_sql_join_alias_definition();
-         found_set.m_extra_join = "LEFT OUTER JOIN \"" + relationship->get_to_table() + "\" AS \"" + uses_rel_temp->get_sql_join_alias_name() + "\" ON (\"" + uses_rel_temp->get_sql_join_alias_name() + "\".\"" + relationship_related->get_from_field() + "\" = \"" + relationship_related->get_to_table() + "\".\"" + relationship_related->get_to_field() + "\")";
-
-         //Add an extra GROUP BY to ensure that we get no repeated records from the doubly-related table:
-         found_set.m_extra_group_by = "GROUP BY \"" + found_set.m_table_name + "\".\"" + m_key_field->get_name() + "\"";
-
-         //Adjust the WHERE clause appropriately for the extra JOIN:
-         where_clause_to_table_name = uses_rel_temp->get_sql_join_alias_name();
-
-         Glib::ustring to_field_name = uses_rel_temp->get_to_field_used();
-         where_clause_to_key_field = get_fields_for_table_one_field(relationship->get_to_table(), to_field_name);
-         //std::cout << "extra_join=" << found_set.m_extra_join << std::endl;
- 
-         //std::cout << "extra_join where_clause_to_key_field=" << where_clause_to_key_field->get_name() << std::endl;
-      }
-
-      found_set.m_where_clause = "\"" + where_clause_to_table_name + "\".\"" + relationship->get_to_field() + "\" = " + where_clause_to_key_field->sql(m_key_value);
-
-
-      //g_warning("refresh_data_from_database_with_foreign_key(): where_clause=%s", where_clause.c_str());
+      FoundSet found_set;
+      set_found_set_where_clause_for_portal(found_set, m_portal, m_key_value);
+   
+      //std::cout << "DEBUG: refresh_data_from_database_with_foreign_key(): where_clause=" << found_set.m_where_clause << std::endl;
       return Box_Data::refresh_data_from_database_with_where_clause(found_set);
     }
     else
@@ -187,7 +154,7 @@ void Box_Data_Portal::on_record_deleted(const Gnome::Gda::Value& /* primary_key_
   signal_portal_record_changed().emit(m_portal->get_relationship_name());
 }
 
-void Box_Data_Portal::on_record_added(const Gnome::Gda::Value& primary_key_value, const Gtk::TreeModel::iterator& row)
+void Box_Data_Portal::on_record_added(const Gnome::Gda::Value& /* primary_key_value */, const Gtk::TreeModel::iterator& /* row */)
 {
   //Allow the parent record (Details view) to recalculate aggregations:
   signal_portal_record_changed().emit(m_portal->get_relationship_name());
@@ -195,10 +162,10 @@ void Box_Data_Portal::on_record_added(const Gnome::Gda::Value& primary_key_value
 
 Box_Data_Portal::type_vecLayoutFields Box_Data_Portal::get_fields_to_show() const
 {
-  const Document_Glom* document = get_document();
+  const Document* document = get_document();
   if(document && m_portal)
   {
-    Document_Glom::type_list_layout_groups mapGroups;
+    Document::type_list_layout_groups mapGroups;
     mapGroups.push_back(m_portal);
 
     sharedptr<const Relationship> relationship = m_portal->get_relationship();
@@ -244,48 +211,50 @@ bool Box_Data_Portal::get_has_suitable_record_to_view_details() const
 
 void Box_Data_Portal::get_suitable_table_to_view_details(Glib::ustring& table_name, sharedptr<const UsesRelationship>& relationship) const
 {
- 
   //Initialize output parameters:
   table_name = Glib::ustring();
 
   if(!m_portal)
     return;
 
+
+  sharedptr<const UsesRelationship> navigation_relationship = m_portal->get_navigation_relationship_specific();
+
   //Check whether a relationship was specified:
-  bool navigation_relationship_main = false;
-  sharedptr<const UsesRelationship> navigation_relationship = m_portal->get_navigation_relationship_specific(navigation_relationship_main);
-  if(!navigation_relationship_main && !navigation_relationship)
+  if(m_portal->get_navigation_type() == LayoutItem_Portal::NAVIGATION_AUTOMATIC)
   {
     //std::cout << "debug: decide automatically." << std::endl;
     //Decide automatically:
-    navigation_relationship_main = false;
+    bool navigation_relationship_main = false; // no longer used
     navigation_relationship = get_portal_navigation_relationship_automatic(m_portal, navigation_relationship_main);
     //std::cout << "debug: auto main=" << navigation_relationship_main << ", navigation_relationship=" << (navigation_relationship ? navigation_relationship->get_name() : navigation_relationship->get_relationship()->get_name()) << std::endl;
   }
   //else
   //  std::cout << "debug: get_suitable_table_to_view_details(): Using specific nav." << std::endl;
 
-  const Document_Glom* document = get_document();
+  const Document* document = get_document();
   if(!document)
     return;
 
 
   //Get the navigation table name from the chosen relationship:
   const Glib::ustring directly_related_table_name = m_portal->get_table_used(Glib::ustring() /* not relevant */);
- 
+
+  // The navigation_table_name (and therefore, the table_name output parameter,
+  // as well) stays empty if the navrel type was set to none.
   Glib::ustring navigation_table_name;
-  if(navigation_relationship_main)
+  if(m_portal->get_navigation_type() == LayoutItem_Portal::NAVIGATION_AUTOMATIC)
   {
     navigation_table_name = directly_related_table_name;
   }
-  else if(navigation_relationship)
+  else if(m_portal->get_navigation_type() == LayoutItem_Portal::NAVIGATION_SPECIFIC)
   {
     navigation_table_name = navigation_relationship->get_table_used(directly_related_table_name);
   }
 
   if(navigation_table_name.empty())
   {
-    std::cerr << "Box_Data_Portal::get_suitable_table_to_view_details(): navigation_table_name is empty." << std::endl;
+    //std::cerr << "Box_Data_Portal::get_suitable_table_to_view_details(): navigation_table_name is empty." << std::endl;
     return;
   }
 
@@ -330,8 +299,13 @@ void Box_Data_Portal::get_suitable_record_to_view_details(const Gnome::Gda::Valu
   type_vecLayoutFields fieldsToGet;
   fieldsToGet.push_back(layout_item);
 
-  const Glib::ustring query = Utils::build_sql_select_with_key(m_portal->get_table_used(Glib::ustring() /* not relevant */), fieldsToGet, get_key_field(), primary_key_value);
-  Glib::RefPtr<Gnome::Gda::DataModel> data_model = query_execute(query);
+  //For instance "invoice_line_id" if this is a portal to an "invoice_lines" table:
+  const Glib::ustring related_table = m_portal->get_table_used(Glib::ustring() /* not relevant */);
+  sharedptr<const Field> key_field = get_field_primary_key_for_table(related_table);
+  //std::cout << "DEBUG: related table=" << related_table << ", whose primary_key=" << key_field->get_name() << std::endl;
+
+  const Glib::ustring query = Utils::build_sql_select_with_key(related_table, fieldsToGet, key_field, primary_key_value);
+  Glib::RefPtr<Gnome::Gda::DataModel> data_model = query_execute_select(query);
 
 
   bool value_found = true;
@@ -354,7 +328,14 @@ void Box_Data_Portal::get_suitable_record_to_view_details(const Gnome::Gda::Valu
   else
   {
     value_found = false;
-    std::cout << "debug: Box_Data_Portal::get_suitable_record_to_view_details(): SQL query returned no suitable primary key." << std::endl;
+
+    std::cout << "DEBUG: Box_Data_Portal::get_suitable_record_to_view_details(): SQL query returned no suitable primary key. table=" 
+      << related_table  
+      << ", field=" << layout_item->get_layout_display_name() 
+      << ", key_field=" << key_field->get_name()
+      << ", primary_key_value=" << primary_key_value.to_string() << std::endl;
+
+    std::cout << "  DEBUG: SQL was: " << query << std::endl;
   }
 
   if(!value_found)
@@ -369,9 +350,9 @@ void Box_Data_Portal::get_suitable_record_to_view_details(const Gnome::Gda::Valu
   }
 }
 
-Document_Glom::type_list_layout_groups Box_Data_Portal::create_layout_get_layout()
+Document::type_list_layout_groups Box_Data_Portal::create_layout_get_layout()
 {
-  Document_Glom::type_list_layout_groups result;
+  Document::type_list_layout_groups result;
 
   if(m_portal)
     result.push_back(m_portal);
