@@ -23,7 +23,7 @@
 
 #include <gtkmm/dialog.h>
 #include "../utility_widgets/dialog_properties.h"
-#include <libglom/document/document_glom.h>
+#include <libglom/document/document.h>
 #include "../box_withbuttons.h"
 
 namespace Glom
@@ -34,7 +34,7 @@ class Dialog_Layout :
   public Base_DB //Give it access to the document, and to the database utilities
 {
 public:
-  Dialog_Layout(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade, bool with_table_title = true);
+  Dialog_Layout(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder, bool with_table_title = true);
   virtual ~Dialog_Layout();
 
   /**
@@ -44,7 +44,7 @@ public:
    * @param table_name The table name.
    * @param table_fields: The actual fields in the table, in case the document does not yet know about them all.
    */
-  virtual void set_document(const Glib::ustring& layout_name, const Glib::ustring& layout_platform, Document_Glom* document, const Glib::ustring& table_name, const type_vecLayoutFields& table_fields);
+  virtual void set_document(const Glib::ustring& layout_name, const Glib::ustring& layout_platform, Document* document, const Glib::ustring& table_name, const type_vecLayoutFields& table_fields);
 
   virtual bool get_modified() const;
 
