@@ -30,16 +30,17 @@ namespace Glom
 class Dialog_Layout_Details : public Dialog_Layout
 {
 public:
-  Dialog_Layout_Details(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
+  Dialog_Layout_Details(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
   virtual ~Dialog_Layout_Details();
 
   /**
-   * @param layout "list" or "details"
+   * @param layout_name "list" or "details"
+   * @param layout_platform As in the document. Empty or "maemo".
    * @param document The document, so that the dialog can load the previous layout, and save changes.
    * @param table_name The table name.
    * @param table_fields: The actual fields in the table, in case the document does not yet know about them all.
    */
-  virtual void set_document(const Glib::ustring& layout, Document_Glom* document, const Glib::ustring& table_name, const type_vecLayoutFields& table_fields);
+  virtual void set_document(const Glib::ustring& layout_name, const Glib::ustring& layout_platform, Document* document, const Glib::ustring& table_name, const type_vecLayoutFields& table_fields);
 
 protected:
 
@@ -58,11 +59,11 @@ protected:
   sharedptr<LayoutItem_Button> offer_button_script_edit(const sharedptr<const LayoutItem_Button>& button);
 
   //signal handlers:
-  void on_button_field_up();
-  void on_button_field_down();
+  void on_button_up();
+  void on_button_down();
   void on_button_field_delete();
-  virtual void on_button_field_add(); //overridden in derived class. 
-  void on_button_field_add_group();
+  virtual void on_button_add_field(); //overridden in derived class. 
+  void on_button_add_group();
   void on_button_add_notebook();
   void on_button_add_related();
   void on_button_add_related_calendar();
@@ -95,10 +96,10 @@ protected:
   Gtk::Box* m_box_related_table_widgets;
   Gtk::Frame* m_box_related_navigation;
 
-  Gtk::Button* m_button_field_up;
-  Gtk::Button* m_button_field_down;
-  Gtk::Button* m_button_field_add;
-  Gtk::Button* m_button_field_add_group;
+  Gtk::Button* m_button_up;
+  Gtk::Button* m_button_down;
+  Gtk::Button* m_button_add_field;
+  Gtk::Button* m_button_add_group;
   Gtk::Button* m_button_add_notebook;
   Gtk::Button* m_button_add_related;
   Gtk::Button* m_button_add_related_calendar;
