@@ -29,7 +29,7 @@ namespace Glom
 class Dialog_Layout_List : public Dialog_Layout_Details
 {
 public:
-  Dialog_Layout_List(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
+  Dialog_Layout_List(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
   virtual ~Dialog_Layout_List();
 };
 
