@@ -21,7 +21,7 @@
 #include "dialog_layout_list_related.h"
 #include "dialog_choose_field.h"
 #include "../layout_item_dialogs/dialog_field_layout.h"
-#include <bakery/App/App_Gtk.h> //For util_bold_message().
+#include <libglom/utils.h> //For bold_message()).
 
 //#include <libgnome/gnome-i18n.h>
 #include <gtkmm/togglebutton.h>
@@ -30,11 +30,12 @@
 namespace Glom
 {
 
-Dialog_Layout_List_Related::Dialog_Layout_List_Related(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
-: Dialog_Layout_List(cobject, refGlade),
+Dialog_Layout_List_Related::Dialog_Layout_List_Related(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
+: Dialog_Layout_List(cobject, builder),
   m_combo_relationship(0),
   m_checkbutton_show_child_relationships(0),
   m_radio_navigation_automatic(0),
+  m_radio_navigation_none(0),
   m_radio_navigation_specify(0),
   m_label_navigation_automatic(0),
   m_combo_navigation_specify(0)
@@ -44,20 +45,22 @@ Dialog_Layout_List_Related::Dialog_Layout_List_Related(BaseObjectType* cobject,
   m_box_related_table_widgets->show();
   m_box_related_navigation->show();
 
-  refGlade->get_widget_derived("combo_relationship_name", m_combo_relationship);
+  builder->get_widget_derived("combo_relationship_name", m_combo_relationship);
   m_combo_relationship->signal_changed().connect(sigc::mem_fun(*this, &Dialog_Layout_List_Related::on_combo_relationship_changed));
 
-  refGlade->get_widget("checkbutton_show_child_relationships", m_checkbutton_show_child_relationships);
+  builder->get_widget("checkbutton_show_child_relationships", m_checkbutton_show_child_relationships);
   m_checkbutton_show_child_relationships->signal_toggled().connect(sigc::mem_fun(*this, &Dialog_Layout_List_Related::on_checkbutton_show_child_relationships));
 
   
 
-  refGlade->get_widget("radiobutton_navigation_automatic", m_radio_navigation_automatic);
-  refGlade->get_widget("label_navigation_automatic", m_label_navigation_automatic);
+  builder->get_widget("radiobutton_navigation_automatic", m_radio_navigation_automatic);
+  builder->get_widget("label_navigation_automatic", m_label_navigation_automatic);
   make_sensitivity_depend_on_toggle_button(*m_radio_navigation_automatic, *m_label_navigation_automatic);
 
-  refGlade->get_widget("radiobutton_navigation_specify", m_radio_navigation_specify);
-  refGlade->get_widget_derived("combobox_navigation_specify", m_combo_navigation_specify);
+  builder->get_widget("radiobutton_navigation_none", m_radio_navigation_none);
+
+  builder->get_widget("radiobutton_navigation_specify", m_radio_navigation_specify);
+  builder->get_widget_derived("combobox_navigation_specify", m_combo_navigation_specify);
   make_sensitivity_depend_on_toggle_button(*m_radio_navigation_specify, *m_combo_navigation_specify);
   m_combo_navigation_specify->signal_changed().connect(sigc::mem_fun(*this, &Dialog_Layout_List_Related::on_combo_navigation_specific_changed));
 
@@ -80,7 +83,7 @@ Dialog_Layout_List_Related::~Dialog_Layout_List_Related()
 }
 
 
-void Dialog_Layout_List_Related::set_document(const Glib::ustring& layout, Document_Glom* document, const sharedptr<const LayoutItem_Portal>& portal, const Glib::ustring& from_table)
+void Dialog_Layout_List_Related::set_document(const Glib::ustring& layout_name, const Glib::ustring& layout_platform, Document* document, const sharedptr<const LayoutItem_Portal>& portal, const Glib::ustring& from_table)
 {
   //Ignore the provided from_table if the portal has one:
   Glib::ustring actual_from_table;
@@ -100,7 +103,7 @@ void Dialog_Layout_List_Related::set_document(const Glib::ustring& layout, Docum
     m_portal = sharedptr<LayoutItem_Portal>::create(); //The rest of the class assumes that this is not null.
   
   type_vecLayoutFields empty_fields; //Just to satisfy the base class.
-  Dialog_Layout::set_document(layout, document, actual_from_table, empty_fields);
+  Dialog_Layout::set_document(layout_name, layout_platform, document, actual_from_table, empty_fields);
   //m_table_name is now actually the parent_table_name.
 
   update_ui();
@@ -116,7 +119,7 @@ void Dialog_Layout_List_Related::update_ui(bool including_relationship_list)
   const Glib::ustring related_table_name = m_portal->get_table_used(Glib::ustring() /* parent table - not relevant*/);
 
   //Update the tree models from the document
-  Document_Glom* document = get_document();
+  Document* document = get_document();
   if(document)
   {
     //Fill the relationships combo:
@@ -146,7 +149,7 @@ void Dialog_Layout_List_Related::update_ui(bool including_relationship_list)
 
     //Set the table name and title:
     //sharedptr<LayoutItem_Portal> portal_temp = m_portal;
-    Document_Glom::type_list_layout_groups mapGroups;
+    Document::type_list_layout_groups mapGroups;
     if(m_portal)
     {
       m_combo_relationship->set_selected_relationship(m_portal->get_relationship(), m_portal->get_related_relationship()); 
@@ -160,7 +163,7 @@ void Dialog_Layout_List_Related::update_ui(bool including_relationship_list)
 
     m_model_items->clear();
 
-    for(Document_Glom::type_list_layout_groups::const_iterator iter = mapGroups.begin(); iter != mapGroups.end(); ++iter)
+    for(Document::type_list_layout_groups::const_iterator iter = mapGroups.begin(); iter != mapGroups.end(); ++iter)
     {
       sharedptr<const LayoutGroup> group = *iter;
       sharedptr<const LayoutGroup> portal = sharedptr<const LayoutItem_Portal>::cast_dynamic(group);
@@ -186,33 +189,38 @@ void Dialog_Layout_List_Related::update_ui(bool including_relationship_list)
   }
 
   //Show the navigation information:
-  //const Document_Glom::type_vecRelationships vecRelationships = document->get_relationships(m_portal->get_relationship()->get_from_table());
+  //const Document::type_vec_relationships vecRelationships = document->get_relationships(m_portal->get_relationship()->get_from_table());
   m_combo_navigation_specify->set_relationships(document, related_table_name, true /* show related relationships */, false /* don't show parent table */); //TODO: Don't show the hidden tables, and don't show relationships that are not used by any fields.
   //m_combo_navigation_specify->set_display_parent_table(""); //This would be superfluous, and a bit confusing.
 
-  bool navigation_is_automatic = false;
-  bool navigation_specific_main = false;
-  sharedptr<UsesRelationship> navrel = m_portal->get_navigation_relationship_specific(navigation_specific_main);
-  if(navigation_specific_main)
-    m_combo_navigation_specify->set_selected_parent_table(related_table_name);
-  else if(navrel)
+  if(m_portal->get_navigation_type() == LayoutItem_Portal::NAVIGATION_SPECIFIC)
   {
+    sharedptr<UsesRelationship> navrel = m_portal->get_navigation_relationship_specific();
     //std::cout << "debug navrel=" << navrel->get_relationship()->get_name() << std::endl;
     m_combo_navigation_specify->set_selected_relationship(navrel->get_relationship(), navrel->get_related_relationship());
   }
   else
   {
-    navigation_is_automatic = true;
-
     sharedptr<const Relationship> none;
     m_combo_navigation_specify->set_selected_relationship(none);
   }
 
   //Set the appropriate radio button:
-  //std::cout << "debug: navigation_is_automatic=" << navigation_is_automatic << std::endl;
-  m_radio_navigation_automatic->set_active(navigation_is_automatic); 
-  m_radio_navigation_specify->set_active(!navigation_is_automatic); 
+  //std::cout << "debug: navrel_type=" << m_portal->get_navigation_relationship_type() << std::endl;
+  switch(m_portal->get_navigation_type())
+  {
+    case LayoutItem_Portal::NAVIGATION_NONE:
+      m_radio_navigation_none->set_active(true);
+      break;
 
+    case LayoutItem_Portal::NAVIGATION_AUTOMATIC:
+      m_radio_navigation_automatic->set_active(true);
+      break;
+
+    case LayoutItem_Portal::NAVIGATION_SPECIFIC:
+      m_radio_navigation_specify->set_active(true);
+      break;
+  }
 
   //Describe the automatic navigation:
   sharedptr<const UsesRelationship> relationship_navigation_automatic;
@@ -252,7 +260,7 @@ void Dialog_Layout_List_Related::save_to_document()
     //Get the data from the TreeView and store it in the document:
 
     //Get the groups and their fields:
-    Document_Glom::type_list_layout_groups mapGroups;
+    Document::type_list_layout_groups mapGroups;
 
     //Add the fields to the portal:
     //The code that created this dialog must read m_portal back out again.
@@ -279,20 +287,34 @@ void Dialog_Layout_List_Related::save_to_document()
       sharedptr<Relationship> rel, rel_related;
       rel = m_combo_navigation_specify->get_selected_relationship(rel_related);
 
-      bool specify_main = (!rel && !rel_related);
       sharedptr<UsesRelationship> uses_rel = sharedptr<UsesRelationship>::create();
       uses_rel->set_relationship(rel);
       uses_rel->set_related_relationship(rel_related);
 
-      m_portal->set_navigation_relationship_specific(specify_main, uses_rel);
+      if(rel || rel_related)
+        m_portal->set_navigation_relationship_specific(uses_rel);
       //std::cout << "debug99 main=specify_main" << ", relationship=" << (rel ? rel->get_name() : "none") << std::endl;
     }
     else
     {
+      // TODO: Get rid of the else branch. Cleanup code for the relations should
+      // go into the Glom::LayoutItem_Portal::set_navigation_relationship_type_* functions.
+
       //std::cout << "debug: set_navigation_relationship_specific(false, none)" << std::endl;
       sharedptr<UsesRelationship> none;
-      m_portal->set_navigation_relationship_specific(false, none);
+      m_portal->set_navigation_relationship_specific(none);
     }
+
+    if (m_radio_navigation_automatic->get_active())
+      m_portal->set_navigation_type(LayoutItem_Portal::NAVIGATION_AUTOMATIC);
+
+    if(m_radio_navigation_none->get_active())
+    {
+      sharedptr<UsesRelationship> uses_rel = sharedptr<UsesRelationship>::create();
+      uses_rel->set_related_relationship(sharedptr<Relationship>());
+      m_portal->set_navigation_type(LayoutItem_Portal::NAVIGATION_NONE);
+    }
+
   }
 }
 
