@@ -27,16 +27,16 @@
 #include <glom/utility_widgets/labelglom.h>
 #include <glom/utility_widgets/dialog_flowtable.h>
 #include <glom/utility_widgets/placeholder-glom.h>
-#include "../application.h"
+#include <glom/application.h>
 #include <gtkmm/checkbutton.h>
 #include <libglom/data_structure/glomconversions.h>
-#include <libglom/glade_utils.h>
-#include "box_data_list_related.h"
-#include "dialog_choose_relationship.h"
-#include <bakery/App/App_Gtk.h> //For util_bold_message().
-#include <glibmm/i18n.h>
+#include <glom/glade_utils.h>
+#include <glom/mode_data/box_data_list_related.h>
+#include <glom/mode_data/dialog_choose_relationship.h>
+#include <glom/utils_ui.h> //For bold_message()).
 #include <libglom/data_structure/layout/layoutitem_placeholder.h>
 #include <glom/signal_reemitter.h>
+#include <glibmm/i18n.h>
 
 namespace Glom
 {
@@ -50,13 +50,13 @@ FlowTableWithFields::Info::Info()
 
 FlowTableWithFields::FlowTableWithFields(const Glib::ustring& table_name)
 :
-#if !defined(GLIBMM_VFUNCS_ENABLED) || !defined(GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED)
+#if !defined(GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED)
   // This creates a custom GType for us, to override vfuncs and default
   // signal handlers even with the reduced API (done in flowtable.cc).
   // TODO: It is necessary to do this in all derived classes which is
   // rather annoying, though I don't see another possibility at the moment. armin.
   Glib::ObjectBase("Glom_FlowTable"),
-#endif // !defined(GLIBMM_VFUNCS_ENABLED) || !defined(GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED)
+#endif // !defined(GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED)
   m_placeholder(0),
   m_table_name(table_name)
 {
@@ -182,7 +182,7 @@ void FlowTableWithFields::add_layout_group_at_position(const sharedptr<LayoutGro
     if(!group->get_title().empty())
     {
       Gtk::Label* label = Gtk::manage( new Gtk::Label ); //TODO: This is maybe leaked, according to valgrind, though it should be managed by GtkFrame.
-      label->set_markup( Bakery::App_Gtk::util_bold_message(group->get_title()) );
+      label->set_markup( Utils::bold_message(group->get_title()) );
       label->show();
       frame->set_label_widget(*label);
     }
@@ -245,7 +245,7 @@ Box_Data_List_Related* FlowTableWithFields::create_related(const sharedptr<Layou
   if(!portal)
     return 0;
 
-  Document_Glom* pDocument = static_cast<Document_Glom*>(get_document());
+  Document* pDocument = static_cast<Document*>(get_document());
   if(pDocument)
   {
     Box_Data_List_Related* portal_box = Gtk::manage(new Box_Data_List_Related);
@@ -284,7 +284,7 @@ Box_Data_Calendar_Related* FlowTableWithFields::create_related_calendar(const sh
   if(!portal)
     return 0;
 
-  Document_Glom* pDocument = static_cast<Document_Glom*>(get_document());
+  Document* pDocument = static_cast<Document*>(get_document());
   if(pDocument)
   {
     Box_Data_Calendar_Related* portal_box = Gtk::manage(new Box_Data_Calendar_Related);
@@ -363,7 +363,7 @@ void FlowTableWithFields::add_layout_notebook_at_position(const sharedptr<Layout
       if(portal)
       {
         const Glib::ustring tab_title = glom_get_sharedptr_title_or_name(portal->get_relationship());
-        //tab_label->set_markup(Bakery::App_Gtk::util_bold_message(tab_title));
+        //tab_label->set_markup(Utils::bold_message(tab_title));
         tab_label->set_label(tab_title);
 
         //Add a Related Records list for this portal:
@@ -377,7 +377,7 @@ void FlowTableWithFields::add_layout_notebook_at_position(const sharedptr<Layout
       else
       {
         const Glib::ustring tab_title = group->get_title_or_name();
-        //tab_label->set_markup(Bakery::App_Gtk::util_bold_message(tab_title));
+        //tab_label->set_markup(Utils::bold_message(tab_title));
         tab_label->set_label(tab_title);
 
         //Add a FlowTable for this group:
@@ -699,7 +699,7 @@ void FlowTableWithFields::add_imageobject_at_position(const sharedptr<LayoutItem
   }
 }
 
-void FlowTableWithFields::get_layout_groups(Document_Glom::type_list_layout_groups& groups)
+void FlowTableWithFields::get_layout_groups(Document::type_list_layout_groups& groups)
 {
   sharedptr<LayoutGroup> group(get_layout_group());
   if(group)
@@ -742,8 +742,36 @@ void FlowTableWithFields::remove_field(const Glib::ustring& id)
 
 void FlowTableWithFields::set_field_value(const sharedptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value)
 {
+  // TODO: Avoid duplication. Maybe we can call set_other_field_value plus
+  // set the value for field's widget directly.
   //Set widgets which should show the value of this field:
-  type_list_widgets list_widgets = get_field(field);
+  type_list_widgets list_widgets = get_field(field, true);
+  for(type_list_widgets::iterator iter = list_widgets.begin(); iter != list_widgets.end(); ++iter)
+  {
+    DataWidget* datawidget = dynamic_cast<DataWidget*>(*iter);
+    if(datawidget)
+    {
+      datawidget->set_value(value);
+    }
+  }
+
+  //Refresh widgets which should show the related records for relationships that use this field:
+  type_portals list_portals = get_portals(field /* from_key field name */);
+  for(type_portals::iterator iter = list_portals.begin(); iter != list_portals.end(); ++iter)
+  {
+    Box_Data_Portal* portal = *iter;
+    if(portal)
+    {
+      //g_warning("FlowTableWithFields::set_field_value: foreign_key_value=%s", value.to_string().c_str());
+      portal->refresh_data_from_database_with_foreign_key(value /* foreign key value */);
+    }
+  }
+}
+
+void FlowTableWithFields::set_other_field_value(const sharedptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value)
+{
+  //Set widgets which should show the value of this field:
+  type_list_widgets list_widgets = get_field(field, false);
   for(type_list_widgets::iterator iter = list_widgets.begin(); iter != list_widgets.end(); ++iter)
   {
     DataWidget* datawidget = dynamic_cast<DataWidget*>(*iter);
@@ -768,7 +796,7 @@ void FlowTableWithFields::set_field_value(const sharedptr<const LayoutItem_Field
 
 Gnome::Gda::Value FlowTableWithFields::get_field_value(const sharedptr<const LayoutItem_Field>& field) const
 {
-  type_list_const_widgets list_widgets = get_field(field);
+  type_list_const_widgets list_widgets = get_field(field, true);
   if(!list_widgets.empty())
   {
     const DataWidget* datawidget = dynamic_cast<const DataWidget*>(*(list_widgets.begin()));
@@ -783,7 +811,7 @@ Gnome::Gda::Value FlowTableWithFields::get_field_value(const sharedptr<const Lay
 
 void FlowTableWithFields::set_field_editable(const sharedptr<const LayoutItem_Field>& field, bool editable)
 {
-  type_list_widgets list_widgets = get_field(field);
+  type_list_widgets list_widgets = get_field(field, true);
   for(type_list_widgets::iterator iter = list_widgets.begin(); iter != list_widgets.end(); ++iter)
   {
     DataWidget* datawidget = dynamic_cast<DataWidget*>(*iter);
@@ -840,21 +868,31 @@ FlowTableWithFields::type_portals FlowTableWithFields::get_portals(const sharedp
   return result;
 }
 
-FlowTableWithFields::type_list_const_widgets FlowTableWithFields::get_field(const sharedptr<const LayoutItem_Field>& layout_item) const
+namespace
+{
+  // Get the direct widgets represesenting a given layout item
+  // from a flowtable, without considering subflowtables:
+  template<typename InputIterator, typename OutputIterator>
+  void get_direct_fields(InputIterator begin, InputIterator end, OutputIterator out, const sharedptr<const LayoutItem_Field>& layout_item, bool include_item)
+  {
+    for(InputIterator iter = begin; iter != end; ++iter)
+    {
+      if(iter->m_field->is_same_field(layout_item) && (include_item || iter->m_field != layout_item))
+      {
+        if(iter->m_checkbutton)
+          *out++ = iter->m_checkbutton;
+        else
+          *out++ = iter->m_second;
+      }
+    }
+  }
+}
+
+FlowTableWithFields::type_list_const_widgets FlowTableWithFields::get_field(const sharedptr<const LayoutItem_Field>& layout_item, bool include_item) const
 {
   type_list_const_widgets result;
 
-  for(type_listFields::const_iterator iter = m_listFields.begin(); iter != m_listFields.end(); ++iter)
-  {
-    if( (iter->m_field->is_same_field(layout_item)) )
-    {
-      const Info& info = *iter;
-      if(info.m_checkbutton)
-        result.push_back(info.m_checkbutton);
-      else
-        result.push_back(info.m_second);
-    }
-  }
+  get_direct_fields(m_listFields.begin(), m_listFields.end(), std::back_inserter(result), layout_item, include_item);
 
   //Check the sub-flowtables:
   for(type_sub_flow_tables::const_iterator iter = m_sub_flow_tables.begin(); iter != m_sub_flow_tables.end(); ++iter)
@@ -862,7 +900,7 @@ FlowTableWithFields::type_list_const_widgets FlowTableWithFields::get_field(cons
     const FlowTableWithFields* subtable = *iter;
     if(subtable)
     {
-      type_list_const_widgets sub_list = subtable->get_field(layout_item);
+      type_list_const_widgets sub_list = subtable->get_field(layout_item, include_item);
       if(!sub_list.empty())
       {
         //Add to the main result:
@@ -874,22 +912,13 @@ FlowTableWithFields::type_list_const_widgets FlowTableWithFields::get_field(cons
   return result;
 }
 
-FlowTableWithFields::type_list_widgets FlowTableWithFields::get_field(const sharedptr<const LayoutItem_Field>& layout_item)
+FlowTableWithFields::type_list_widgets FlowTableWithFields::get_field(const sharedptr<const LayoutItem_Field>& layout_item, bool include_item)
 {
-  //TODO: Avoid duplication
   type_list_widgets result;
 
-  for(type_listFields::const_iterator iter = m_listFields.begin(); iter != m_listFields.end(); ++iter)
-  {
-    if( (iter->m_field->is_same_field(layout_item)) )
-    {
-      const Info& info = *iter;
-      if(info.m_checkbutton)
-        result.push_back(info.m_checkbutton);
-      else
-        result.push_back(info.m_second);
-    }
-  }
+  get_direct_fields(m_listFields.begin(), m_listFields.end(), std::back_inserter(result), layout_item, include_item);
+
+  //TODO: Avoid duplication
 
   //Check the sub-flowtables:
   for(type_sub_flow_tables::const_iterator iter = m_sub_flow_tables.begin(); iter != m_sub_flow_tables.end(); ++iter)
@@ -897,7 +926,7 @@ FlowTableWithFields::type_list_widgets FlowTableWithFields::get_field(const shar
     FlowTableWithFields* subtable = *iter;
     if(subtable)
     {
-      type_list_widgets sub_list = subtable->get_field(layout_item);
+      type_list_widgets sub_list = subtable->get_field(layout_item, include_item);
       if(!sub_list.empty())
       {
         //Add to the main result:
@@ -989,12 +1018,12 @@ void FlowTableWithFields::on_script_button_clicked(const sharedptr< LayoutItem_B
   m_signal_script_button_clicked.emit(layout_item);
 }
 
-void FlowTableWithFields::on_entry_edited(const Gnome::Gda::Value& value, sharedptr<const LayoutItem_Field> field)
+void FlowTableWithFields::on_entry_edited(const Gnome::Gda::Value& value, const sharedptr<const LayoutItem_Field> field)
 {
   m_signal_field_edited.emit(field, value);
 }
 
-void FlowTableWithFields::on_entry_open_details_requested(const Gnome::Gda::Value& value, sharedptr<const LayoutItem_Field> field)
+void FlowTableWithFields::on_entry_open_details_requested(const Gnome::Gda::Value& value, const sharedptr<const LayoutItem_Field> field)
 {
   m_signal_field_open_details_requested.emit(field, value);
 }
@@ -1155,24 +1184,14 @@ void FlowTableWithFields::on_portal_user_requested_details(Gnome::Gda::Value pri
   if(!portal)
     return;
 
-  const Glib::ustring related_table = portal->get_table_used(Glib::ustring() /* parent table - not relevant */);
-  if(related_table.empty())
-    return;
+  //Try to find a related (or doubly related) table that is not hidden, and open that,
+  //based on the navigation options for the portal:
+  Glib::ustring table_name;
+  Gnome::Gda::Value primary_key;
+  portal_box->get_suitable_record_to_view_details(primary_key_value, table_name, primary_key);
 
-  if(get_document()->get_table_is_hidden(related_table))
-  {
-    //Try to find a doubly-related table that is not hidden, and open that instead:
-    Glib::ustring doubly_related_table_name;
-    Gnome::Gda::Value doubly_related_primary_key;
-    portal_box->get_suitable_record_to_view_details(primary_key_value, doubly_related_table_name, doubly_related_primary_key);
-
-    if(!(doubly_related_table_name.empty()) && !Conversions::value_is_empty(doubly_related_primary_key))
-       signal_requested_related_details().emit(doubly_related_table_name, doubly_related_primary_key);
-  }
-  else
-  {
-    signal_requested_related_details().emit(related_table, primary_key_value);
-  }
+  if(!(table_name.empty()) && !Conversions::value_is_empty(primary_key))
+    signal_requested_related_details().emit(table_name, primary_key);
 }
 
 
@@ -1194,8 +1213,9 @@ void FlowTableWithFields::on_dnd_add_layout_item_field(LayoutWidgetBase* above)
     realize();
     return;
   }
+
   sharedptr<LayoutItem> item = sharedptr<LayoutItem>::cast_dynamic(layout_item_field);
-  dnd_add_to_layout_group (item, above);
+  dnd_add_to_layout_group(item, above);
   
   //Tell the parent to tell the document to save the layout
   signal_layout_changed().emit();
@@ -1212,7 +1232,7 @@ void FlowTableWithFields::on_dnd_add_layout_notebook (LayoutWidgetBase* above)
   group->set_name(_("Group"));
   notebook->m_list_items.push_back(group);
   
-  dnd_add_to_layout_group (item, above);
+  dnd_add_to_layout_group(item, above);
   
   //Tell the parent to tell the document to save the layout
   signal_layout_changed().emit();
@@ -1284,10 +1304,9 @@ void FlowTableWithFields::on_dnd_add_layout_item_image(LayoutWidgetBase* above)
   signal_layout_changed().emit();
 }
 
-void FlowTableWithFields::on_dnd_add_layout_item (LayoutWidgetBase* above,
-                                                  sharedptr<LayoutItem>& item)
+void FlowTableWithFields::on_dnd_add_layout_item(LayoutWidgetBase* above, const sharedptr<LayoutItem>& item)
 {
-  dnd_add_to_layout_group (item, above);
+  dnd_add_to_layout_group(item, above);
   
   // Don't do this here - it's done in the drag_end handler
   // signal_layout_changed().emit();
@@ -1307,8 +1326,8 @@ void FlowTableWithFields::on_dnd_add_placeholder(LayoutWidgetBase* above)
                                                             above);
   sharedptr<LayoutItem_Placeholder> placeholder_field(new LayoutItem_Placeholder);
   sharedptr<LayoutItem> item = sharedptr<LayoutItem>::cast_dynamic(placeholder_field);  
-  add_layout_item_at_position (placeholder_field, cur_widget);
-  dnd_add_to_layout_group (item, above, true /* ignore error*/);
+  add_layout_item_at_position(placeholder_field, cur_widget);
+  dnd_add_to_layout_group(item, above, true /* ignore error*/);
 }
 
 void FlowTableWithFields::on_dnd_remove_placeholder()
@@ -1347,9 +1366,7 @@ void FlowTableWithFields::dnd_notify_failed_drop()
   dialog.run();
 }
 
-bool FlowTableWithFields::dnd_add_to_layout_group (sharedptr<LayoutItem>& item, 
-                                                   LayoutWidgetBase* layoutwidget,
-                                                   bool ignore_error)
+bool FlowTableWithFields::dnd_add_to_layout_group(const sharedptr<LayoutItem>& item,  LayoutWidgetBase* layoutwidget, bool ignore_error)
 {
   //Get the layout group that the "above" widget's layout item is in:
   sharedptr<LayoutGroup> layout_group = get_layout_group();
@@ -1369,51 +1386,11 @@ bool FlowTableWithFields::dnd_add_to_layout_group (sharedptr<LayoutItem>& item,
   return true;
 }
 
-#endif // !GLOM_ENABLE_CLIENT_ONLY
-
-sharedptr<LayoutItem_Portal> FlowTableWithFields::get_layout_item_from_relation()
-{
-  sharedptr<LayoutItem_Portal> layout_item(0);
-  try
-  {
-    Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom.glade"), "dialog_choose_relationship");
-
-    Dialog_ChooseRelationship* dialog = 0;
-    refXml->get_widget_derived("dialog_choose_relationship", dialog);
-
-    if(dialog)
-    {
-      Document_Glom* pDocument = static_cast<Document_Glom*>(get_document());
-      dialog->set_document(pDocument, m_table_name);
-      //TODO: dialog->set_transient_for(*get_app_window());
-      const int response = dialog->run();
-      dialog->hide();
-      if(response == Gtk::RESPONSE_OK)
-      {
-        //Get the chosen relationship:
-        sharedptr<Relationship> relationship  = dialog->get_relationship_chosen();
-        if(relationship)
-        {
-          layout_item = sharedptr<LayoutItem_Portal>::create();
-          layout_item->set_relationship(relationship);
-        }
-      }
-      delete dialog;
-    }
-  }
-  catch(const Gnome::Glade::XmlError& ex)
-  {
-    std::cerr << ex.what() << std::endl;
-  }
-  return layout_item;
-}
-
-#ifndef GLOM_ENABLE_CLIENT_ONLY
 void FlowTableWithFields::on_menu_properties_activate()
 {
   try
   {
-    Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "dialog_flowtable");
+    Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "dialog_flowtable");
 
     Dialog_FlowTable* dialog = 0;
     refXml->get_widget_derived("dialog_flowtable", dialog);
@@ -1433,7 +1410,7 @@ void FlowTableWithFields::on_menu_properties_activate()
       delete dialog;
     }
   }
-  catch(const Gnome::Glade::XmlError& ex)
+  catch(const Gtk::BuilderError& ex)
   {
     std::cerr << ex.what() << std::endl;
   }
@@ -1487,14 +1464,14 @@ sharedptr<LayoutItem_Portal> FlowTableWithFields::get_portal_relationship()
 {
   try
   {
-    Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "dialog_choose_relationship");
+    Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "dialog_choose_relationship");
     
     Dialog_ChooseRelationship* dialog = 0;
     refXml->get_widget_derived("dialog_choose_relationship", dialog);
     
     if(dialog)
     {
-      Document_Glom* pDocument = static_cast<Document_Glom*>(get_document());
+      Document* pDocument = static_cast<Document*>(get_document());
       dialog->set_document(pDocument, m_table_name);
       //TODO: dialog->set_transient_for(*get_app_window());
       const int response = dialog->run();
@@ -1514,7 +1491,7 @@ sharedptr<LayoutItem_Portal> FlowTableWithFields::get_portal_relationship()
       delete dialog;
     }
   }
-  catch(const Gnome::Glade::XmlError& ex)
+  catch(const Gtk::BuilderError& ex)
   {
     std::cerr << ex.what() << std::endl;
   }
