@@ -32,12 +32,12 @@
 namespace Glom
 {
 
-Dialog_FieldCalculation::Dialog_FieldCalculation(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
+Dialog_FieldCalculation::Dialog_FieldCalculation(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Gtk::Dialog(cobject)
 {
-  refGlade->get_widget("textview_calculation",  m_text_view);
-  refGlade->get_widget("button_test",  m_button_test);
-  refGlade->get_widget("label_triggered_by", m_label_triggered_by);
+  builder->get_widget("textview_calculation",  m_text_view);
+  builder->get_widget("button_test",  m_button_test);
+  builder->get_widget("label_triggered_by", m_label_triggered_by);
 
   m_button_test->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_FieldCalculation::on_button_test) );
   //on_foreach_connect(*this);
@@ -110,11 +110,11 @@ void Dialog_FieldCalculation::on_button_test()
 
   type_map_fields field_values;
 
-  Document_Glom* document = get_document();
+  Document* document = get_document();
   if(document)
   {
-    const Document_Glom::type_vecFields fields = document->get_table_fields(m_table_name);
-    for(Document_Glom::type_vecFields::const_iterator iter = fields.begin(); iter != fields.end(); ++iter)
+    const Document::type_vec_fields fields = document->get_table_fields(m_table_name);
+    for(Document::type_vec_fields::const_iterator iter = fields.begin(); iter != fields.end(); ++iter)
     {
       const sharedptr<const Field> field = *iter;
       const Gnome::Gda::Value example_value = Conversions::get_example_value(field->get_glom_type());
