@@ -22,8 +22,8 @@
 #define DIALOG_FIELDCALCULATION_H
 
 #include <gtkmm.h>
-#include <libglademm.h>
-#include <glom/libglom/data_structure/field.h>
+#include <gtkmm/builder.h>
+#include <libglom/data_structure/field.h>
 #include "../../base_db.h"
 #include <gtksourceviewmm/sourceview.h>
 
@@ -36,14 +36,15 @@ class Dialog_FieldCalculation
 
 {
 public:
-  Dialog_FieldCalculation(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
+  Dialog_FieldCalculation(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
   virtual ~Dialog_FieldCalculation();
 
-  virtual void set_field(const sharedptr<const Field>& field, const Glib::ustring& table_name);
-  virtual sharedptr<Field> get_field() const;
+  void set_field(const sharedptr<const Field>& field, const Glib::ustring& table_name);
+  sharedptr<Field> get_field() const;
 
-protected:
-  virtual void on_button_test();
+private:
+  void on_button_test();
+  bool check_for_return_statement(const Glib::ustring& calculation);
 
   gtksourceview::SourceView* m_text_view;
   Gtk::Button* m_button_test;
