@@ -20,7 +20,7 @@
  */
 
 #include "canvas_print_layout.h"
-#include <bakery/App/App_Gtk.h> //For util_bold_message().
+#include <glom/utils_ui.h> //For bold_message()).
 #include <gtkmm/stock.h>
 #include <glom/mode_design/print_layouts/dialog_text_formatting.h>
 #include <glom/mode_data/dialog_layout_list_related.h>
@@ -29,9 +29,9 @@
 #include <glom/utility_widgets/canvas/canvas_table_movable.h>
 #include <glom/utility_widgets/canvas/canvas_image_movable.h>
 #include <glom/utility_widgets/canvas/canvas_text_movable.h>
-#include <glom/libglom/data_structure/glomconversions.h>
+#include <libglom/data_structure/glomconversions.h>
 
-#include <glom/libglom/glade_utils.h>
+#include <glom/glade_utils.h>
 #include <glibmm/i18n.h>
 
 namespace Glom
@@ -78,10 +78,15 @@ void Canvas_PrintLayout::set_print_layout(const Glib::ustring& table_name, const
   remove_all_items(m_items_group);
   add_layout_group(print_layout->m_layout_group, true /* is top-level */);
 
-  //TODO: Use PageSetup::copy() when we can use gtkmm 2.14:
   Glib::RefPtr<Gtk::PageSetup> page_setup;
-  if(print_layout->get_page_setup())
-    page_setup = Glib::wrap( gtk_page_setup_copy(const_cast<GtkPageSetup*>(print_layout->get_page_setup()->gobj())) );
+  const Glib::ustring key_file_text = print_layout->get_page_setup();
+  if(!key_file_text.empty())
+  {
+    Glib::KeyFile key_file;
+    key_file.load_from_data(key_file_text);
+    //TODO: Use this when gtkmm and GTK+ have been fixed: page_setup = Gtk::PageSetup::create(key_file);
+    page_setup = Glib::wrap(gtk_page_setup_new_from_key_file(key_file.gobj(), NULL, NULL));
+  }
 
   set_page_setup(page_setup);
 
@@ -92,7 +97,12 @@ sharedptr<PrintLayout> Canvas_PrintLayout::get_print_layout()
 {
   sharedptr<PrintLayout> result = sharedptr<PrintLayout>::create();
   fill_layout_group(result->m_layout_group);
-  result->set_page_setup(m_page_setup);
+
+  //Page Setup:
+  Glib::KeyFile key_file;
+  m_page_setup->save_to_key_file(key_file);
+  result->set_page_setup(key_file.to_data());
+
   return result;
 }
 
@@ -298,7 +308,7 @@ sharedptr<LayoutItem_Portal> Canvas_PrintLayout::offer_related_records(const sha
 
   Dialog_Layout_List_Related* dialog = 0;
 
-  Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "window_data_layout");
+  Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "window_data_layout");
   if(refXml)
     refXml->get_widget_derived("window_data_layout", dialog);
   
@@ -369,7 +379,7 @@ void Canvas_PrintLayout::on_context_menu_edit()
 
   m_modified = true;
 
-  m_context_item.clear();
+  m_context_item.reset();
 }
 
 void Canvas_PrintLayout::on_context_menu_formatting()
@@ -394,13 +404,13 @@ void Canvas_PrintLayout::on_context_menu_formatting()
 
   try
   {
-    Glib::RefPtr<Gnome::Glade::Xml> refXmlFormatting = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "window_text_format");
+    Glib::RefPtr<Gtk::Builder> refXmlFormatting = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "window_text_format");
     refXmlFormatting->get_widget_derived("window_text_format", m_dialog_format);
     add_view(m_dialog_format);
 
     m_dialog_format->signal_hide().connect( sigc::mem_fun(*this, &Canvas_PrintLayout::on_dialog_format_hide) );
   }
-  catch(const Gnome::Glade::XmlError& ex)
+  catch(const Gtk::BuilderError& ex)
   {
     std::cerr << ex.what() << std::endl;
   }
@@ -425,7 +435,7 @@ void Canvas_PrintLayout::on_context_menu_formatting()
 void Canvas_PrintLayout::on_context_menu_delete()
 {
   m_context_item->remove();
-  m_context_item.clear();
+  m_context_item.reset();
 }
 
 void Canvas_PrintLayout::on_dialog_format_hide()
@@ -495,7 +505,7 @@ void Canvas_PrintLayout::set_page_setup(const Glib::RefPtr<Gtk::PageSetup>& page
   if(m_bounds_group)
   {
     m_bounds_group->remove();
-    m_bounds_group.clear();
+    m_bounds_group.reset();
   }
 
   Glib::RefPtr<Goocanvas::Item> root = get_root_item();
@@ -686,7 +696,7 @@ void Canvas_PrintLayout::fill_with_data_portal(const Glib::RefPtr<CanvasLayoutIt
 
   const Glib::ustring sql_query = Utils::build_sql_select_with_where_clause(found_set.m_table_name, fields_shown, found_set.m_where_clause, found_set.m_extra_join, found_set.m_sort_clause, found_set.m_extra_group_by);
   //std::cout << "DEBUG: sql_query=" << sql_query << std::endl;
-  Glib::RefPtr<Gnome::Gda::DataModel> datamodel = query_execute_select(sql_query, 0 /* TODO: get_app_window() */);
+  Glib::RefPtr<Gnome::Gda::DataModel> datamodel = query_execute_select(sql_query);
   if(!(datamodel))
     return;
     
@@ -746,7 +756,7 @@ void Canvas_PrintLayout::set_canvas_item_field_value(const Glib::RefPtr<Goocanva
     if(!canvas_image)
       return;
 
-    Glib::RefPtr<Gdk::Pixbuf> pixbuf = Conversions::get_pixbuf_for_gda_value(value);
+    Glib::RefPtr<Gdk::Pixbuf> pixbuf = Utils::get_pixbuf_for_gda_value(value);
     canvas_image->property_pixbuf() = pixbuf;
   }
   else //text, numbers, date, time, boolean:
@@ -835,13 +845,13 @@ Glib::RefPtr<Goocanvas::Item> Canvas_PrintLayout::get_canvas_table_cell_child(co
 
 Base_DB::type_vecLayoutFields Canvas_PrintLayout::get_portal_fields_to_show(const sharedptr<LayoutItem_Portal>& portal)
 {
-  const Document_Glom* document = get_document();
+  const Document* document = get_document();
   if(!document)
     std::cerr << "Canvas_PrintLayout::get_portal_fields_to_show(): document is NULL." << std::endl;
 
   if(document && portal)
   {
-    Document_Glom::type_list_layout_groups mapGroups;
+    Document::type_list_layout_groups mapGroups;
     mapGroups.push_back(portal);
 
     sharedptr<const Relationship> relationship = portal->get_relationship();
