@@ -18,16 +18,16 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include "box_tables.h"
-#include <bakery/App/App_Gtk.h> //For util_bold_message().
+#include <glom/navigation/box_tables.h>
+#include <glom/utils_ui.h> //For bold_message()).
 #include <glom/application.h>
 #include <glibmm/i18n.h>
 
 namespace Glom
 {
 
-Box_Tables::Box_Tables(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
-: Box_WithButtons(cobject, refGlade),
+Box_Tables::Box_Tables(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
+: Box_WithButtons(cobject, builder),
   m_pLabelFrameTitle(0),
   m_pCheckButtonShowHidden(0),
   m_colTableName(0),
@@ -37,16 +37,16 @@ Box_Tables::Box_Tables(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade:
 {
   //Get the Glade-instantiated widgets, and connect signal handlers:
   Gtk::Button* pButtonCancel = 0;
-  refGlade->get_widget("button_cancel", pButtonCancel);
+  builder->get_widget("button_cancel", pButtonCancel);
   set_button_cancel(*pButtonCancel);
 
   Gtk::Alignment* pAligmentPlaceholder = 0;
-  refGlade->get_widget("alignment_placeholder_adddel", pAligmentPlaceholder);
+  builder->get_widget("alignment_placeholder_adddel", pAligmentPlaceholder);
   pAligmentPlaceholder->add(m_AddDel);
 
-  refGlade->get_widget("label_frame_title", m_pLabelFrameTitle);
+  builder->get_widget("label_frame_title", m_pLabelFrameTitle);
 
-  refGlade->get_widget("checkbutton_show_hidden", m_pCheckButtonShowHidden);
+  builder->get_widget("checkbutton_show_hidden", m_pCheckButtonShowHidden);
   m_pCheckButtonShowHidden->signal_toggled().connect(sigc::mem_fun(*this, &Box_Tables::on_show_hidden_toggled));
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
@@ -96,7 +96,7 @@ void Box_Tables::fill_table_row(const Gtk::TreeModel::iterator& iter, const shar
 
 bool Box_Tables::fill_from_database()
 {
-  Bakery::BusyCursor busy_cursor(App_Glom::get_application());
+  BusyCursor busy_cursor(App_Glom::get_application());
 
   bool result = Base_DB::fill_from_database();
 
@@ -137,8 +137,8 @@ bool Box_Tables::fill_from_database()
 
   //Get the list of hidden tables:
 
-  Document_Glom::type_listTableInfo listTablesDocument;
-  Document_Glom* document = get_document();
+  Document::type_listTableInfo listTablesDocument;
+  Document* document = get_document();
   if(document)
   {
     listTablesDocument = document->get_tables();
@@ -160,16 +160,16 @@ bool Box_Tables::fill_from_database()
     m_AddDel.remove_all();
     Glib::RefPtr<Gnome::Gda::Connection> connection = sharedconnection->get_gda_connection();
 
-    const type_vecStrings vecTables = get_table_names_from_database();
+    const type_vec_strings vecTables = get_table_names_from_database();
 
-    for(type_vecStrings::const_iterator iter = vecTables.begin(); iter != vecTables.end(); iter++)
+    for(type_vec_strings::const_iterator iter = vecTables.begin(); iter != vecTables.end(); iter++)
     {
       const Glib::ustring strName = *iter;
 
       sharedptr<TableInfo> table_info;
 
       //Check whether it should be hidden:
-      Document_Glom::type_listTableInfo::const_iterator iterFind = std::find_if(listTablesDocument.begin(), listTablesDocument.end(), predicate_FieldHasName<TableInfo>(strName));
+      Document::type_listTableInfo::const_iterator iterFind = std::find_if(listTablesDocument.begin(), listTablesDocument.end(), predicate_FieldHasName<TableInfo>(strName));
       if(iterFind != listTablesDocument.end())
       {
         table_info = *iterFind;
@@ -232,7 +232,7 @@ void Box_Tables::on_adddel_Add(const Gtk::TreeModel::iterator& row)
   if(exists_in_db)
   {
     //Ask the user if they want us to try to cope with this:
-    Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("Table Already Exists")), true, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL);
+    Gtk::MessageDialog dialog(Utils::bold_message(_("Table Already Exists")), true, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL);
     dialog.set_secondary_text(_("This table already exists on the database server, though it is not mentioned in the .glom file. This should not happen. Would you like Glom to attempt to use the existing table?"));
     dialog.set_transient_for(*App_Glom::get_application());
 
@@ -254,7 +254,7 @@ void Box_Tables::on_adddel_Add(const Gtk::TreeModel::iterator& row)
   {
     //Show the new information for this whole row:
     
-    Document_Glom* document = get_document();
+    Document* document = get_document();
     if(document)
     {
       sharedptr<TableInfo> table_info = document->get_table(table_name);
@@ -263,7 +263,7 @@ void Box_Tables::on_adddel_Add(const Gtk::TreeModel::iterator& row)
       //Save the field information directly into the database, because we cannot get all the correct information from the database.
       //Otherwise some information would be forgotten:
 
-      type_vecFields fields = document->get_table_fields(table_name);
+      type_vec_fields fields = document->get_table_fields(table_name);
       document->set_table_fields(table_name, fields);
 
       //TODO: Just let create_table_with_default_fields() update the document, and then reload the row.
@@ -286,7 +286,7 @@ void Box_Tables::on_adddel_Delete(const Gtk::TreeModel::iterator& rowStart, cons
 
     if(!table_name.empty())
     {
-      Document_Glom* document = get_document();
+      Document* document = get_document();
       if(document)
       {
         //Don't open a table that the document does not know about, because we need information from the document:
@@ -301,7 +301,7 @@ void Box_Tables::on_adddel_Delete(const Gtk::TreeModel::iterator& rowStart, cons
         {
           //Ask the user to confirm:
           Glib::ustring strMsg = _("Are you sure that you want to delete this table?\nTable name: ") + table_name;
-          Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("Delete Table")), true);
+          Gtk::MessageDialog dialog(Utils::bold_message(_("Delete Table")), true);
           dialog.set_secondary_text(strMsg);
           dialog.set_transient_for(*App_Glom::get_application());
           int iButtonClicked = dialog.run();
@@ -387,7 +387,7 @@ void Box_Tables::on_adddel_changed(const Gtk::TreeModel::iterator& row, guint co
             set_modified();
 
             //Tell the document that this table's name has changed:
-            Document_Glom* document = get_document();
+            Document* document = get_document();
             if(document)
               document->change_table_name(table_name, table_name_new);
 
@@ -404,14 +404,14 @@ void Box_Tables::on_adddel_Edit(const Gtk::TreeModel::iterator& row)
 {
   Glib::ustring table_name = m_AddDel.get_value_key(row);
 
-  Document_Glom* document = get_document();
+  Document* document = get_document();
   if(document)
   {
     //Don't open a table that the document does not know about, because we need information from the document:
     //This should never happen, because we never show them in the list:
     if(false) //Let's see if we can adapt.  (!document->get_table_is_known(table_name))
     {
-       Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("Unknown Table")), true);
+       Gtk::MessageDialog dialog(Utils::bold_message(_("Unknown Table")), true);
        dialog.set_secondary_text(_("You cannot open this table, because there is no information about this table in the document."));
        dialog.set_transient_for(*App_Glom::get_application());
        dialog.run();
@@ -433,9 +433,9 @@ void Box_Tables::save_to_document()
   if(get_userlevel() == AppState::USERLEVEL_DEVELOPER)
   {
     //Save the hidden tables. TODO_usermode: Only if we are in developer mode.
-    Document_Glom::type_listTableInfo listTables;
+    Document::type_listTableInfo listTables;
 
-    Document_Glom* document = get_document();
+    Document* document = get_document();
 
     for(Gtk::TreeModel::iterator iter = m_AddDel.get_model()->children().begin(); iter != m_AddDel.get_model()->children().end(); ++iter)
     {
