@@ -22,7 +22,7 @@
 #define NOTEBOOK_GLOM_H
 
 #include "box_withbuttons.h"
-#include <libglom/document/document_glom.h>
+#include <libglom/document/document.h>
 
 namespace Glom
 {
