@@ -19,31 +19,31 @@
  */
 
 #include "dialog_layout_report.h"
-#include <glom/libglom/data_structure/layout/report_parts/layoutitem_groupby.h>
-#include <glom/libglom/data_structure/layout/report_parts/layoutitem_summary.h>
-#include <glom/libglom/data_structure/layout/report_parts/layoutitem_fieldsummary.h>
-#include <glom/libglom/data_structure/layout/report_parts/layoutitem_verticalgroup.h>
-#include <glom/libglom/data_structure/layout/report_parts/layoutitem_header.h>
-#include <glom/libglom/data_structure/layout/report_parts/layoutitem_footer.h>
-#include <glom/libglom/data_structure/layout/layoutitem_field.h>
-#include <glom/libglom/data_structure/layout/layoutitem_text.h>
-#include <glom/libglom/data_structure/layout/layoutitem_image.h>
-#include <glom/libglom/glade_utils.h>
+#include <libglom/data_structure/layout/report_parts/layoutitem_groupby.h>
+#include <libglom/data_structure/layout/report_parts/layoutitem_summary.h>
+#include <libglom/data_structure/layout/report_parts/layoutitem_fieldsummary.h>
+#include <libglom/data_structure/layout/report_parts/layoutitem_verticalgroup.h>
+#include <libglom/data_structure/layout/report_parts/layoutitem_header.h>
+#include <libglom/data_structure/layout/report_parts/layoutitem_footer.h>
+#include <libglom/data_structure/layout/layoutitem_field.h>
+#include <libglom/data_structure/layout/layoutitem_text.h>
+#include <libglom/data_structure/layout/layoutitem_image.h>
+#include <glom/glade_utils.h>
 #include "../mode_data/dialog_choose_field.h"
 #include "../layout_item_dialogs/dialog_field_layout.h"
 #include "../layout_item_dialogs/dialog_group_by.h"
 #include "../layout_item_dialogs/dialog_field_summary.h"
 #include "../mode_data/dialog_choose_relationship.h"
 //#include <libgnome/gnome-i18n.h>
-#include <bakery/App/App_Gtk.h> //For util_bold_message().
+#include <libglom/utils.h> //For bold_message()).
 #include <glibmm/i18n.h>
 #include <sstream> //For stringstream
 
 namespace Glom
 {
 
-Dialog_Layout_Report::Dialog_Layout_Report(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
-: Dialog_Layout(cobject, refGlade, false /* No table title */),
+Dialog_Layout_Report::Dialog_Layout_Report(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
+: Dialog_Layout(cobject, builder, false /* No table title */),
   m_notebook_parts(0),
   m_treeview_parts_header(0),
   m_treeview_parts_footer(0),
@@ -60,34 +60,34 @@ Dialog_Layout_Report::Dialog_Layout_Report(BaseObjectType* cobject, const Glib::
   m_entry_title(0),
   m_checkbutton_table_title(0)
 {
-  refGlade->get_widget("label_table_name", m_label_table_name);
-  refGlade->get_widget("entry_name", m_entry_name);
-  refGlade->get_widget("entry_title", m_entry_title);
-  refGlade->get_widget("checkbutton_table_title", m_checkbutton_table_title);
+  builder->get_widget("label_table_name", m_label_table_name);
+  builder->get_widget("entry_name", m_entry_name);
+  builder->get_widget("entry_title", m_entry_title);
+  builder->get_widget("checkbutton_table_title", m_checkbutton_table_title);
 
-  refGlade->get_widget("button_up", m_button_up);
+  builder->get_widget("button_up", m_button_up);
   m_button_up->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_Layout_Report::on_button_up) );
 
-  refGlade->get_widget("button_down", m_button_down);
+  builder->get_widget("button_down", m_button_down);
   m_button_down->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_Layout_Report::on_button_down) );
 
-  refGlade->get_widget("button_delete", m_button_delete);
+  builder->get_widget("button_delete", m_button_delete);
   m_button_delete->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_Layout_Report::on_button_delete) );
 
-  refGlade->get_widget("button_add", m_button_add);
+  builder->get_widget("button_add", m_button_add);
   m_button_add->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_Layout_Report::on_button_add) );
 
-  refGlade->get_widget("button_edit", m_button_edit);
+  builder->get_widget("button_edit", m_button_edit);
   m_button_edit->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_Layout_Report::on_button_edit) );
 
-  refGlade->get_widget("button_formatting", m_button_formatting);
+  builder->get_widget("button_formatting", m_button_formatting);
   m_button_formatting->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_Layout_Report::on_button_formatting) );
 
-  refGlade->get_widget("notebook_parts", m_notebook_parts);
+  builder->get_widget("notebook_parts", m_notebook_parts);
   m_notebook_parts->set_current_page(1); //The main part, because it is used most often.
 
   //Available parts:
-  refGlade->get_widget("treeview_available_parts", m_treeview_available_parts);
+  builder->get_widget("treeview_available_parts", m_treeview_available_parts);
   if(m_treeview_available_parts)
   {
     //Add list of available parts:
@@ -165,11 +165,11 @@ Dialog_Layout_Report::Dialog_Layout_Report(BaseObjectType* cobject, const Glib::
     }
   }
 
-  refGlade->get_widget("treeview_parts_header", m_treeview_parts_header);
+  builder->get_widget("treeview_parts_header", m_treeview_parts_header);
   setup_model(*m_treeview_parts_header, m_model_parts_header);
-  refGlade->get_widget("treeview_parts_footer", m_treeview_parts_footer);
+  builder->get_widget("treeview_parts_footer", m_treeview_parts_footer);
   setup_model(*m_treeview_parts_footer, m_model_parts_footer);
-  refGlade->get_widget("treeview_parts_main", m_treeview_parts_main);
+  builder->get_widget("treeview_parts_main", m_treeview_parts_main);
   setup_model(*m_treeview_parts_main, m_model_parts_main);
 
 
@@ -328,7 +328,7 @@ void Dialog_Layout_Report::add_group(const Glib::RefPtr<type_model>& model_parts
   }
 }
 
-//void Dialog_Layout_Report::set_document(const Glib::ustring& layout, Document_Glom* document, const Glib::ustring& table_name, const type_vecLayoutFields& table_fields)
+//void Dialog_Layout_Report::set_document(const Glib::ustring& layout, Document* document, const Glib::ustring& table_name, const type_vecLayoutFields& table_fields)
 void Dialog_Layout_Report::set_report(const Glib::ustring& table_name, const sharedptr<const Report>& report)
 {
   m_modified = false;
@@ -631,14 +631,20 @@ void Dialog_Layout_Report::on_button_add()
   Glib::RefPtr<type_model> model_available = Glib::RefPtr<type_model>::cast_dynamic(m_treeview_available_parts->get_model());
 
   Gtk::TreeModel::iterator parent = get_selected_group_parent();
-  sharedptr<LayoutItem> pParentPart;
+  sharedptr<const LayoutItem> pParentPart;
   if(parent)
-    pParentPart = (*parent)[m_model_available_parts_main->m_columns.m_col_item];
+  {
+    sharedptr<LayoutItem> temp = (*parent)[m_model_available_parts_main->m_columns.m_col_item];
+    pParentPart = temp;
+  }
 
   Gtk::TreeModel::iterator available = get_selected_available();
-  sharedptr<LayoutItem> pAvailablePart;
+  sharedptr<const LayoutItem> pAvailablePart;
   if(available)
-    pAvailablePart = (*available)[model_available->m_columns.m_col_item];
+  {
+    sharedptr<LayoutItem> temp = (*available)[model_available->m_columns.m_col_item];
+    pAvailablePart = temp;
+  }
 
 
   //Check whether the available part may be a child of the selected parent:
@@ -649,7 +655,9 @@ void Dialog_Layout_Report::on_button_add()
     parent = (*parent).parent();
     if(parent)
     {
-      pParentPart = (*parent)[model_available->m_columns.m_col_item];
+      sharedptr<LayoutItem> temp = (*parent)[model_available->m_columns.m_col_item];
+      pParentPart = temp;
+
       if(!TreeStore_ReportLayout::may_be_child_of(pParentPart, pAvailablePart))
         return; //Not allowed either.
     }
@@ -683,7 +691,7 @@ sharedptr<Relationship> Dialog_Layout_Report::offer_relationship_list()
 
   try
   {
-    Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "dialog_choose_relationship");
+    Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "dialog_choose_relationship");
 
     Dialog_ChooseRelationship* dialog = 0;
     refXml->get_widget_derived("dialog_choose_relationship", dialog);
@@ -703,7 +711,7 @@ sharedptr<Relationship> Dialog_Layout_Report::offer_relationship_list()
       delete dialog;
     }
   }
-  catch(const Gnome::Glade::XmlError& ex)
+  catch(const Gtk::BuilderError& ex)
   {
     std::cerr << ex.what() << std::endl;
   }
@@ -820,7 +828,7 @@ void Dialog_Layout_Report::on_button_edit()
       {
         try
         {
-          Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "dialog_field_summary");
+          Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "dialog_field_summary");
 
           Dialog_FieldSummary* dialog = 0;
           refXml->get_widget_derived("dialog_field_summary", dialog);
@@ -851,7 +859,7 @@ void Dialog_Layout_Report::on_button_edit()
             delete dialog;
           }
         }
-        catch(const Gnome::Glade::XmlError& ex)
+        catch(const Gtk::BuilderError& ex)
         {
           std::cerr << ex.what() << std::endl;
         }
@@ -902,7 +910,7 @@ void Dialog_Layout_Report::on_button_edit()
               {
                 try
                 {
-                  Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "dialog_group_by");
+                  Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "dialog_group_by");
   
                   Dialog_GroupBy* dialog = 0;
                   refXml->get_widget_derived("dialog_group_by", dialog);
@@ -932,7 +940,7 @@ void Dialog_Layout_Report::on_button_edit()
                     delete dialog;
                   }
                 }
-                catch(const Gnome::Glade::XmlError& ex)
+                catch(const Gtk::BuilderError& ex)
                 {
                   std::cerr << ex.what() << std::endl;
                 }
