@@ -22,16 +22,16 @@
 #include "combobox_locale.h"
 #include "dialog_identify_original.h"
 #include "dialog_copy_translation.h"
-#include <bakery/App/App_Gtk.h> //For util_bold_message().
+#include <glom/utils_ui.h> //For bold_message()).
 #include <libglom/utils.h>
-#include <libglom/glade_utils.h>
+#include <glom/glade_utils.h>
 
 #include <glibmm/i18n.h>
 #include <string.h> // for memset
 
 // To read the .po files
 #include <gettext-po.h>
-#include "config.h" //For HAVE_GETTEXTPO_XERROR
+#include <config.h> //For HAVE_GETTEXTPO_XERROR
 
 #include <sstream>
 
@@ -42,7 +42,7 @@
 namespace Glom
 {
 
-Window_Translations::Window_Translations(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
+Window_Translations::Window_Translations(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Gtk::Window(cobject),
   m_treeview(0),
   m_button_identify(0),
@@ -54,9 +54,9 @@ Window_Translations::Window_Translations(BaseObjectType* cobject, const Glib::Re
   m_button_export(0),
   m_treeview_modified(false)
 {
-  refGlade->get_widget("label_source_locale", m_label_source_locale);
+  builder->get_widget("label_source_locale", m_label_source_locale);
 
-  refGlade->get_widget("treeview", m_treeview);
+  builder->get_widget("treeview", m_treeview);
   if(m_treeview)
   {
     m_model = Gtk::ListStore::create(m_columns);
@@ -85,25 +85,25 @@ Window_Translations::Window_Translations(BaseObjectType* cobject, const Glib::Re
       renderer->signal_edited().connect(sigc::mem_fun(*this, &Window_Translations::on_treeview_edited));
   }
 
-  refGlade->get_widget("button_identify", m_button_identify);
+  builder->get_widget("button_identify", m_button_identify);
   m_button_identify->signal_clicked().connect( sigc::mem_fun(*this, &Window_Translations::on_button_identify) );
 
-  refGlade->get_widget_derived("combobox_target_locale", m_combo_target_locale);
+  builder->get_widget_derived("combobox_target_locale", m_combo_target_locale);
   m_combo_target_locale->signal_changed().connect(sigc::mem_fun(*this, &Window_Translations::on_combo_target_locale_changed));
 
-  refGlade->get_widget("button_ok", m_button_ok);
+  builder->get_widget("button_ok", m_button_ok);
   m_button_ok->signal_clicked().connect( sigc::mem_fun(*this, &Window_Translations::on_button_ok) );
 
-  refGlade->get_widget("button_cancel", m_button_cancel);
+  builder->get_widget("button_cancel", m_button_cancel);
   m_button_cancel->signal_clicked().connect( sigc::mem_fun(*this, &Window_Translations::on_button_cancel) );
 
-  refGlade->get_widget("button_copy_translation", m_button_copy_translation);
+  builder->get_widget("button_copy_translation", m_button_copy_translation);
   m_button_copy_translation->signal_clicked().connect( sigc::mem_fun(*this, &Window_Translations::on_button_copy_translation) );
 
-  refGlade->get_widget("button_import", m_button_import);
+  builder->get_widget("button_import", m_button_import);
   m_button_import->signal_clicked().connect( sigc::mem_fun(*this, &Window_Translations::on_button_import) );
 
-  refGlade->get_widget("button_export", m_button_export);
+  builder->get_widget("button_export", m_button_export);
   m_button_export->signal_clicked().connect( sigc::mem_fun(*this, &Window_Translations::on_button_export) );
 
   show_all_children();
@@ -129,7 +129,7 @@ void Window_Translations::enable_buttons()
 
 void Window_Translations::on_button_identify()
 {
-  Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "dialog_translation_identify_original");
+  Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "dialog_translation_identify_original");
   if(refXml)
   {
     Dialog_IdentifyOriginal* dialog = 0;
@@ -208,7 +208,7 @@ void Window_Translations::load_from_document()
 {
   m_model->clear(); //Remove all rows.
 
-  Document_Glom* document = get_document();
+  Document* document = get_document();
   if(!document)
     return;
 
@@ -219,8 +219,8 @@ void Window_Translations::load_from_document()
   m_label_source_locale->set_text(original_locale_name);
 
   //Add tables:
-  Document_Glom::type_listTableInfo tables = document->get_tables();
-  for(Document_Glom::type_listTableInfo::const_iterator iter = tables.begin(); iter != tables.end(); ++iter)
+  Document::type_listTableInfo tables = document->get_tables();
+  for(Document::type_listTableInfo::const_iterator iter = tables.begin(); iter != tables.end(); ++iter)
   {
     sharedptr<TableInfo> tableinfo = *iter;
     const Glib::ustring table_name = tableinfo->get_name();
@@ -233,8 +233,8 @@ void Window_Translations::load_from_document()
     row[m_columns.m_col_parent_table] = Glib::ustring(); //Not used for tables.
 
     //The table's field titles:
-    Document_Glom::type_vecFields fields = document->get_table_fields(table_name);
-    for(Document_Glom::type_vecFields::iterator iter = fields.begin(); iter != fields.end(); ++iter)
+    Document::type_vec_fields fields = document->get_table_fields(table_name);
+    for(Document::type_vec_fields::iterator iter = fields.begin(); iter != fields.end(); ++iter)
     {
       Gtk::TreeModel::iterator iterTree = m_model->append();
       Gtk::TreeModel::Row row = *iterTree;
@@ -247,8 +247,8 @@ void Window_Translations::load_from_document()
     }
 
     //The table's relationships:
-    Document_Glom::type_vecRelationships relationships = document->get_relationships(table_name);
-    for(Document_Glom::type_vecRelationships::iterator iter = relationships.begin(); iter != relationships.end(); ++iter)
+    Document::type_vec_relationships relationships = document->get_relationships(table_name);
+    for(Document::type_vec_relationships::iterator iter = relationships.begin(); iter != relationships.end(); ++iter)
     {
       sharedptr<Relationship> relationship = *iter;
       if(relationship)
@@ -263,8 +263,8 @@ void Window_Translations::load_from_document()
     }
 
     //The table's report titles:
-    Document_Glom::type_listReports listReports = document->get_report_names(table_name);
-    for(Document_Glom::type_listReports::iterator iter = listReports.begin(); iter != listReports.end(); ++iter)
+    Document::type_listReports listReports = document->get_report_names(table_name);
+    for(Document::type_listReports::iterator iter = listReports.begin(); iter != listReports.end(); ++iter)
     {
       const Glib::ustring report_name = *iter;
       sharedptr<Report> report = document->get_report(table_name, report_name);
@@ -279,8 +279,8 @@ void Window_Translations::load_from_document()
         row[m_columns.m_col_parent_table] = table_name;
 
         //Translatable report items:
-        Document_Glom::type_list_translatables list_layout_items = document->get_translatable_report_items(table_name, report_name);
-        for(Document_Glom::type_list_translatables::iterator iter = list_layout_items.begin(); iter != list_layout_items.end(); ++iter)
+        Document::type_list_translatables list_layout_items = document->get_translatable_report_items(table_name, report_name);
+        for(Document::type_list_translatables::iterator iter = list_layout_items.begin(); iter != list_layout_items.end(); ++iter)
         {
           sharedptr<TranslatableItem> item = *iter;
           if(item)
@@ -300,8 +300,8 @@ void Window_Translations::load_from_document()
     }
 
     //The table's translatable layout items:
-    Document_Glom::type_list_translatables list_layout_items = document->get_translatable_layout_items(table_name);
-    for(Document_Glom::type_list_translatables::iterator iter = list_layout_items.begin(); iter != list_layout_items.end(); ++iter)
+    Document::type_list_translatables list_layout_items = document->get_translatable_layout_items(table_name);
+    for(Document::type_list_translatables::iterator iter = list_layout_items.begin(); iter != list_layout_items.end(); ++iter)
     {
       sharedptr<TranslatableItem> item = *iter;
       if(item)
@@ -359,7 +359,7 @@ void Window_Translations::on_button_ok()
 
 void Window_Translations::on_button_copy_translation()
 {
-   Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "dialog_translation_copy");
+   Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "dialog_translation_copy");
   if(refXml)
   {
     Dialog_CopyTranslation* dialog = 0;
