@@ -18,25 +18,24 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include "config.h" // For GLOM_ENABLE_MAEMO
+#include <libglom/libglom_config.h> // For GLOM_ENABLE_MAEMO
 
-#include "adddel.h"
+#include <glom/utility_widgets/adddel/adddel.h>
 #include <algorithm> //For std::find.
 #include <glibmm/i18n.h>
-#include "../cellrendererlist/cellrendererlist.h"
-#include "treeviewcolumn_glom.h"
-#include <glom/libglom/data_structure/glomconversions.h>
-#include "../../dialog_invalid_data.h"
-#include <glom/libglom/utils.h>
-#include "bakery/App/App_Gtk.h"
+#include <glom/utility_widgets/cellrendererlist/cellrendererlist.h>
+#include <glom/utility_widgets/adddel/treeviewcolumn_glom.h>
+#include <libglom/data_structure/glomconversions.h>
+#include <glom/dialog_invalid_data.h>
+#include <glom/utils_ui.h>
+#include <libglom/utils.h>
+//#include <glom/bakery/app_gtk.h>
 #include <iostream> //For debug output.
 
 #ifdef GLOM_ENABLE_MAEMO
 #include <hildonmm/note.h>
 #endif // GLOM_ENABLE_MAEMO
 
-#include "eggcolumnchooser/eggcolumnchooserdialog.h"
-
 namespace Glom
 {
 
@@ -86,7 +85,7 @@ AddDel::AddDel()
 }
 
 
-AddDel::AddDel(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& /* refGlade */)
+AddDel::AddDel(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& /* builder */)
 : Gtk::VBox(cobject),
   m_col_key(0),
   m_pMenuPopup(0),
@@ -157,7 +156,7 @@ void AddDel::warn_about_duplicate()
 #ifdef GLOM_ENABLE_MAEMO
   Hildon::Note dialog(Hildon::NOTE_TYPE_INFORMATION, message);
 #else
-  Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("Duplicate")), true, Gtk::MESSAGE_WARNING, Gtk::BUTTONS_OK);
+  Gtk::MessageDialog dialog(Utils::bold_message(_("Duplicate")), true, Gtk::MESSAGE_WARNING, Gtk::BUTTONS_OK);
   dialog.set_secondary_text(message);
 #endif
   //TODO: dialog.set_transient_for(get_parent_window());
@@ -210,14 +209,6 @@ AddDel::on_MenuPopup_activate_Edit()
   }
 }
 
-void AddDel::on_MenuPopup_activate_ChooseColumns()
-{
-  GtkDialog* pDialog = GTK_DIALOG( egg_column_chooser_dialog_new(m_TreeView.gobj()) );
-  gtk_widget_show_all( GTK_WIDGET(pDialog) );
-  gtk_dialog_run(pDialog); //It will delete itself. The C API is funny like that.
-  pDialog = 0;
-}
-
 void AddDel::on_MenuPopup_activate_Delete()
 {
   finish_editing();
@@ -652,8 +643,8 @@ void AddDel::construct_specified_columns()
           CellRendererList* pCellRenderer = Gtk::manage( new CellRendererList() );
 
           //Add the choices:
-          const type_vecStrings vecStrings = m_ColumnTypes[model_column_index].m_choices;
-          for(type_vecStrings::const_iterator iter = vecStrings.begin(); iter != vecStrings.end(); ++iter)
+          const type_vec_strings vecStrings = m_ColumnTypes[model_column_index].m_choices;
+          for(type_vec_strings::const_iterator iter = vecStrings.begin(); iter != vecStrings.end(); ++iter)
           {
             pCellRenderer->append_list_item(*iter);
           }
@@ -753,7 +744,7 @@ void AddDel::construct_specified_columns()
           delete pModelColumnDerived;
           break;
         }
-	case(AddDelColumnInfo::STYLE_Numerical):
+        case(AddDelColumnInfo::STYLE_Numerical):
         {
           Gtk::TreeModelColumn<int>* pModelColumnDerived = static_cast< Gtk::TreeModelColumn<int>* >(pModelColumn);
           delete pModelColumnDerived;
@@ -953,7 +944,7 @@ void AddDel::set_prevent_user_signals(bool bVal)
   m_bPreventUserSignals = bVal;
 }
 
-void AddDel::set_column_choices(guint col, const type_vecStrings& vecStrings)
+void AddDel::set_column_choices(guint col, const type_vec_strings& vecStrings)
 {
   InnerIgnore innerIgnore(this); //Stop on_treeview_columns_changed() from doing anything when it is called just because we add new columns.
 
@@ -968,7 +959,7 @@ void AddDel::set_column_choices(guint col, const type_vecStrings& vecStrings)
     {
       //Add the choices:
       pCellRenderer->remove_all_list_items();
-      for(type_vecStrings::const_iterator iter = vecStrings.begin(); iter != vecStrings.end(); ++iter)
+      for(type_vec_strings::const_iterator iter = vecStrings.begin(); iter != vecStrings.end(); ++iter)
       {
         pCellRenderer->append_list_item(*iter);
       }
@@ -1070,9 +1061,10 @@ void AddDel::remove_item_by_key(const Glib::ustring& strKey)
 }
 
 AddDel::InnerIgnore::InnerIgnore(AddDel* pOuter)
+: m_pOuter(pOuter),
+  m_bPreventUserSignals(false),
+  m_bIgnoreSheetSignals(false)
 {
-  m_pOuter = pOuter;
-
   if(m_pOuter)
   {
     m_bPreventUserSignals = m_pOuter->get_prevent_user_signals();
@@ -1304,7 +1296,7 @@ void AddDel::on_treeview_cell_edited(const Glib::ustring& path_string, const Gli
 }
 
 
-void AddDel::on_treeview_cell_editing_started(Gtk::CellEditable* editable, const Glib::ustring& path_string, int model_column_index)
+void AddDel::on_treeview_cell_editing_started(Gtk::CellEditable* /* editable */, const Glib::ustring& path_string, int model_column_index)
 {
   Gtk::TreeModel::Path path(path_string);
 
@@ -1409,7 +1401,7 @@ void AddDel::on_treeview_columns_changed()
   }
 }
 
-AddDel::type_vecStrings AddDel::get_columns_order() const
+AddDel::type_vec_strings AddDel::get_columns_order() const
 {
   //This list is rebuilt in on_treeview_columns_changed, but maybe we could just build it here.
   return m_vecColumnIDs;
