@@ -19,7 +19,7 @@
  */
 
 #include "comboglomchoicesbase.h"
-#include <glom/libglom/data_structure/glomconversions.h>
+#include <libglom/data_structure/glomconversions.h>
 #include <glibmm/i18n.h>
 //#include <sstream> //For stringstream
 
@@ -28,6 +28,9 @@
 #include <iostream>   // for cout, endl
 
 
+namespace Glom
+{
+
 ComboGlomChoicesBase::ComboGlomChoicesBase()
 : m_with_second(false)
 {
@@ -62,11 +65,11 @@ void ComboGlomChoicesBase::set_choices_with_second(const type_list_values_with_s
     sharedptr<const LayoutItem_Field> layout_item = sharedptr<LayoutItem_Field>::cast_dynamic(get_layout_item());
     if(layout_item)
     {
-      row[m_Columns.m_col_first] = GlomConversions::get_text_for_gda_value(layout_item->get_glom_type(), iter->first, layout_item->get_formatting_used().m_numeric_format);
+      row[m_Columns.m_col_first] = Conversions::get_text_for_gda_value(layout_item->get_glom_type(), iter->first, layout_item->get_formatting_used().m_numeric_format);
 
       if(m_with_second)
       {
-        row[m_Columns.m_col_second] = GlomConversions::get_text_for_gda_value(m_layoutitem_second->get_glom_type(), iter->second, m_layoutitem_second->get_formatting_used().m_numeric_format);
+        row[m_Columns.m_col_second] = Conversions::get_text_for_gda_value(m_layoutitem_second->get_glom_type(), iter->second, m_layoutitem_second->get_formatting_used().m_numeric_format);
       }
     }
   }
@@ -86,10 +89,12 @@ void ComboGlomChoicesBase::set_choices(const FieldFormatting::type_list_values&
     if(layout_item)
     {
       const Gnome::Gda::Value value = *iter;
-      const Glib::ustring text = GlomConversions::get_text_for_gda_value(layout_item->get_glom_type(), value, layout_item->get_formatting_used().m_numeric_format);
+      const Glib::ustring text = Conversions::get_text_for_gda_value(layout_item->get_glom_type(), value, layout_item->get_formatting_used().m_numeric_format);
 
       row[m_Columns.m_col_first] = text;
     }
   }
 }
 
+
+} //namespace Glom
