@@ -26,14 +26,14 @@
 #include "comboglom.h"
 #include "textviewglom.h"
 #include "imageglom.h"
-#include <glom/libglom/data_structure/glomconversions.h>
-#include "../application.h"
+#include <libglom/data_structure/glomconversions.h>
+#include <glom/application.h>
 #include "../mode_data/dialog_choose_field.h"
 #include "dialog_choose_id.h"
 #include "dialog_choose_date.h"
 #include "../layout_item_dialogs/dialog_field_layout.h"
-#include <glom/libglom/utils.h>
-#include <glom/libglom/glade_utils.h>
+#include <glom/utils_ui.h>
+#include <glom/glade_utils.h>
 #include <glibmm/i18n.h>
 
 namespace Glom
@@ -45,7 +45,9 @@ DataWidget::DataWidget(Field::glom_field_type glom_type, const Glib::ustring& ti
   m_pMenuPopup(0)
 */
 
-DataWidget::DataWidget(const sharedptr<LayoutItem_Field>& field, const Glib::ustring& table_name, const Document_Glom* document)
+DataWidget::DataWidget(const sharedptr<LayoutItem_Field>& field, const Glib::ustring& table_name, const Document* document)
+:  m_child(0),
+   m_button_go_to_details(0)
 {
   const Field::glom_field_type glom_type = field->get_glom_type();
   set_layout_item(field, table_name);
@@ -240,10 +242,10 @@ DataWidget::DataWidget(const sharedptr<LayoutItem_Field>& field, const Glib::ust
     if((field_used_in_relationship_to_one || field_is_related_primary_key) && hbox_parent)
     {
       //Add a button for related record navigation:
-      Gtk::Button* button_go_to_details = Gtk::manage(new Gtk::Button(Gtk::Stock::OPEN));
-      button_go_to_details->set_tooltip_text(_("Open the record identified by this ID, in the other table."));
-      hbox_parent->pack_start(*button_go_to_details);
-      button_go_to_details->signal_clicked().connect(sigc::mem_fun(*this, &DataWidget::on_button_open_details));
+      m_button_go_to_details = Gtk::manage(new Gtk::Button(Gtk::Stock::OPEN));
+      m_button_go_to_details->set_tooltip_text(_("Open the record identified by this ID, in the other table."));
+      hbox_parent->pack_start(*m_button_go_to_details);
+      m_button_go_to_details->signal_clicked().connect(sigc::mem_fun(*this, &DataWidget::on_button_open_details));
 
       //Add a button to make it easier to choose an ID for this field.
       //Don't add this for simple related primary key fields, because they 
@@ -276,6 +278,7 @@ DataWidget::~DataWidget()
 void DataWidget::on_widget_edited()
 {
   m_signal_edited.emit(get_value());
+  update_go_to_details_button_sensitivity();
 }
 
 DataWidget::type_signal_edited DataWidget::signal_edited()
@@ -307,6 +310,20 @@ void DataWidget::set_value(const Gnome::Gda::Value& value)
       checkbutton->set_active( bValue );
     }
   }
+
+  update_go_to_details_button_sensitivity();
+}
+
+void DataWidget::update_go_to_details_button_sensitivity()
+{
+  //If there is a Go-To-Details "Open" button, only enable it if there is 
+  //an ID:
+  if(m_button_go_to_details)
+  {
+    const Gnome::Gda::Value value = get_value();
+    const bool enabled = !Conversions::value_is_empty(value);
+    m_button_go_to_details->set_sensitive(enabled);
+  }
 }
 
 Gnome::Gda::Value DataWidget::get_value() const
@@ -584,25 +601,25 @@ sharedptr<LayoutItem_Field> DataWidget::offer_field_list(const Glib::ustring& ta
   return offer_field_list (table_name, start_field, get_document(), get_application());
 }
 
-sharedptr<LayoutItem_Field> DataWidget::offer_field_list(const Glib::ustring& table_name, const sharedptr<const LayoutItem_Field>& start_field, Document_Glom* document, App_Glom* app)
+sharedptr<LayoutItem_Field> DataWidget::offer_field_list(const Glib::ustring& table_name, const sharedptr<const LayoutItem_Field>& start_field, Document* document, App_Glom* app)
 {
   sharedptr<LayoutItem_Field> result;
 
-  Glib::RefPtr<Gnome::Glade::Xml> refXml;
+  Glib::RefPtr<Gtk::Builder> refXml;
 
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
-    refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "dialog_choose_field");
+    refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "dialog_choose_field");
   }
-  catch(const Gnome::Glade::XmlError& ex)
+  catch(const Gtk::BuilderError& ex)
   {
     std::cerr << ex.what() << std::endl;
     return result;
   }
 #else
-  std::auto_ptr<Gnome::Glade::XmlError> error;
-  refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "dialog_choose_field", "", error);
+  std::auto_ptr<Gtk::BuilderError> error;
+  refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "dialog_choose_field", "", error);
   if(error.get())
   {
     std::cerr << error->what() << std::endl;
@@ -638,7 +655,7 @@ sharedptr<LayoutItem_Field> DataWidget::offer_field_layout(const sharedptr<const
 
   try
   {
-    Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "dialog_layout_field_properties");
+    Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "dialog_layout_field_properties");
 
     Dialog_FieldLayout* dialog = 0;
     refXml->get_widget_derived("dialog_layout_field_properties", dialog);
@@ -660,7 +677,7 @@ sharedptr<LayoutItem_Field> DataWidget::offer_field_layout(const sharedptr<const
       delete dialog;
     }
   }
-  catch(const Gnome::Glade::XmlError& ex)
+  catch(const Gtk::BuilderError& ex)
   {
     std::cerr << ex.what() << std::endl;
   }
@@ -771,20 +788,20 @@ const Gtk::Widget* DataWidget::get_data_child_widget() const
 
 void DataWidget::on_button_choose_date()
 {
-  Glib::RefPtr<Gnome::Glade::Xml> refXml;
+  Glib::RefPtr<Gtk::Builder> refXml;
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
-    refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "dialog_choose_date");
+    refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "dialog_choose_date");
   }
-  catch(const Gnome::Glade::XmlError& ex)
+  catch(const Gtk::BuilderError& ex)
   {
     std::cerr << ex.what() << std::endl;
     return;
   }
 #else
-  std::auto_ptr<Gnome::Glade::XmlError> error;
-  refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "dialog_choose_date", "", error);
+  std::auto_ptr<Gtk::BuilderError> error;
+  refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "dialog_choose_date", "", error);
   if(error.get())
   {
     std::cerr << error->what() << std::endl;
@@ -828,20 +845,20 @@ bool DataWidget::offer_related_record_id_find(Gnome::Gda::Value& chosen_id)
   //Initialize output variable:
   chosen_id = Gnome::Gda::Value();
 
-  Glib::RefPtr<Gnome::Glade::Xml> refXml;
+  Glib::RefPtr<Gtk::Builder> refXml;
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
-    refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom.glade"), "dialog_find_id");
+    refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom.glade"), "dialog_find_id");
   }
-  catch(const Gnome::Glade::XmlError& ex)
+  catch(const Glib::Error& ex)
   {
     std::cerr << ex.what() << std::endl;
     return result;
   }
 #else
-  std::auto_ptr<Gnome::Glade::XmlError> error;
-  refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom.glade"), "dialog_find_id", "", error);
+  std::auto_ptr<Glib::Error> error;
+  refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom.glade"), "dialog_find_id", "", error);
   if(error.get())
   {
     std::cerr << error->what() << std::endl;
