@@ -42,8 +42,8 @@ class DataWidget
    public View_Composite_Glom
 {
 public:
-  //explicit DataWidget(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
-  explicit DataWidget(const sharedptr<LayoutItem_Field>& field, const Glib::ustring& table_name, const Document_Glom* document);
+  //explicit DataWidget(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
+  explicit DataWidget(const sharedptr<LayoutItem_Field>& field, const Glib::ustring& table_name, const Document* document);
   virtual ~DataWidget();
 
   virtual Gtk::Label* get_label();
@@ -60,7 +60,7 @@ public:
   virtual void set_editable(bool editable = true);
   virtual void set_viewable(bool viewable = true);
 
-  static sharedptr<LayoutItem_Field> offer_field_list(const Glib::ustring& table_name, const sharedptr<const LayoutItem_Field>& start_field, Document_Glom* document, App_Glom* app);
+  static sharedptr<LayoutItem_Field> offer_field_list(const Glib::ustring& table_name, const sharedptr<const LayoutItem_Field>& start_field, Document* document, App_Glom* app);
   sharedptr<LayoutItem_Field> offer_field_list(const Glib::ustring& table_name);
   sharedptr<LayoutItem_Field> offer_field_list(const Glib::ustring& table_name, const sharedptr<const LayoutItem_Field>& start_field);
 #ifndef GLOM_ENABLE_CLIENT_ONLY
@@ -113,11 +113,16 @@ private:
    */
   bool offer_related_record_id_find(Gnome::Gda::Value& chosen_id);
 
+private:
+  void update_go_to_details_button_sensitivity();
+
+protected:
   type_signal_edited m_signal_edited;
   type_signal_open_details_requested m_signal_open_details_requested;
 
   Gtk::Label m_label;
   Gtk::Widget* m_child;
+  Gtk::Button* m_button_go_to_details;
 };
 
 } //namespace Glom
