@@ -24,13 +24,13 @@
 #include "../cellrendererlist/cellrendererlist.h"
 #include "db_treeviewcolumn_glom.h"
 #include <libglom/data_structure/glomconversions.h>
-#include "../../dialog_invalid_data.h"
-#include "../../application.h"
-#include <libglom/utils.h>
+#include <glom/dialog_invalid_data.h>
+#include <glom/application.h>
+#include <glom/utils_ui.h>
 #include "cellrenderer_buttonimage.h"
 #include "cellrenderer_buttontext.h"
 #include <glom/utility_widgets/imageglom.h> //For ImageGlom::scale_keeping_ratio().
-//#include "../cellrendererlist.h"
+
 #include <iostream> //For debug output.
 #include <gtk/gtktreeview.h>
 #include <gtk/gtkstock.h>
@@ -648,7 +648,7 @@ Gtk::CellRenderer* DbAddDel::construct_specified_columns_cellrenderer(const shar
      {
        Gtk::CellRendererPixbuf* pixbuf_renderer = Gtk::manage( new Gtk::CellRendererPixbuf() );
 
-       Glib::RefPtr<Gdk::Pixbuf> pixbuf = item_image->get_image_as_pixbuf();
+       Glib::RefPtr<Gdk::Pixbuf> pixbuf = Utils::get_pixbuf_for_gda_value(item_image->m_image);
        if(pixbuf)
          pixbuf_renderer->set_property("pixbuf", pixbuf);
        else
@@ -748,7 +748,7 @@ Gtk::CellRenderer* DbAddDel::construct_specified_columns_cellrenderer(const shar
           const sharedptr<LayoutItem_Field> layout_field_second = sharedptr<LayoutItem_Field>::create();
           if(use_second)
           {
-            Document_Glom* document = get_document();
+            Document* document = get_document();
             if(document)
             {
               sharedptr<Field> field_second = document->get_field(to_table, choice_second); //TODO: Actually show this in the combo:
@@ -832,7 +832,7 @@ void DbAddDel::construct_specified_columns()
   {
     //std::cout << "debug: DbAddDel::construct_specified_columns(): showing hint model: m_find_mode=" << m_find_mode << std::endl;
 
-    m_refListStore.clear();
+    m_refListStore.reset();
     if(m_table_name.empty())
       m_TreeView.set_model(m_refListStore); // clear old model from treeview
     else
@@ -932,7 +932,10 @@ void DbAddDel::construct_specified_columns()
     m_treeviewcolumn_button->pack_start(*pCellButton);
 
 
-    int x_offset, y_offset, width, height;
+    int x_offset = 0;
+    int y_offset = 0;
+    int width = 0;
+    int height = 0;
     pCellButton->get_size(m_TreeView, x_offset, y_offset, width, height);
 
     m_treeviewcolumn_button->set_sizing(Gtk::TREE_VIEW_COLUMN_FIXED); //Need by fixed-height mode.
@@ -1236,7 +1239,7 @@ void DbAddDel::set_prevent_user_signals(bool bVal)
   m_bPreventUserSignals = bVal;
 }
 
-void DbAddDel::set_column_choices(guint col, const type_vecStrings& vecStrings)
+void DbAddDel::set_column_choices(guint col, const type_vec_strings& vecStrings)
 {
   InnerIgnore innerIgnore(this); //Stop on_treeview_columns_changed() from doing anything when it is called just because we add new columns.
 
@@ -1251,7 +1254,7 @@ void DbAddDel::set_column_choices(guint col, const type_vecStrings& vecStrings)
     {
       //Add the choices:
       pCellRenderer->remove_all_list_items();
-      for(type_vecStrings::const_iterator iter = vecStrings.begin(); iter != vecStrings.end(); ++iter)
+      for(type_vec_strings::const_iterator iter = vecStrings.begin(); iter != vecStrings.end(); ++iter)
       {
         pCellRenderer->append_list_item(*iter);
       }
@@ -1695,7 +1698,7 @@ guint DbAddDel::treeview_append_column(const Glib::ustring& title, Gtk::CellRend
   sharedptr<const LayoutItem> layout_item = m_ColumnTypes[model_column_index].m_item;
   sharedptr<const LayoutItem_Field> layout_item_field = sharedptr<const LayoutItem_Field>::cast_dynamic(layout_item);
 
-  //Tell the TreeView how to render the Gnome::Gda::Values:
+  //Tell the Treeview.how to render the Gnome::Gda::Values:
   if(layout_item_field)
   {
     pViewColumn->set_cell_data_func(cellrenderer, 
@@ -1757,7 +1760,7 @@ void DbAddDel::on_treeview_column_resized(int model_column_index, DbTreeViewColu
 
 void DbAddDel::on_treeview_column_clicked(int model_column_index)
 {
-  Bakery::BusyCursor busy_cursor(get_application());
+  BusyCursor busy_cursor(get_application());
 
   if(model_column_index >= (int)m_ColumnTypes.size())
     return;
@@ -1813,7 +1816,7 @@ void DbAddDel::on_treeview_columns_changed()
   }
 }
 
-DbAddDel::type_vecStrings DbAddDel::get_columns_order() const
+DbAddDel::type_vec_strings DbAddDel::get_columns_order() const
 {
   //This list is rebuilt in on_treeview_columns_changed, but maybe we could just build it here.
   return m_vecColumnIDs;
@@ -2002,7 +2005,7 @@ void DbAddDel::treeviewcolumn_on_cell_data(Gtk::CellRenderer* renderer, const Gt
           Gtk::CellRendererPixbuf* pDerived = dynamic_cast<Gtk::CellRendererPixbuf*>(renderer);
           if(pDerived)
           {
-            Glib::RefPtr<Gdk::Pixbuf> pixbuf = Conversions::get_pixbuf_for_gda_value(value);
+            Glib::RefPtr<Gdk::Pixbuf> pixbuf = Utils::get_pixbuf_for_gda_value(value);
          
             //Scale it down to a sensible size.
             if(pixbuf)
@@ -2191,7 +2194,7 @@ void DbAddDel::user_changed(const Gtk::TreeModel::iterator& row, guint col)
         //plus how to identify the record in that table.
         const Glib::ustring relationship_name = layout_field->get_relationship_name();
 
-        Document_Glom* document = dynamic_cast<Document_Glom*>(get_document());
+        Document* document = dynamic_cast<Document*>(get_document());
 
         sharedptr<Relationship> relationship = document->get_relationship(m_found_set.m_table_name, relationship_name);
         if(relationship)
@@ -2322,7 +2325,7 @@ void DbAddDel::user_added(const Gtk::TreeModel::iterator& row)
   if(m_allow_only_one_related_record && (get_count() > 0))
   {
     //Tell user that they can't do that:
-    Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("Extra Related Records Not Possible")), true, Gtk::MESSAGE_WARNING);
+    Gtk::MessageDialog dialog(Utils::bold_message(_("Extra Related Records Not Possible")), true, Gtk::MESSAGE_WARNING);
     dialog.set_secondary_text(_("You attempted to add a new related record, but there can only be one related record, because the relationship uses a unique key.")),
     dialog.set_transient_for(*App_Glom::get_application());
     dialog.run();
