@@ -22,16 +22,16 @@
 #define GLOM_DB_ADDDEL_H
 
 #include <gtkmm.h>
-#include <glom/libglom/data_structure/layout/layoutitem_field.h>
+#include <libglom/data_structure/layout/layoutitem_field.h>
 #include <libgdamm.h>
 #include "glom_db_treemodel.h"
-#include <glom/libglom/document/document_glom.h>
+#include <libglom/document/document.h>
 #include <glom/base_db_table_data.h>
 
 #include <vector>
 #include <map>
 
-#include "config.h" // For GLOM_ENABLE_CLIENT_ONLY
+#include <libglom/libglom_config.h> // For GLOM_ENABLE_CLIENT_ONLY
 
 namespace Glom
 {
@@ -48,8 +48,8 @@ public:
   sharedptr<LayoutItem> m_item;
 
   //For fields with choices:
-  typedef std::vector<Glib::ustring> type_vecStrings;
-  type_vecStrings m_choices;
+  typedef std::vector<Glib::ustring> type_vec_strings;
+  type_vec_strings m_choices;
 
   bool m_editable;
   bool m_visible;
@@ -178,12 +178,12 @@ public:
 
   sharedptr<const LayoutItem_Field> get_column_field(guint column_index) const;
 
-  typedef DbAddDelColumnInfo::type_vecStrings type_vecStrings;
+  typedef DbAddDelColumnInfo::type_vec_strings type_vec_strings;
 
   /** Retrieves the column order, even after they have been reordered by the user.
    * @result a vector of column_id. These column_ids were provided in the call to add_column().
    */
-  type_vecStrings get_columns_order() const;
+  type_vec_strings get_columns_order() const;
 
   void remove_all_columns();
   //virtual void set_columns_count(guint count);
@@ -191,7 +191,7 @@ public:
   void set_column_width(guint col, guint width);
 
   /// For popup cells.
-  void set_column_choices(guint col, const type_vecStrings& vecStrings);
+  void set_column_choices(guint col, const type_vec_strings& vecStrings);
 
   void construct_specified_columns(); //Delay actual use of set_column_*() stuff until this method is called.
 
@@ -259,14 +259,15 @@ public:
 
   virtual void set_open_button_title(const Glib::ustring& title);
 
-protected:
+private:
   
   
   //Overrides of Base_DB/Base_DB_Table methods:
   virtual void set_entered_field_data(const sharedptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value);
   virtual void set_entered_field_data(const Gtk::TreeModel::iterator& row, const sharedptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value);
   virtual Gnome::Gda::Value get_entered_field_data(const sharedptr<const LayoutItem_Field>& field) const;
-
+  virtual Gtk::TreeModel::iterator get_row_selected();
+ 
   //Implementations of pure virtual methods from Base_DB_Table_Data:
   virtual sharedptr<Field> get_field_primary_key() const;
   virtual Gnome::Gda::Value get_primary_key_value_selected() const;
@@ -285,7 +286,10 @@ protected:
   ///Return the query column index of any columns that display this field:
   type_list_indexes get_data_model_column_index(const sharedptr<const LayoutItem_Field>& layout_item_field) const;
 
+protected:
   virtual void setup_menu();
+
+private:
   virtual Gnome::Gda::Value treeview_get_key(const Gtk::TreeModel::iterator& row) const;
 
   ///Add a blank row, or return the existing blank row if there already is one.
@@ -303,10 +307,13 @@ protected:
 
   virtual bool on_button_press_event_Popup(GdkEventButton* event);
 
+protected:
   void on_MenuPopup_activate_Edit();
   void on_MenuPopup_activate_Add();
   void on_MenuPopup_activate_Delete();
 
+private:
+
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   void on_MenuPopup_activate_layout();
 #endif
@@ -373,8 +380,10 @@ protected:
   bool m_column_sorted_direction; //true means ascending. 
   guint m_column_sorted; //Previously-clicked (on the treeview header) column. Remember it so we can reverse the sort order on a second click.
 
+protected:
   Glib::ustring m_open_button_title; //Allow us to change "Open" to "Select".
 
+private:
   //TODO: Avoid repeating these in so many widgets:
   Gtk::Menu* m_pMenuPopup;
   Glib::RefPtr<Gtk::ActionGroup> m_refActionGroup;
@@ -390,10 +399,13 @@ protected:
   bool m_bPreventUserSignals;
   bool m_bIgnoreTreeViewSignals;
 
-  type_vecStrings m_vecColumnIDs; //We give each ViewColumn a special ID, so we know where they are after a reorder.
+  type_vec_strings m_vecColumnIDs; //We give each ViewColumn a special ID, so we know where they are after a reorder.
 
+protected:
   bool m_allow_add;
   bool m_allow_delete;
+
+private:
     
   bool m_find_mode;
   bool m_allow_only_one_related_record;
@@ -430,7 +442,7 @@ protected:
     InnerIgnore(DbAddDel* pOuter);
     ~InnerIgnore();
 
-  protected:
+  private:
     DbAddDel* m_pOuter;
     bool m_bPreventUserSignals, m_bIgnoreTreeViewSignals;
   };
