@@ -30,211 +30,6 @@
 namespace Glom
 {
 
-#ifndef GLIBMM_VFUNCS_ENABLED
-  // C vfuncs implementation. Merely copied from gtkmm.
-  GtkTreeModelFlags DbTreeModel::glom_get_flags_impl(GtkTreeModel* model)
-  {
-    Glib::ObjectBase* const obj_base = static_cast<Glib::ObjectBase*>(Glib::ObjectBase::_get_current_wrapper((GObject*)model));
-    if(obj_base)
-    {
-      Glom::DbTreeModel* cpp_model = dynamic_cast<Glom::DbTreeModel*>(obj_base);
-      g_assert(cpp_model);
-      return GtkTreeModelFlags(cpp_model->get_flags_vfunc());
-    }
-    else
-      return GtkTreeModelFlags(0);
-  }
-
-  gint DbTreeModel::glom_get_n_columns_impl(GtkTreeModel* model)
-  {
-    Glib::ObjectBase* const obj_base = static_cast<Glib::ObjectBase*>(Glib::ObjectBase::_get_current_wrapper((GObject*)model));
-    if(obj_base)
-    {
-      Glom::DbTreeModel* cpp_model = dynamic_cast<Glom::DbTreeModel*>(obj_base);
-      g_assert(cpp_model);
-      return cpp_model->get_n_columns_vfunc();
-    }
-    else
-      return 0;
-  }
-  
-  GType DbTreeModel::glom_get_column_type_impl(GtkTreeModel* model, gint index)
-  {
-    Glib::ObjectBase* const obj_base = static_cast<Glib::ObjectBase*>(Glib::ObjectBase::_get_current_wrapper((GObject*)model));
-    if(obj_base)
-    {
-      Glom::DbTreeModel* cpp_model = dynamic_cast<Glom::DbTreeModel*>(obj_base);
-      g_assert(cpp_model);
-      return cpp_model->get_column_type_vfunc(index);
-    }
-    else
-      return G_TYPE_NONE;
-  }
-
-  void DbTreeModel::glom_get_value_impl(GtkTreeModel* model, GtkTreeIter* iter, gint column, GValue* value)
-  {
-    Glib::ObjectBase* const obj_base = static_cast<Glib::ObjectBase*>(Glib::ObjectBase::_get_current_wrapper((GObject*)model));
-    if(obj_base)
-    {
-      Glom::DbTreeModel* cpp_model = dynamic_cast<Glom::DbTreeModel*>(obj_base);
-      g_assert(cpp_model);
-      cpp_model->get_value_vfunc(Gtk::TreeModel::iterator(model, iter), column, *reinterpret_cast<Glib::ValueBase*>(value));
-    }
-  }
-
-  gboolean DbTreeModel::glom_iter_next_impl(GtkTreeModel* model, GtkTreeIter* iter)
-  {
-    Glib::ObjectBase* const obj_base = static_cast<Glib::ObjectBase*>(Glib::ObjectBase::_get_current_wrapper((GObject*)model));
-    if(obj_base)
-    {
-      Glom::DbTreeModel* cpp_model = dynamic_cast<Glom::DbTreeModel*>(obj_base);
-      g_assert(cpp_model);
-
-      TreeModel::iterator iter_input = TreeModel::iterator(model, iter);
-      TreeModel::iterator iter_next(model, iter);
-      const gboolean retval = cpp_model->iter_next_vfunc(iter_input, iter_next);
-
-      if(retval)
-        *iter = *(iter_next.gobj());
-      
-      return retval;
-    }
-    else
-      return FALSE;
-  }
-
-  gboolean DbTreeModel::glom_iter_children_impl(GtkTreeModel* model, GtkTreeIter* iter, GtkTreeIter* parent)
-  {
-    Glib::ObjectBase* const obj_base = static_cast<Glib::ObjectBase*>(Glib::ObjectBase::_get_current_wrapper((GObject*)model));
-    if(obj_base)
-    {
-      Glom::DbTreeModel* cpp_model = dynamic_cast<Glom::DbTreeModel*>(obj_base);
-      g_assert(cpp_model);
-
-      TreeModel::iterator iter_out(model, iter);
-      const gboolean retval = cpp_model->iter_children_vfunc(TreeModel::iterator(model, parent), iter_out);
-
-      if(retval)
-        *iter = *(iter_out.gobj());
-      
-      return retval;
-    }
-    else
-      return FALSE;
-  }
-
-  gboolean DbTreeModel::glom_iter_has_child_impl(GtkTreeModel* model, GtkTreeIter* iter)
-  {
-    Glib::ObjectBase* const obj_base = static_cast<Glib::ObjectBase*>(Glib::ObjectBase::_get_current_wrapper((GObject*)model));
-    if(obj_base)
-    {
-      Glom::DbTreeModel* cpp_model = dynamic_cast<Glom::DbTreeModel*>(obj_base);
-      g_assert(cpp_model);
-      return cpp_model->iter_has_child_vfunc(TreeModel::iterator(model, iter));
-    }
-    else
-      return FALSE;
-  }
-
-  gint DbTreeModel::glom_iter_n_children_impl(GtkTreeModel* model, GtkTreeIter* iter)
-  {
-    Glib::ObjectBase* const obj_base = static_cast<Glib::ObjectBase*>(Glib::ObjectBase::_get_current_wrapper((GObject*)model));
-    if(obj_base)
-    {
-      Glom::DbTreeModel* cpp_model = dynamic_cast<Glom::DbTreeModel*>(obj_base);
-      g_assert(cpp_model);
-      return cpp_model->iter_n_children_vfunc(TreeModel::iterator(model, iter));
-    }
-    else
-      return 0;
-  }
-
-  gboolean DbTreeModel::glom_iter_nth_child_impl(GtkTreeModel* model, GtkTreeIter* iter, GtkTreeIter* parent, gint n)
-  {
-    Glib::ObjectBase* const obj_base = static_cast<Glib::ObjectBase*>(Glib::ObjectBase::_get_current_wrapper((GObject*)model));
-    if(obj_base)
-    {
-      Glom::DbTreeModel* cpp_model = dynamic_cast<Glom::DbTreeModel*>(obj_base);
-      g_assert(cpp_model);
-
-      TreeModel::iterator iter_out(model, iter);
-      gboolean retval = false;
-
-      // Deal with this special case, documented in the C docs as:
-      // "As a special case, if @parent is %NULL, then the nth root node is set.":
-      if(!parent)
-        retval = cpp_model->iter_nth_root_child_vfunc(n, iter_out);
-      else
-        retval = cpp_model->iter_nth_child_vfunc(TreeModel::iterator(model, parent), n, iter_out);
-
-      if(retval)
-        *iter = *(iter_out.gobj());
-
-      return retval;
-    }
-    else
-      return FALSE;
-  }
-
-  gboolean DbTreeModel::glom_iter_parent_impl(GtkTreeModel* model, GtkTreeIter* iter, GtkTreeIter* child)
-  {
-    Glib::ObjectBase* const obj_base = static_cast<Glib::ObjectBase*>(Glib::ObjectBase::_get_current_wrapper((GObject*)model));
-    if(obj_base)
-    {
-      Glom::DbTreeModel* cpp_model = dynamic_cast<Glom::DbTreeModel*>(obj_base);
-      g_assert(cpp_model);
-
-      TreeModel::iterator iter_out(model, iter);
-      const gboolean retval = cpp_model->iter_parent_vfunc(TreeModel::iterator(model, child), iter_out);
-
-      if(retval)
-        *iter = *(iter_out.gobj());
-
-      return retval;
-    }
-    else
-      return FALSE;
-  }
-
-  GtkTreePath* DbTreeModel::glom_get_path_impl(GtkTreeModel* model, GtkTreeIter* iter)
-  {
-    Glib::ObjectBase* const obj_base = static_cast<Glib::ObjectBase*>(Glib::ObjectBase::_get_current_wrapper((GObject*)model));
-    if(obj_base)
-    {
-      Glom::DbTreeModel* cpp_model = dynamic_cast<Glom::DbTreeModel*>(obj_base);
-      g_assert(cpp_model);
-      return cpp_model->get_path_vfunc(TreeModel::iterator(model, iter)).gobj_copy();
-    }
-    else
-      return NULL;
-  }
-
-  gboolean DbTreeModel::glom_get_iter_impl(GtkTreeModel* model, GtkTreeIter* iter, GtkTreePath* path)
-  {
-    Glib::ObjectBase* const obj_base = static_cast<Glib::ObjectBase*>(Glib::ObjectBase::_get_current_wrapper((GObject*)model));
-    if(obj_base)
-    {
-      Glom::DbTreeModel* cpp_model = dynamic_cast<Glom::DbTreeModel*>(obj_base);
-      g_assert(cpp_model);
-
-      TreeModel::iterator iter_out(model, iter);
-
-      const gboolean retval = cpp_model->get_iter_vfunc(Gtk::TreeModel::Path(path, true), iter_out);
-
-      if(retval)
-        *iter = *(iter_out.gobj());
-
-      return retval;
-    }
-    else
-      return FALSE;
-  }
-#endif // !GLIBMM_VFUNCS_ENABLED
-} // namespace Glom
-
-namespace Glom
-{
-
 DbTreeModelRow::DbTreeModelRow()
 : m_values_retrieved(false),
   m_removed(false),
@@ -390,22 +185,6 @@ DbTreeModel::DbTreeModel(const Gtk::TreeModelColumnRecord& columns, const FoundS
     //GType gtype = G_OBJECT_TYPE(gobj());  //The custom GType created in the Object constructor, from the typeid.
     //Gtk::TreeModel::add_interface( gtype );
 
-#ifndef GLIBMM_VFUNCS_ENABLED
-    GtkTreeModelIface* iface = GTK_TREE_MODEL_GET_IFACE(gobj());
-    iface->get_flags = glom_get_flags_impl;
-    iface->get_n_columns = glom_get_n_columns_impl;
-    iface->get_column_type = glom_get_column_type_impl;
-    iface->get_value = glom_get_value_impl;
-    iface->iter_next = glom_iter_next_impl;
-    iface->iter_children = glom_iter_children_impl;
-    iface->iter_has_child = glom_iter_has_child_impl;
-    iface->iter_n_children = glom_iter_n_children_impl;
-    iface->iter_nth_child = glom_iter_nth_child_impl;
-    iface->iter_parent = glom_iter_parent_impl;
-    iface->get_path = glom_get_path_impl;
-    iface->get_iter = glom_get_iter_impl;
-#endif // !GLIBMM_VFUNCS_ENABLED
-
     m_iface_initialized = true; //Prevent us from calling add_interface() on the same gtype again.
   }
 
@@ -541,19 +320,19 @@ bool DbTreeModel::refresh_from_database(const FoundSet& found_set)
     catch(const Glib::Exception& ex)
     {
       std::cerr << "DbTreeModel::refresh_from_database(): Glib::Exception caught." << std::endl;
-      m_gda_datamodel.clear(); //So that it is 0, so we can handle it below.
+      m_gda_datamodel.reset(); //So that it is 0, so we can handle it below.
     }
     catch(const std::exception& ex)
     {
       std::cerr << "DbTreeModel::refresh_from_database(): std::exception caught." << std::endl;
-      m_gda_datamodel.clear(); //So that it is 0, so we can handle it below.
+      m_gda_datamodel.reset(); //So that it is 0, so we can handle it below.
     }
 #else
     std::auto_ptr<Glib::Error> error;
     m_gda_datamodel = m_connection->get_gda_connection()->statement_execute_select(stmt, set, error);
     if(error.get())
     {
-      m_gda_datamodel.clear(); //So that it is 0, so we can handle it below.
+      m_gda_datamodel.reset(); //So that it is 0, so we can handle it below.
     }
 #endif //GLIBMM_EXCEPTIONS_ENABLED
 
@@ -563,7 +342,7 @@ bool DbTreeModel::refresh_from_database(const FoundSet& found_set)
       m_data_model_columns_count = m_columns_count;
 
       std::cerr << "DbTreeModel::refresh_from_database(): error executing SQL: " << sql_query << std::endl;
-      ConnectionPool::handle_error();
+      ConnectionPool::handle_error_cerr_only();
       return false; //No records were found.
     }
     else
