@@ -21,9 +21,9 @@
 #ifndef GLOM_UTILITY_WIDGETS_FILECHOOSERDIALOG_SAVEEXTRAS_H
 #define GLOM_UTILITY_WIDGETS_FILECHOOSERDIALOG_SAVEEXTRAS_H
 
-#include "config.h" // For GLOM_ENABLE_CLIENT_ONLY, GLOM_ENABLE_SQLITE
+#include <libglom/libglom_config.h> // For GLOM_ENABLE_CLIENT_ONLY, GLOM_ENABLE_SQLITE
 
-#include <glom/libglom/document/document_glom.h>
+#include <libglom/document/document.h>
 
 #include <gtkmm/filechooserdialog.h>
 #include <gtkmm/label.h>
@@ -47,17 +47,17 @@ public:
   void set_extra_message(const Glib::ustring& message);
   void set_extra_newdb_title(const Glib::ustring& title);
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-  void set_extra_newdb_hosting_mode(Document_Glom::HostingMode mode);
+  void set_extra_newdb_hosting_mode(Document::HostingMode mode);
   //void set_extra_newdb_self_hosted(bool self_hosted = true);
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
   Glib::ustring get_extra_newdb_title() const;
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-  Document_Glom::HostingMode get_extra_newdb_hosting_mode() const;
+  Document::HostingMode get_extra_newdb_hosting_mode() const;
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-protected:
+private:
   void create_child_widgets();
 
   Gtk::VBox m_extra_widget;
@@ -66,8 +66,11 @@ protected:
   /* New database details: */
   Gtk::Entry m_entry_title;
 #ifndef GLOM_ENABLE_CLIENT_ONLY
+
+#ifdef GLOM_ENABLE_POSTGRESQL
   Gtk::RadioButton m_radiobutton_server_postgres_central;
   Gtk::RadioButton m_radiobutton_server_postgres_selfhosted;
+#endif // GLOM_ENABLE_POSTGRESQL
 
 #ifdef GLOM_ENABLE_SQLITE
   Gtk::RadioButton m_radiobutton_server_sqlite;
