@@ -26,111 +26,9 @@
 #include <gdkmm/window.h>
 #include <gtk/gtk.h>
 
-// So we don't need to check for the condition above all the time
-
-// A GObject for the flowtable to allow overriding vfuncs even with the
-// reduced glibmm API
-namespace
-{
-#if 0
-#define GLOM_TYPE_FLOWTABLE (glom_flowtable_get_type())
-#define GLOM_FLOWTABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), GLOM_TYPE_FLOWTABLE, GlomFlowtable))
-#endif
-
-#ifndef GLIBMM_VFUNCS_ENABLED
-  GtkContainerClass* parent_class = NULL;
-#endif
-
-#if 0
-  struct GlomFlowtableClass
-  {
-    GtkContainerClass parent_class;
-  }
-
-  struct GlomFlowtable
-  {
-    GtkContainer parent_instance;
-    Glom::FlowTable* cpp_table;
-  }
-
-  void glom_flowtable_init(GlowFlowtable* object)
-  {
-    object->cpp_table = NULL;
-  }
-#endif
-
-#if 0
-  void glom_flowtable_class_init(gpointer g_class, gpointer class_data)
-  {
-    GtkWidgetClass* widget_class = GTK_WIDGET_CLASS(g_class);
-    GtkContainerClass* container_class = GTK_CONTAINER_CLASS(g_class);
-
-    parent_class = GTK_CONTAINER_CLASS(g_type_class_peek_parent(g_class));
-
-  }
-
-  GType glom_flowtable_get_type()
-  {
-    static GType flowtable_type = 0;
-
-    if(!flowtable_type)
-    {
-      static const GTypeInfo flowtable_type_info = {
-        sizeof(GlomFlowtableClass),  /* class_size */
-        NULL,                        /* base_init */
-        NULL,                        /* base_finalize */
-        glom_flowtable_class_init,   /* class_init */
-        NULL,                        /* class_finalize */
-        NULL,                        /* class_data */
-        sizeof(GlomFlowtable),       /* instance_size */
-        0,                           /* n_preallocs */
-        glom_flowtable_init,         /* instance_init */
-        NULL                         /* value_table */
-      };
-
-      flowtable_type = g_type_register_static(GTK_TYPE_CONTAINER, "GlomFlowtable", &flowtable_type_info, 0);
-    }
-
-    return flowtable_type;
-  }
-#endif
-}
 
 namespace Glom
 {
-#ifndef GLIBMM_VFUNCS_ENABLED
-  void FlowTable::glom_forall_impl(GtkContainer* container, gboolean include_internals, GtkCallback callback, gpointer callback_data)
-  {
-    Glib::ObjectBase *const obj_base = static_cast<Glib::ObjectBase*>(
-      Glib::ObjectBase::_get_current_wrapper((GObject*)container));
-
-    if(obj_base)
-    {
-      Glom::FlowTable* table = dynamic_cast<Glom::FlowTable*>(obj_base);
-      g_assert(table);
-      table->forall_vfunc(include_internals, callback, callback_data);
-    }
-    else if(parent_class->forall)
-      parent_class->forall(container, include_internals, callback, callback_data);
-  }
-
-  GType FlowTable::glom_child_type_impl(GtkContainer* container)
-  {
-    Glib::ObjectBase *const obj_base = static_cast<Glib::ObjectBase*>(
-      Glib::ObjectBase::_get_current_wrapper((GObject*)container));
-
-    if(obj_base)
-    {
-      Glom::FlowTable* table = dynamic_cast<Glom::FlowTable*>(obj_base);
-      g_assert(table);
-      return table->child_type_vfunc();
-    }
-    else if(parent_class->child_type)
-      return parent_class->child_type(container);
-    else
-      return G_TYPE_NONE;
-  }
-#endif // !GLIBMM_VFUNCS_ENABLED
 
 #ifndef GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
   // TODO: It is probably OK doing static_cast here.
@@ -244,7 +142,7 @@ namespace Glom
       return FALSE;
   }
 #endif // !GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
-}
+} //namespace Glom
 
 namespace Glom
 {
@@ -292,18 +190,18 @@ FlowTable::FlowTableItem::FlowTableItem(Gtk::Widget* first, Gtk::Widget* second,
 
 FlowTable::FlowTable()
 :
-#if !defined(GLIBMM_VFUNCS_ENABLED) || !defined(GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED)
+#if !defined(GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED)
   // This creates a custom GType for us, to override vfuncs and default
   // signal handlers even with the reduced API.
   // TODO: It is necessary to do this in all derived classes which is
   // rather annoying, though I don't see another possibility at the moment. armin.
   Glib::ObjectBase("Glom_FlowTable"),
-#endif // !defined(GLIBMM_VFUNCS_ENABLED) || !defined(GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED)
+#endif // ! !defined(GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED)
   m_columns_count(1),
   m_padding(0),
   m_design_mode(false)
 {
-#if !defined(GLIBMM_VFUNCS_ENABLED) || !defined(GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED)
+#if !defined(GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED)
   // TODO: Thread safety?
   // TODO: We could also set up a Glib::Class derived object with a custom
   // class init function so we do not need to lookup the class object by
@@ -313,11 +211,6 @@ FlowTable::FlowTable()
     GtkContainerClass* container_class = G_TYPE_INSTANCE_GET_CLASS(gobj(), G_TYPE_FROM_INSTANCE(gobj()), GtkContainerClass);
     GtkWidgetClass* widget_class = GTK_WIDGET_CLASS(container_class);
 
-#ifndef GLIBMM_VFUNCS_ENABLED
-    container_class->forall = &Glom::FlowTable::glom_forall_impl;
-    container_class->child_type = &Glom::FlowTable::glom_child_type_impl;
-#endif // !GLIBMM_VFUNCS_ENABLED
-
 #ifndef GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
     container_class->add = &Glom::FlowTable::glom_add_impl;
     container_class->remove = &Glom::FlowTable::glom_remove_impl;
@@ -331,7 +224,7 @@ FlowTable::FlowTable()
 
     parent_class = GTK_CONTAINER_CLASS(g_type_class_peek_parent(container_class));
   }
-#endif // !defined(GLIBMM_VFUNCS_ENABLED) || !defined(GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED)
+#endif // !defined(GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED)
 
   set_flags(Gtk::NO_WINDOW);
   set_redraw_on_allocate(false);
@@ -934,7 +827,7 @@ void FlowTable::on_size_allocate(Gtk::Allocation& allocation)
   }
 }
 
-GtkType FlowTable::child_type_vfunc() const
+GType FlowTable::child_type_vfunc() const
 {
   //TODO: What is this for?
   if(!m_children.empty())
@@ -1095,8 +988,8 @@ void FlowTable::on_realize()
 
 void FlowTable::on_unrealize()
 {
-  m_refGdkWindow.clear();
-  m_refGC.clear();
+  m_refGdkWindow.reset();
+  m_refGC.reset();
 
 #ifdef GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
   Gtk::Container::on_unrealize();
