@@ -20,8 +20,10 @@
 
 #include "imageglom.h"
 #include <glibmm/i18n.h>
-#include "../application.h"
-#include <glom/libglom/data_structure/glomconversions.h>
+#include <glom/application.h>
+#include <glom/utils_ui.h>
+#include <glom/glade_utils.h>
+#include <libglom/data_structure/glomconversions.h>
 //#include <sstream> //For stringstream
 
 #include <iostream>   // for cout, endl
@@ -36,7 +38,7 @@ ImageGlom::ImageGlom()
   init();
 }
 
-ImageGlom::ImageGlom(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& /* refGlade */)
+ImageGlom::ImageGlom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& /* builder */)
 : Gtk::EventBox(cobject),
   m_image(Gtk::Stock::MISSING_IMAGE, Gtk::ICON_SIZE_DIALOG), //The widget is invisible if we don't specify an image.
   m_pMenuPopup_UserMode(0)
@@ -156,7 +158,11 @@ void ImageGlom::set_pixbuf(const Glib::RefPtr<Gdk::Pixbuf>& pixbuf)
 
 void ImageGlom::set_value(const Gnome::Gda::Value& value)
 {
-  Glib::RefPtr<Gdk::Pixbuf> pixbuf = Conversions::get_pixbuf_for_gda_value(value);
+  // Remember original data 
+  m_original_data = Gnome::Gda::Value();
+  m_original_data = value;
+  Glib::RefPtr<Gdk::Pixbuf> pixbuf = Utils::get_pixbuf_for_gda_value(value);
+
   if(pixbuf)
   {
     set_pixbuf(pixbuf);
@@ -218,7 +224,8 @@ Gnome::Gda::Value ImageGlom::get_value() const
 {
   //TODO: Return the data from the file that was just chosen.
   //Don't store the original here any longer than necessary,
-  Gnome::Gda::Value result;
+  if(m_original_data.get_value_type() != G_TYPE_NONE)
+    return m_original_data;
   
   if(m_pixbuf_original)
   {
@@ -244,11 +251,16 @@ Gnome::Gda::Value ImageGlom::get_value() const
       //for(int i = 0; i < 10; ++i)
       //  g_warning("%02X (%c), ", (guint8)buffer[i], buffer[i]);
 
-      result.Glib::ValueBase::init(GDA_TYPE_BINARY);
-      result.set(reinterpret_cast<const guchar*>(buffer), buffer_size);
+      GdaBinary* bin = g_new(GdaBinary, 1);
+      bin->data = reinterpret_cast<guchar*>(buffer);
+      bin->binary_length = buffer_size;
+
+      m_original_data = Gnome::Gda::Value();
+      m_original_data.Glib::ValueBase::init(GDA_TYPE_BINARY);
+      gda_value_take_binary(m_original_data.gobj(), bin);
 
-      g_free(buffer);
       buffer = 0;
+      return m_original_data;
     }
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
     catch(const Glib::Exception& ex)
@@ -258,7 +270,7 @@ Gnome::Gda::Value ImageGlom::get_value() const
 #endif // GLIBMM_EXCEPTIONS_ENABLED
   }
 
-  return result;
+  return Gnome::Gda::Value();
 }
 
 bool ImageGlom::on_expose_event(GdkEventExpose* event)
@@ -394,47 +406,37 @@ void ImageGlom::on_menupopup_activate_select_file()
 
   if((response != Gtk::RESPONSE_CANCEL) && (response != Gtk::RESPONSE_DELETE_EVENT))
   {
-    const std::string filepath = dialog.get_filename();
-    if(!filepath.empty())
+    const Glib::ustring uri = dialog.get_uri();
+    if(!uri.empty())
     {
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-      try
-#else
-      std::auto_ptr<Glib::Error> error;
-#endif // GLIBMM_EXCEPTIONS_ENABLED
+      Dialog_Image_Progress* dialog;
+      Glib::RefPtr<Gtk::Builder> builder = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom.glade"), "dialog_image_progress");
+      builder->get_widget_derived("dialog_image_progress", dialog);
+      if(dialog)
       {
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-        m_pixbuf_original = Gdk::Pixbuf::create_from_file(filepath);
-#else
-        m_pixbuf_original = Gdk::Pixbuf::create_from_file(filepath, error);
-        if(error.get() != NULL)
-        {
-#endif // GLIBMM_EXCEPTIONS_ENABLED
-          if(m_pixbuf_original)
-          {
-            m_image.set(m_pixbuf_original); //Load the image.
-            scale();
-            signal_edited().emit();
-          }
-          else
-          {
-            g_warning("ImageGlom::on_menupopup_activate_select_file(): file load failed.");
-          }
-#ifndef GLIBMM_EXCEPTIONS_ENABLED
-        }
-#endif // !GLIBMM_EXCEPTIONS_ENABLED
-      }
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-      catch(const Glib::Exception& ex)
-      {
-#else
-      if(error.get() != NULL)
-      {
-        const Glib::Exception& ex = *error.get();
-#endif
+        // Automatically delete the dialog when we no longer need it:
+        std::auto_ptr<Gtk::Dialog> dialog_keeper(dialog);
+
         App_Glom* pApp = get_application();
-        if(pApp)
-          Frame_Glom::show_ok_dialog(_("Image loading failed"), _("The image file could not be opened:\n") + ex.what(), *pApp, Gtk::MESSAGE_ERROR);
+        dialog->set_transient_for(*pApp);
+        dialog->load(uri);
+
+        if(dialog->run() == Gtk::RESPONSE_ACCEPT)
+        {
+          GdaBinary* bin = g_new(GdaBinary, 1);
+          std::auto_ptr<GdaBinary> image_data = dialog->get_image_data();
+          bin->data = image_data->data;
+          bin->binary_length = image_data->binary_length;
+
+          m_original_data = Gnome::Gda::Value();
+          m_original_data.Glib::ValueBase::init(GDA_TYPE_BINARY);
+          gda_value_take_binary(m_original_data.gobj(), bin);
+
+          m_pixbuf_original = dialog->get_pixbuf();
+          m_image.set(m_pixbuf_original); //Load the image.
+          scale();
+          signal_edited().emit();
+        }
       }
     }
   }
@@ -463,7 +465,7 @@ void ImageGlom::on_clipboard_clear()
   if(m_read_only)
     return;
 
-  m_pixbuf_clipboard.clear();
+  m_pixbuf_clipboard.reset();
 }
 
 void ImageGlom::on_menupopup_activate_copy()
@@ -474,7 +476,7 @@ void ImageGlom::on_menupopup_activate_copy()
     m_pixbuf_clipboard = m_pixbuf_original->copy(); //TODO: Get it from the DB, when we stop storing the original here instead of just the preview.
   }
   else
-    m_pixbuf_clipboard.clear();
+    m_pixbuf_clipboard.reset();
 
   Glib::RefPtr<Gtk::Clipboard> refClipboard = Gtk::Clipboard::get();
 
@@ -493,6 +495,9 @@ void ImageGlom::on_clipboard_received_image(const Glib::RefPtr<Gdk::Pixbuf>& pix
 
   if(pixbuf)
   {
+    // Clear original data of previous image
+    m_original_data = Gnome::Gda::Value();
+
     m_pixbuf_original = pixbuf;
 
     m_image.set(m_pixbuf_original); //Load the image.
@@ -519,7 +524,7 @@ void ImageGlom::on_menupopup_activate_clear()
   if(m_read_only)
     return;
 
-  m_pixbuf_original.clear();
+  m_pixbuf_original.reset();
   m_image.set(Gtk::Stock::MISSING_IMAGE, Gtk::ICON_SIZE_DIALOG);
   signal_edited().emit();
 }
