@@ -24,7 +24,8 @@
 #include <gtkmm.h>
 #include <libglom/data_structure/field.h>
 #include "layoutwidgetfield.h"
-#include <libglademm.h>
+#include "dialog_image_progress.h"
+#include <gtkmm/builder.h>
 
 namespace Glom
 {
@@ -37,7 +38,7 @@ class ImageGlom
 {
 public:
   ImageGlom();
-  explicit ImageGlom(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
+  explicit ImageGlom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
 
 
   virtual ~ImageGlom();
@@ -81,6 +82,7 @@ private:
  
   Gtk::Image m_image;
   Gtk::Frame m_frame;
+  mutable Gnome::Gda::Value m_original_data; // Original file data (mutable so that we can create it in get_value() if it does not exist yet)
   Glib::RefPtr<Gdk::Pixbuf> m_pixbuf_original; //Only stored temporarily, because it could be big.
   Glib::RefPtr<Gdk::Pixbuf> m_pixbuf_clipboard; //When copy is used, store it here until it is pasted.
 
